(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    165989,       4785]*)
(*NotebookOutlinePosition[    166638,       4808]*)
(*  CellTagsIndexPosition[    166594,       4804]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Beispiele, in denen der Gr\[ODoubleDot]bnerwalk funktioniert.", \
"Subsubsection"],

Cell["\<\
In den betrachteten Beispielen werden Differential/Shift-Algebren \
betrachtet. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<GroebnerWalk`\>"]\), "\[IndentingNewLine]", 
    \(\(Diff\  = \ OreDefineDiff[Dx, x];\)\), "\n", 
    \(\(NShift = OreDefineShift[Sn, n];\)\ \), "\n", 
    \({Varlist, Mat} = OreGetMonomOrder[]\)}], "Input"],

Cell[BoxData[
    \({{Dx, Sn, x, 
        n}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
          1}}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ein kleines Beispiel:", "Subsubsection"],

Cell["\<\
Wir definieren ein Ideal, repr\[ADoubleDot]sentiert durch zwei \
erzeugenden Elemente.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(G1 = OMu[NShift, OPo[x^2]];\)\), "\n", 
    \(\(G2 = OMu[OPo[x], Diff] + OPo[n^2];\)\), "\n", 
    \(Ideal = {G1, G2}\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ 
              Power[ x, 2], 
              OreMonomial[ {2, 1}]], ""],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", \(n\^2\)}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ 
                Power[ n, 2], 
                OreMonomial[ ]]], "+"],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Unsere Zielordnung soll die gradlexikografische mit Dx>Sn>x>n sein. \

Wir schauen uns vorab das Ergebnis an.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(C2 = {{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}\), "\n", 
    \(\(V = {Diff, NShift, x, n};\)\), "\n", 
    \(\(\(OreRedefineMonomOrder[V, C2];\)\  (*\ 
        Gradlex . \ Ordnung\ \(\(definieren\)\(.\)\)\ *) ;\)\), "\n", 
    \(Ideal = OreSimplify /@ Ideal; \ \ \ \  (*\ 
      Idealelemente\ \(\(normalisieren\)\(.\)\)\ *) ;\), "\n", 
    \(Timing[GBneu = OreLeftGroebnerLimited[Ideal, 11]]\ \), "\n", 
    \(GBneu = OreReduceGroebnerBasis[GBneu]\)}], "Input"],

Cell[BoxData[
    \({{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}\)], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.282957`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-n\^2\)\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-n\^4\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ n, 4]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-4\)\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-3\)\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ n, 4]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((\(-n\^4\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -1, 
                    Power[ n, 4]], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-4\)\ n\^3)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -4, 
                    Power[ n, 3]], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-3\)\ n\^2)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -3, 
                    Power[ n, 2]], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((2\ n)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 2, n], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Times[ -1, 
                  Power[ n, 4]], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ -4, 
                  Power[ n, 3]], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ -3, 
                  Power[ n, 2]], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ 2, n], 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((\(-n\^2\)\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -1, 
                    Power[ n, 2], x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-2\)\ n\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -2, n, x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(x \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Times[ -1, 
                  Power[ n, 2], x], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ -2, n, x], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ x, 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ 
              Power[ x, 2], 
              OreMonomial[ {2, 1}]], ""],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", \(n\^2\)}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ 
                Power[ n, 2], 
                OreMonomial[ ]]], "+"],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Die Basis in unserer Zielordnung C2 hat also vier Elemente ... 
Mit lexikografischen Ordnung mit n>x>Sn>Dx allerdings ist die \
Gr\[ODoubleDot]bnerbasis ganz einfach, wir wechseln wieder in die \
Startordnung und lassen sie ausrechnen: \
\>", "Text"],

Cell[BoxData[{
    \(\(C1 = {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 
            0}};\)\), "\n", 
    \(\(OreRedefineMonomOrder[V, C1];\)\), "\[IndentingNewLine]", 
    \(\(Ideal = OreSimplify /@ Ideal;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Timing[
      GBneu = OreLeftGroebnerLimited[Ideal, 11]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.02499599999999998`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["In der Tat reduziert sich das einzige S-Polynom zu Null:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Spol = OreSPoly[Ideal[\([1]\)], Ideal[\([2]\)]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        InterpretationBox[\(\((\(-2\)\ n\ x\^2)\) \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ 
              Times[ -2, n, 
                Power[ x, 2]], 
              OreMonomial[ {2, 1}]], ""],
          Editable->False], "+", 
        InterpretationBox[
          RowBox[{\((\(-x\^3\))\), "\<\"\"\>", 
            RowBox[{"(", 
              InterpretationBox[\(Dx \*"\<\"\"\>" Sn\),
                Infix[ {Dx, Sn}, ""],
                Editable->False], ")"}]}],
          Infix[ 
            OreSummand[ 
              Times[ -1, 
                Power[ x, 3]], 
              OreMonomial[ {1, 1}, {2, 1}]], ""],
          Editable->False], "+", 
        InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ 
              Times[ -1, 
                Power[ x, 2]], 
              OreMonomial[ {2, 1}]], ""],
          Editable->False]}],
      Infix[ 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -2, n, 
              Power[ x, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 3]], 
            OreMonomial[ {1, 1}, {2, 1}]], 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {2, 1}]]], "+"],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OreDivision[Spol, Ideal]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"0", ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(2\ n\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(-1\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 2, n], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ -1, 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Nun schauen wir, was der Gr\[ODoubleDot]bnerwalk macht. Wir lassen \
uns Startordnung, Zielordnung und aktuelle Ordnung anzeigen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({C1 // MatrixForm, \ C2 // MatrixForm, 
      MatrixForm /@ OreGetMonomOrder[], \ Ideal}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1", "1"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {"Dx"},
                      {"Sn"},
                      {"x"},
                      {"n"}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], ",", 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "1", "0"},
                    {"0", "1", "0", "0"},
                    {"1", "0", "0", "0"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Nun gehen wir in die Startordnung und schreiten zur Zielordnung. \
Der gesammte Walk besteht hier
nur aus zwei Schritten:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(OreRedefineMonomOrder[V, C1];\)\), "\n", 
    \(Ideal = OreSimplify /@ Ideal; GB = DoTheWalk[Ideal, C2, 3]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Entering DoTheWalk:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}], 
        "\[InvisibleSpace]", \({{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 
            0, 0, 1}}\)}],
      SequenceForm[ "Entering DoTheWalk:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}, {{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 
        0}, {0, 0, 0, 1}}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Initialized: v,w,g=\"\>", 
        "\[InvisibleSpace]", \({1, 1, 1, 1}\), 
        "\[InvisibleSpace]", \({0, 0, 0, 1}\), "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Initialized: v,w,g=", {1, 1, 1, 1}, {0, 0, 0, 1}, {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{0, 0, 0, 
            1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 0}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{0, 0, 0, 
            1}, {1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 
            0}}\[InvisibleSpace]"."\),
      SequenceForm[ 
      "New order matrix is:", {{0, 0, 0, 1}, {1, 1, 1, 1}, {0, 1, 0, 0}, {0, 
        0, 1, 0}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"1", "1", "1", "1"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 0}}],
         "actual order: ", 
        MatrixForm[ {{0, 0, 0, 1}, {1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}}],
         "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(n\^2\)}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(n\^2\)}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"It is:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(n\^2\)}], "}"}]}],
      SequenceForm[ "It is:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Entering LiftUp:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]False\),
      SequenceForm[ "Step 8: Ready? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 9: New weight determined."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("t="\[InvisibleSpace]1\[InvisibleSpace]" weight="\
\[InvisibleSpace]{1, 1, 1, 1}\),
      SequenceForm[ "t=", 1, " weight=", {1, 1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Next weight vector: w="\[InvisibleSpace]{1, 1, 1, 
          1}\),
      SequenceForm[ "Next weight vector: w=", {1, 1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Entering iteration "\[InvisibleSpace]2\),
      SequenceForm[ "Entering iteration ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{0, 0, 0, 
            1}, {1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{0, 0, 0, 1}, {1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{1, 1, 1, 
            1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
            1}}\[InvisibleSpace]"."\),
      SequenceForm[ 
      "New order matrix is:", {{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 
        0, 0, 1}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"1", "1", "1", "1"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1", "1"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{0, 0, 0, 1}, {1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}}],
         "actual order: ", 
        MatrixForm[ {{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}],
         "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"It is:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "It is:", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Entering LiftUp:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]True\),
      SequenceForm[ "Step 8: Ready? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ n, 4], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 4, 
                    Power[ n, 3]], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 3, 
                    Power[ n, 2]], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -2, n], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Power[ n, 4], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ 4, 
                  Power[ n, 3]], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ 3, 
                  Power[ n, 2]], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ -2, n], 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 
                    Power[ n, 2], x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 2, n, x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -1, x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Times[ 
                  Power[ n, 2], x], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ 2, n, x], 
                OreMonomial[ {2, 1}]], 
              OreSummand[ 
                Times[ -1, x], 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ 
              Power[ x, 2], 
              OreMonomial[ {2, 1}]], ""],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", \(n\^2\)}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ 
                Power[ n, 2], 
                OreMonomial[ ]]], "+"],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OreIsLeftGroebner[GB]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Ein Blick auf die Daten zeigt, da\[SZ] wir uns nun in der \
Zielordnung befinden und die gefundene Basis mit dem vorab bestimmten \
Ergebnis \[UDoubleDot]bereinstimmt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({MatrixForm /@ OreGetMonomOrder[], \ GB}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {"Dx"},
                      {"Sn"},
                      {"x"},
                      {"n"}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], ",", 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "1", "1", "1"},
                    {"0", "1", "0", "0"},
                    {"0", "0", "1", "0"},
                    {"0", "0", "0", "1"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["Wir  k\[ODoubleDot]nnen also direkt wieder zur\[UDoubleDot]cklaufen:", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GBzur = DoTheWalk[GB, C1, 3]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Entering DoTheWalk:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False]}], "}"}], 
        "\[InvisibleSpace]", \({{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 
            0, 0, 0}}\)}],
      SequenceForm[ "Entering DoTheWalk:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}, {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 
        0, 0, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Initialized: v,w,g=\"\>", 
        "\[InvisibleSpace]", \({0, 0, 0, 1}\), 
        "\[InvisibleSpace]", \({1, 1, 1, 1}\), "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", \(n\^2\)}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Initialized: v,w,g=", {0, 0, 0, 1}, {1, 1, 1, 1}, {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{1, 1, 1, 
            1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{1, 1, 1, 
            1}, {0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 
            0}}\[InvisibleSpace]"."\),
      SequenceForm[ 
      "New order matrix is:", {{1, 1, 1, 1}, {0, 0, 0, 1}, {0, 0, 1, 0}, {0, 
        1, 0, 0}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1", "1"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1", "1"},
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{1, 1, 1, 1}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}],
         "actual order: ", 
        MatrixForm[ {{1, 1, 1, 1}, {0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}}],
         "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ n, 4], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 
                    Power[ n, 2], x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ n, 4], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 
                    Power[ n, 2], x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"It is:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ n, 4], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ 
                    Power[ n, 2], x], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-2\)\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(x \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[\(\((\(-n\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Times[ -1, n], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "It is:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, n], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Entering LiftUp:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(n\^4\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Power[ n, 4], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((4\ n\^3)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 4, 
                        Power[ n, 3]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((3\ n\^2)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 3, 
                        Power[ n, 2]], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ n)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, n], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 4], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 4, 
                      Power[ n, 3]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 3, 
                      Power[ n, 2]], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -2, n], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\^2\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 
                        Power[ n, 2], x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((2\ n\ x)\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ 2, n, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ 
                      Power[ n, 2], x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ 2, n, x], 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", "0", ",", "0", ",", "0"}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 4], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 4, 
              Power[ n, 3]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 3, 
              Power[ n, 2]], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -2, n], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ 
              Power[ n, 2], x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ 2, n, x], 
            OreMonomial[ {2, 1}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 0, 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 0, 
            OreMonomial[ ]]], 
        OrePolynomial[ 
          OreSummand[ 0, 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]False\),
      SequenceForm[ "Step 8: Ready? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 9: New weight determined."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("t="\[InvisibleSpace]1\[InvisibleSpace]" weight="\
\[InvisibleSpace]{0, 0, 0, 1}\),
      SequenceForm[ "t=", 1, " weight=", {0, 0, 0, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Next weight vector: w="\[InvisibleSpace]{0, 0, 0, 
          1}\),
      SequenceForm[ "Next weight vector: w=", {0, 0, 0, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Entering iteration "\[InvisibleSpace]2\),
      SequenceForm[ "Entering iteration ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{1, 1, 1, 
            1}, {0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{1, 1, 1, 1}, {0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{0, 0, 0, 
            1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 
            0}}\[InvisibleSpace]"."\),
      SequenceForm[ 
      "New order matrix is:", {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 
        0, 0, 0}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1", "1"},
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{1, 1, 1, 1}, {0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}}],
         "actual order: ", 
        MatrixForm[ {{0, 0, 0, 1}, {0, 0, 1, 0}, {0, 1, 0, 0}, {1, 0, 0, 0}}],
         "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(n\^2\)}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(n\^2\)}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"It is:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(n\^2\)}], "}"}]}],
      SequenceForm[ "It is:", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Entering LiftUp:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Power[ n, 2], 
            OreMonomial[ ]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Power[ x, 2], 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]True\),
      SequenceForm[ "Step 8: Ready? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{\(n\^2\), "+", 
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Power[ n, 2], 
                OreMonomial[ ]], 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ 
              Power[ x, 2], 
              OreMonomial[ {2, 1}]], ""],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Es hat geklappt! Ein Blick auf Schritt 6 im ersten Durchlauf zeigt, \
da\[SZ] drei Elemente der Gr\[ODoubleDot]bnerbasis der Initialpolynome nicht \
geliftet wurden. \nW\[UDoubleDot]rde Schritt 5 ausgef\[UDoubleDot]hrt werden, \
also die Basis der Initialpolynome reduziert werden, \nh\[ADoubleDot]tte das \
vorletzte Element der Basis nach Schritt 4 das Element ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^2\) \(Sn\)\(\ \)\(eliminiert . \ 
          Damit\)\(\ \)\(w\[ADoubleDot]re\)\(\ \)\(die\)\(\ \)\(gefundene\)\(\
\ \)\(Basis\)\(\ \)\(unvollst\[ADoubleDot]ndig!\)\(\ \)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({C1 // MatrixForm, \ C2 // MatrixForm, 
      MatrixForm /@ OreGetMonomOrder[], \ GBzur}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1"},
                {"0", "0", "1", "0"},
                {"0", "1", "0", "0"},
                {"1", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1", "1"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {"Dx"},
                      {"Sn"},
                      {"x"},
                      {"n"}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], ",", 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", "0", "0", "1"},
                    {"0", "0", "1", "0"},
                    {"0", "1", "0", "0"},
                    {"1", "0", "0", "0"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(n\^2\), "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ n, 2], 
                    OreMonomial[ ]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Hier haben wir also ein Beispiel, wo der Gr\[ODoubleDot]bner--walk \
korrekt Basen unterschiedlicher L\[ADoubleDot]ngen ineinander \
\[UDoubleDot]berf\[UDoubleDot]hrt.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ein weiteres kleines Beispiel:", "Subsubsection"],

Cell["\<\
Das folgende Beispiel k\[ODoubleDot]nnte sich ergeben, wenn man \
Funktionen f(x,n) sucht, die verschiedenen Funktionalgleichungen im stetigen \
Parameter x und dem diskreten Parameter n gen\[UDoubleDot]gen. 
Es soll f(x,n+1)=x f\.b4(x,n)  und  n x^2 f\.b4\.b4(x,n)=f(x,n+2)    sein. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(N1 = OMu[OPo[x], Diff] - NShift;\)\), "\n", 
    \(\(N2 = OMu[OPo[n\ x^2], Diff^2] - NShift^2;\)\), "\n", 
    \(Ideal = {N1, N2}\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ -1, 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((n\ x\^2)\) \*"\<\"\"\>" Dx\^2\),
              Infix[ 
                OreSummand[ 
                  Times[ n, 
                    Power[ x, 2]], 
                  OreMonomial[ {1, 2}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\^2\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 2}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Times[ n, 
                  Power[ x, 2]], 
                OreMonomial[ {1, 2}]], 
              OreSummand[ -1, 
                OreMonomial[ {2, 2}]]], "+"],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Die gesuchten Funktionen m\[UDoubleDot]ssen durch diese Operatoren \
verschwinden. 
Wir berechnen die Gr\[ODoubleDot]bnerbasis bez\[UDoubleDot]glichd der \
lexikografischen Ordnung:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(OreDefineLexOrder;\)\), "\[IndentingNewLine]", 
    \({Varlist, C1} = OreGetMonomOrder[]; \ {MatrixForm[Varlist], 
      MatrixForm[C1]}\), "\n", 
    \(Ideal = OreSimplify /@ Ideal\), "\n", 
    \(Timing[GBneu = OreLeftGroebnerLimited[Ideal, 11]]\ \), "\n", 
    \(GBstart = OreReduceGroebnerBasis[GBneu]\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", 
            TagBox[GridBox[{
                  {"Dx"},
                  {"Sn"},
                  {"x"},
                  {"n"}
                  },
                RowSpacings->1,
                ColumnAlignments->{Left}],
              Column], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ -1, 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((n\ x\^2)\) \*"\<\"\"\>" Dx\^2\),
              Infix[ 
                OreSummand[ 
                  Times[ n, 
                    Power[ x, 2]], 
                  OreMonomial[ {1, 2}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\^2\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 2}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Times[ n, 
                  Power[ x, 2]], 
                OreMonomial[ {1, 2}]], 
              OreSummand[ -1, 
                OreMonomial[ {2, 2}]]], "+"],
          Editable->False]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.37694300000000014`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((n\ x\^2)\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ n, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\^2\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 2}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ n, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 2}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-n\))\) \*"\<\"\"\>" Sn\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, n], 
                      OreMonomial[ {2, 2}]], ""],
                  Editable->False], "+", \(Sn\^2\), "+", 
                InterpretationBox[\(n \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ n, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, n], 
                    OreMonomial[ {2, 2}]], 
                  OreSummand[ 1, 
                    OreMonomial[ {2, 2}]], 
                  OreSummand[ n, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{\(Sn\^3\), "+", 
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\^2\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 2}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 1, 
                    OreMonomial[ {2, 3}]], 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 2}]]], "+"],
              Editable->False], ",", \(Sn\^2\), ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ -1, 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", \(Sn\^2\), ",", 
        InterpretationBox[\(n \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ n, 
              OreMonomial[ {2, 1}]], ""],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Hier sieht man, da\[SZ] ",
  Cell[BoxData[
      \(TraditionalForm\`\(Sn\^2\)(f(x, n)) = 0\)]],
  " gelten mu\[SZ]. Aus f(x,n+2)=0 sehen wir da\[SZ] nur die Nullfunktion das \
Ausgangsproblem l\[ODoubleDot]st. Aber sehen wir davon einmal ab. \nNun wird \
so eliminiert, da\[SZ] m\[ODoubleDot]glichst ein Ausdruck in x, Dx \
\[UDoubleDot]brigbleibt: also, Sn, n bekommen\nhohe Priorit\[ADoubleDot]t, x \
und Dx kommen am Schlu\[SZ]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(C2 = {{0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}, {1, 0, 0, 
            0}};\)\), "\n", 
    \(C2 // MatrixForm\), "\[IndentingNewLine]", 
    \(\(OreRedefineMonomOrder[V, C2];\)\), "\n", 
    \(\(Ideal = OreSimplify /@ Ideal;\)\), "\n", 
    \(Timing[GBneu = OreLeftGroebnerLimited[Ideal, 11]]\ \), "\n", 
    \(GBneu = OreReduceGroebnerBasis[GBneu]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "0", "1"},
            {"0", "0", "1", "0"},
            {"1", "0", "0", "1"},
            {"1", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.678897`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\^2\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((n\ x\^2)\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ n, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 2}]], 
                  OreSummand[ 
                    Times[ n, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-n\)\ x\^2)\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, n, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Power[ x, 2], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, n, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Power[ x, 2], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^3\))\) \*"\<\"\"\>" Dx\^3\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 3]], 
                      OreMonomial[ {1, 3}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-2\)\ x\^2)\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -2, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 3]], 
                    OreMonomial[ {1, 3}]], 
                  OreSummand[ 
                    Times[ -2, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Power[ x, 2], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Power[ x, 2], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
          Infix[ 
            OreSummand[ 
              Times[ n, x], 
              OreMonomial[ {1, 1}]], ""],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ -1, 
                OreMonomial[ {2, 1}]], 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\(x\^2\) \*"\<\"\"\>" Dx\^2\),
              Infix[ 
                OreSummand[ 
                  Power[ x, 2], 
                  OreMonomial[ {1, 2}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Power[ x, 2], 
                OreMonomial[ {1, 2}]], 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]]], "+"],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Das war die direkte Berechnung. Nun gehen wir zur\[UDoubleDot]ck \
zur lexikografischen Ordnung, und probieren den Walk, diesmal werden drei \
Iterationen gebraucht:\
\>", "Text"],

Cell[BoxData[
    \(OreDefineLexOrder\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Result = DoTheWalk[GBstart, C2, 2, 5]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{1, 0, 0, 
            0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{1, 0, 0, 
            0}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 
            1}}\[InvisibleSpace]"."\),
      SequenceForm[ 
      "New order matrix is:", {{1, 0, 0, 0}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 
        0, 0, 1}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "1", "0", "0"},
                {"0", "0", "1", "0"},
                {"0", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "1", "0", "1"},
                {"0", "0", "1", "0"},
                {"1", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", \(Sn\^2\), ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}],
         "actual order: ", 
        MatrixForm[ {{1, 0, 0, 0}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}],
         "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", \(Sn\^2\), ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", \(Sn\^2\), ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", \(Sn\^2\), ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]], 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(Sn\^2\)}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]], 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]False\),
      SequenceForm[ "Step 8: Ready? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 9: New weight determined."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Entering iteration "\[InvisibleSpace]2\),
      SequenceForm[ "Entering iteration ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{1, 0, 0, 
            0}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{1, 0, 0, 0}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{1\/2, 1\/2, 
            0, 1\/2}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 
            1}}\[InvisibleSpace]"."\),
      SequenceForm[ "New order matrix is:", {{
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2]}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "1", "0", "1"},
                {"0", "0", "1", "0"},
                {"1", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(1\/2\), \(1\/2\), "0", \(1\/2\)},
                {"0", "1", "0", "1"},
                {"0", "0", "1", "0"},
                {"1", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(Sn\^2\)}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{1, 0, 0, 0}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}],
         "actual order: ", 
        MatrixForm[ {{
          Rational[ 1, 2], 
          Rational[ 1, 2], 0, 
          Rational[ 1, 2]}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}], 
        "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(Sn\^2\)}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(Sn\^2\)}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(n \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ n, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], ",", \(Sn\^2\), ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ n, 
            OreMonomial[ {2, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 1, 
            OreMonomial[ {2, 2}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]False\),
      SequenceForm[ "Step 8: Ready? ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 9: New weight determined."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Entering iteration "\[InvisibleSpace]3\),
      SequenceForm[ "Entering iteration ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{1\/2, 1\/2, 
            0, 1\/2}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2]}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("New order matrix is:"\[InvisibleSpace]{{0, 1, 0, 
            1}, {0, 0, 1, 0}, {1, 0, 0, 1}, {1, 0, 0, 
            0}}\[InvisibleSpace]"."\),
      SequenceForm[ 
      "New order matrix is:", {{0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}, {1, 
        0, 0, 0}}, "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"last order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(1\/2\), \(1\/2\), "0", \(1\/2\)},
                {"0", "1", "0", "1"},
                {"0", "0", "1", "0"},
                {"1", "0", "0", "1"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"actual order: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0", "1"},
                {"0", "0", "1", "0"},
                {"1", "0", "0", "1"},
                {"1", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        "\[InvisibleSpace]", "\<\"Gb now: \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "last order: ", 
        MatrixForm[ {{
          Rational[ 1, 2], 
          Rational[ 1, 2], 0, 
          Rational[ 1, 2]}, {0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}}], 
        "actual order: ", 
        MatrixForm[ {{0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}, {1, 0, 0, 0}}],
         "Gb now: ", {
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 2, Initial forms:\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 2, Initial forms:", {
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 3: Sorted, now Gwp=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 3: Sorted, now Gwp=", {
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Step 4: Calculating GB of initials:"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 6: Gwp now lifted: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 6: Gwp now lifted: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Step 7: Gwp reduced: GG=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ n, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
                  Infix[ 
                    OreSummand[ -1, 
                      OreMonomial[ {2, 1}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(x \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ x, 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ -1, 
                    OreMonomial[ {2, 1}]], 
                  OreSummand[ x, 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False], ",", 
            InterpretationBox[
              RowBox[{
                InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, 
                        Power[ x, 2]], 
                      OreMonomial[ {1, 2}]], ""],
                  Editable->False], "+", 
                InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
                  Infix[ 
                    OreSummand[ 
                      Times[ -1, x], 
                      OreMonomial[ {1, 1}]], ""],
                  Editable->False]}],
              Infix[ 
                OrePolynomial[ 
                  OreSummand[ 
                    Times[ -1, 
                      Power[ x, 2]], 
                    OreMonomial[ {1, 2}]], 
                  OreSummand[ 
                    Times[ -1, x], 
                    OreMonomial[ {1, 1}]]], "+"],
              Editable->False]}], "}"}]}],
      SequenceForm[ "Step 7: Gwp reduced: GG=", {
        OrePolynomial[ 
          OreSummand[ 
            Times[ n, x], 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ -1, 
            OreMonomial[ {2, 1}]], 
          OreSummand[ x, 
            OreMonomial[ {1, 1}]]], 
        OrePolynomial[ 
          OreSummand[ 
            Times[ -1, 
              Power[ x, 2]], 
            OreMonomial[ {1, 2}]], 
          OreSummand[ 
            Times[ -1, x], 
            OreMonomial[ {1, 1}]]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Step 8: Ready? "\[InvisibleSpace]True\),
      SequenceForm[ "Step 8: Ready? ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[\(\((n\ x)\) \*"\<\"\"\>" Dx\),
          Infix[ 
            OreSummand[ 
              Times[ n, x], 
              OreMonomial[ {1, 1}]], ""],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ -1, 
                OreMonomial[ {2, 1}]], 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]]], "+"],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(\((\(-x\^2\))\) \*"\<\"\"\>" Dx\^2\),
              Infix[ 
                OreSummand[ 
                  Times[ -1, 
                    Power[ x, 2]], 
                  OreMonomial[ {1, 2}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-x\))\) \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ 
                  Times[ -1, x], 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ 
                Times[ -1, 
                  Power[ x, 2]], 
                OreMonomial[ {1, 2}]], 
              OreSummand[ 
                Times[ -1, x], 
                OreMonomial[ {1, 1}]]], "+"],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["Probehalber laufen wir nochmals zur\[UDoubleDot]ck:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoTheWalk[Result, C1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{0, 1, 0, 
            1}, {0, 0, 1, 0}, {1, 0, 0, 1}, {1, 0, 0, 0}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{0, 1, 0, 1}, {0, 0, 1, 0}, {1, 0, 0, 1}, {1, 0, 0, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{0, 1, 0, 
            1}, {1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{0, 1, 0, 1}, {1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Check, whether actual GG is still a \
Gr\[ODoubleDot]bner base: Current matrix is:"\[InvisibleSpace]{{1\/2, 1\/2, 
            0, 1\/2}, {1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}}\),
      SequenceForm[ 
      "Check, whether actual GG is still a Gr\[ODoubleDot]bner base: Current \
matrix is:", {{
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2]}, {1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("It is."\)], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            InterpretationBox[\(x \*"\<\"\"\>" Dx\),
              Infix[ 
                OreSummand[ x, 
                  OreMonomial[ {1, 1}]], ""],
              Editable->False], "+", 
            InterpretationBox[\(\((\(-1\))\) \*"\<\"\"\>" Sn\),
              Infix[ 
                OreSummand[ -1, 
                  OreMonomial[ {2, 1}]], ""],
              Editable->False]}],
          Infix[ 
            OrePolynomial[ 
              OreSummand[ x, 
                OreMonomial[ {1, 1}]], 
              OreSummand[ -1, 
                OreMonomial[ {2, 1}]]], "+"],
          Editable->False], ",", \(Sn\^2\), ",", 
        InterpretationBox[\(n \*"\<\"\"\>" Sn\),
          Infix[ 
            OreSummand[ n, 
              OreMonomial[ {2, 1}]], ""],
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["Und wir sind wieder zur\[UDoubleDot]ckgelangt!", "Text"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
WindowSize->{1003, 683},
WindowMargins->{{91, Automatic}, {Automatic, 0}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 88, 1, 39, "Subsubsection"],
Cell[1867, 56, 104, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[1996, 63, 237, 4, 108, "Input"],
Cell[2236, 69, 128, 3, 39, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2413, 78, 46, 0, 39, "Subsubsection"],
Cell[2462, 80, 110, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[2597, 87, 154, 3, 85, "Input"],
Cell[2754, 92, 760, 23, 46, "Output"]
}, Open  ]],
Cell[3529, 118, 133, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[3687, 126, 498, 8, 154, "Input"],
Cell[4188, 136, 90, 1, 39, "Output"],
Cell[4281, 139, 4030, 104, 76, "Output"],
Cell[8314, 245, 3552, 102, 76, "Output"]
}, Open  ]],
Cell[11881, 350, 260, 5, 96, "Text"],
Cell[12144, 357, 231, 4, 85, "Input"],

Cell[CellGroupData[{
Cell[12400, 365, 103, 2, 39, "Input"],
Cell[12506, 369, 933, 25, 46, "Output"]
}, Open  ]],
Cell[13454, 397, 72, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[13551, 401, 80, 1, 39, "Input"],
Cell[13634, 404, 1388, 43, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15059, 452, 57, 1, 39, "Input"],
Cell[15119, 455, 772, 21, 39, "Output"]
}, Open  ]],
Cell[15906, 479, 153, 3, 71, "Text"],

Cell[CellGroupData[{
Cell[16084, 486, 121, 2, 62, "Input"],
Cell[16208, 490, 2754, 76, 110, "Output"]
}, Open  ]],
Cell[18977, 569, 145, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[19147, 577, 143, 2, 85, "Input"],
Cell[19293, 581, 1463, 40, 63, "Print"],
Cell[20759, 623, 1415, 39, 40, "Print"],
Cell[22177, 664, 417, 7, 56, "Print"],
Cell[22597, 673, 41, 1, 33, "Print"],
Cell[22641, 676, 340, 7, 33, "Print"],
Cell[22984, 685, 2495, 67, 104, "Print"],
Cell[25482, 754, 694, 20, 40, "Print"],
Cell[26179, 776, 698, 20, 40, "Print"],
Cell[26880, 798, 70, 1, 33, "Print"],
Cell[26953, 801, 662, 20, 40, "Print"],
Cell[27618, 823, 51, 1, 33, "Print"],
Cell[27672, 826, 1307, 37, 40, "Print"],
Cell[28982, 865, 1301, 37, 40, "Print"],
Cell[30286, 904, 161, 3, 33, "Print"],
Cell[30450, 909, 65, 1, 33, "Print"],
Cell[30518, 912, 211, 4, 33, "Print"],
Cell[30732, 918, 200, 4, 33, "Print"],
Cell[30935, 924, 161, 3, 33, "Print"],
Cell[31099, 929, 417, 7, 56, "Print"],
Cell[31519, 938, 41, 1, 33, "Print"],
Cell[31563, 941, 340, 7, 33, "Print"],
Cell[31906, 950, 2495, 67, 104, "Print"],
Cell[34404, 1019, 1297, 37, 40, "Print"],
Cell[35704, 1058, 1301, 37, 40, "Print"],
Cell[37008, 1097, 70, 1, 33, "Print"],
Cell[37081, 1100, 5081, 142, 70, "Print"],
Cell[42165, 1244, 51, 1, 33, "Print"],
Cell[42219, 1247, 5123, 142, 70, "Print"],
Cell[47345, 1391, 5117, 142, 70, "Print"],
Cell[52465, 1535, 159, 3, 33, "Print"],
Cell[52627, 1540, 3525, 102, 76, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56189, 1647, 54, 1, 39, "Input"],
Cell[56246, 1650, 38, 1, 39, "Output"]
}, Open  ]],
Cell[56299, 1654, 191, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[56515, 1662, 73, 1, 39, "Input"],
Cell[56591, 1665, 4963, 131, 148, "Output"]
}, Open  ]],
Cell[61569, 1799, 86, 1, 46, "Text"],

Cell[CellGroupData[{
Cell[61680, 1804, 61, 1, 39, "Input"],
Cell[61744, 1807, 5279, 145, 93, "Print"],
Cell[67026, 1954, 5231, 144, 92, "Print"],
Cell[72260, 2100, 417, 7, 56, "Print"],
Cell[72680, 2109, 41, 1, 33, "Print"],
Cell[72724, 2112, 340, 7, 33, "Print"],
Cell[73067, 2121, 6311, 172, 252, "Print"],
Cell[79381, 2295, 2038, 59, 40, "Print"],
Cell[81422, 2356, 2042, 59, 40, "Print"],
Cell[83467, 2417, 70, 1, 33, "Print"],
Cell[83540, 2420, 3623, 104, 40, "Print"],
Cell[87166, 2526, 51, 1, 33, "Print"],
Cell[87220, 2529, 5396, 151, 70, "Print"],
Cell[92619, 2682, 1301, 37, 40, "Print"],
Cell[93923, 2721, 161, 3, 33, "Print"],
Cell[94087, 2726, 65, 1, 33, "Print"],
Cell[94155, 2729, 211, 4, 33, "Print"],
Cell[94369, 2735, 200, 4, 33, "Print"],
Cell[94572, 2741, 161, 3, 33, "Print"],
Cell[94736, 2746, 417, 7, 56, "Print"],
Cell[95156, 2755, 41, 1, 33, "Print"],
Cell[95200, 2758, 340, 7, 33, "Print"],
Cell[95543, 2767, 2495, 67, 104, "Print"],
Cell[98041, 2836, 694, 20, 40, "Print"],
Cell[98738, 2858, 698, 20, 40, "Print"],
Cell[99439, 2880, 70, 1, 33, "Print"],
Cell[99512, 2883, 662, 20, 40, "Print"],
Cell[100177, 2905, 51, 1, 33, "Print"],
Cell[100231, 2908, 1307, 37, 40, "Print"],
Cell[101541, 2947, 1301, 37, 40, "Print"],
Cell[102845, 2986, 159, 3, 33, "Print"],
Cell[103007, 2991, 760, 23, 46, "Output"]
}, Open  ]],
Cell[103782, 3017, 619, 10, 143, "Text"],

Cell[CellGroupData[{
Cell[104426, 3031, 121, 2, 62, "Input"],
Cell[104550, 3035, 2754, 76, 110, "Output"]
}, Open  ]],
Cell[107319, 3114, 191, 4, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107547, 3123, 55, 0, 39, "Subsubsection"],
Cell[107605, 3125, 310, 6, 96, "Text"],

Cell[CellGroupData[{
Cell[107940, 3135, 166, 3, 85, "Input"],
Cell[108109, 3140, 1524, 44, 46, "Output"]
}, Open  ]],
Cell[109648, 3187, 205, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[109878, 3196, 342, 6, 131, "Input"],
Cell[110223, 3204, 898, 27, 110, "Output"],
Cell[111124, 3233, 1524, 44, 46, "Output"],
Cell[112651, 3279, 3437, 88, 76, "Output"],
Cell[116091, 3369, 910, 26, 46, "Output"]
}, Open  ]],
Cell[117016, 3398, 463, 9, 121, "Text"],

Cell[CellGroupData[{
Cell[117504, 3411, 386, 7, 154, "Input"],
Cell[117893, 3420, 406, 12, 129, "Output"],
Cell[118302, 3434, 5096, 132, 76, "Output"],
Cell[123401, 3568, 1647, 48, 46, "Output"]
}, Open  ]],
Cell[125063, 3619, 189, 4, 71, "Text"],
Cell[125255, 3625, 50, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[125330, 3630, 70, 1, 39, "Input"],
Cell[125403, 3633, 417, 7, 56, "Print"],
Cell[125823, 3642, 41, 1, 33, "Print"],
Cell[125867, 3645, 340, 7, 33, "Print"],
Cell[126210, 3654, 2703, 71, 214, "Print"],
Cell[128916, 3727, 894, 25, 40, "Print"],
Cell[129813, 3754, 898, 25, 40, "Print"],
Cell[130714, 3781, 70, 1, 33, "Print"],
Cell[130787, 3784, 1515, 41, 40, "Print"],
Cell[132305, 3827, 1509, 41, 40, "Print"],
Cell[133817, 3870, 161, 3, 33, "Print"],
Cell[133981, 3875, 65, 1, 33, "Print"],
Cell[134049, 3878, 161, 3, 33, "Print"],
Cell[134213, 3883, 417, 7, 56, "Print"],
Cell[134633, 3892, 41, 1, 33, "Print"],
Cell[134677, 3895, 402, 8, 55, "Print"],
Cell[135082, 3905, 2793, 74, 230, "Print"],
Cell[137878, 3981, 1505, 41, 40, "Print"],
Cell[139386, 4024, 1509, 41, 40, "Print"],
Cell[140898, 4067, 70, 1, 33, "Print"],
Cell[140971, 4070, 3041, 84, 62, "Print"],
Cell[144015, 4156, 2654, 73, 40, "Print"],
Cell[146672, 4231, 161, 3, 33, "Print"],
Cell[146836, 4236, 65, 1, 33, "Print"],
Cell[146904, 4239, 161, 3, 33, "Print"],
Cell[147068, 4244, 495, 10, 79, "Print"],
Cell[147566, 4256, 41, 1, 33, "Print"],
Cell[147610, 4259, 340, 7, 33, "Print"],
Cell[147953, 4268, 3938, 106, 157, "Print"],
Cell[151894, 4376, 2052, 57, 40, "Print"],
Cell[153949, 4435, 2056, 57, 40, "Print"],
Cell[156008, 4494, 70, 1, 33, "Print"],
Cell[156081, 4497, 2660, 73, 40, "Print"],
Cell[158744, 4572, 2654, 73, 40, "Print"],
Cell[161401, 4647, 159, 3, 33, "Print"],
Cell[161563, 4652, 1789, 52, 46, "Output"]
}, Open  ]],
Cell[163367, 4707, 67, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[163459, 4711, 54, 1, 39, "Input"],
Cell[163516, 4714, 417, 7, 56, "Print"],
Cell[163936, 4723, 41, 1, 33, "Print"],
Cell[163980, 4726, 417, 7, 56, "Print"],
Cell[164400, 4735, 41, 1, 33, "Print"],
Cell[164444, 4738, 495, 10, 79, "Print"],
Cell[164942, 4750, 41, 1, 33, "Print"],
Cell[164986, 4753, 910, 26, 46, "Output"]
}, Open  ]],
Cell[165911, 4782, 62, 0, 46, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

