(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18552,        436]*)
(*NotebookOutlinePosition[     19233,        460]*)
(*  CellTagsIndexPosition[     19189,        456]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Der Gr\[ODoubleDot]bner-Walk", "Title",
  InitializationCell->True],

Cell["F\[UDoubleDot]r Ore Algebren, nach \"On the Walk\", ", "Subtitle",
  InitializationCell->True],

Cell[BoxData[
    \(\(Needs["\<OreAlgorithms`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BeginPackage["\<GroebnerWalk`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Sicherstellen der Funktionen aus dem Paket OreAlgorithms", \
"Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Needs["\<OreAlgorithms`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Ore`\>"];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Erstellungsdaten:", "Subsubsection"],

Cell[BoxData[
    \(\(\( (*\(\(**\)\(**\)\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\)**********) \)\(\[IndentingNewLine]\)\( (*\ 
      Implementation\ des\ Gr\[ODoubleDot]bner - 
        Walk\ mit\ dem\ Ore - \(\(Package\)\(.\)\)\ \ \ \ \ \ \ \ \ *) \)\(\
\[IndentingNewLine]\)\( (*\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \)\
\(\[IndentingNewLine]\)\( (*\ \(Grundfunktionen\ nach\ "\<On the Walk\>"\)\(,\
\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \)\(\
\[IndentingNewLine]\)\( (*\ B . \ Amrhein, \ O . \ Gloor, \ 
      W . \ K\[UDoubleDot]chlin . \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ *) \)\(\[IndentingNewLine]\)\( (*\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)***********) \)\(\
\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\( (*\ \
\(Done\)\(:\)\ *) \)\(\[IndentingNewLine]\)\( (*\ 
      01.09  .04 : \ 
        Entering\ \(\(debugging\)\(.\)\)\ ; \[IndentingNewLine]\ \ 24.08  .04 \
: \ InitGB, \ LiftUp, \ \(\(;\)\(\(\[IndentingNewLine]\)
      \(\ \ \)\(02.04  .04 : \ Frame\ for\ Groebner - Walk, \ 
      TakeInitials[G_List]; \[IndentingNewLine]\ \ 02.04  .04 : \ 
        SortOrePolynomials[
          G_List]; \[IndentingNewLine]\[IndentingNewLine]\ \
\(\(Todo\)\(:\)\)\)\)\)\ *) \)\(\[IndentingNewLine]\)\( (*\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ *) \)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Die ben\[ODoubleDot]tigten Grundfunktionen", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
RefinedOrder[w_,B_] erstellt aus einer gegebenen Ordnungsmatrix B \
zu einem gegebenen Gewichtsvektor die Matrix der Matrixordnung, 
die das gegebene Gewicht zu einer Monomordnung verfeinert. \
\>", \
"Subsubsection",
  InitializationCell->True],

Cell["\<\
Hierzu wird aus der rechteckigen Matrix, die sich durch \
voranstellen von w als erste Zeile ergibt, die erste m\[ODoubleDot]gliche \
Zeile von unten her gestrichen, so da\[SZ] eine nichtsingul\[ADoubleDot]re \
Matrix entsteht.
Im theoretischen Teil wird einfach eine n \[Cross] n+1 \[LongDash]Matrix \
verwendet. Die Implementation braucht aber eine quadratische, regul\
\[ADoubleDot]re Matrix.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[RefinedOrder];\)\), "\[IndentingNewLine]", 
    \(\(RefinedOrder[w_ /; Or @@ \((Thread[w != 0])\), B_ /; Det[B] =!= 0] := 
        Module[\[IndentingNewLine]{l, n, 
            Result}, \[IndentingNewLine]l = \(n = Length[B]\); \  (*\ 
            Number\ of\ Line\ to\ drop\ *) \[IndentingNewLine]Result = 
            Prepend[Drop[B, \(-1\)], w]; \ \[IndentingNewLine]While[\ 
            Det[Result] \[Equal] 0, \[IndentingNewLine]n = 
              n - 1; \ \[IndentingNewLine]Result = \
\[IndentingNewLine]Flatten[{{w}, Take[B, \((n - 1)\)], Drop[B, n]}, 
                1];\[IndentingNewLine]]; \[IndentingNewLine]Return[
            Result];\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SortOrePolynomials sortiert eine Liste von Orepolynomen der \
Monomordnung nach.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[SortOrePolynomials];\)\), "\[IndentingNewLine]", 
    \(\(SortOrePolynomials[G_List, verbosity_Integer:  0] := \ 
        Sort[G, #1 > #2 &];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TakeInitials[G_List] erzeugt aus einer Liste von Ore Polynomen die \
Liste der zugeh\[ODoubleDot]rigen Initialterme im Bezug auf die Aktuelle \
Monomordnung.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[TakeInitials];\)\), "\[IndentingNewLine]", 
    \(\(TakeInitials[G_List] := \[IndentingNewLine]Map[OreInitialTerm[#] &, 
          G];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
InitGB bestimmt die Gr\[ODoubleDot]bnerbasis der Initialformen \
einer gegebenen Menge von Ore Polynomen.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[InitGB];\)\), "\[IndentingNewLine]", 
    \(\(InitGB[G_List, 
          verbosity_Integer:  0] := \[IndentingNewLine]Module[{ifo, 
            rGB}, \[IndentingNewLine]InfoMessage[verbosity, 
            5, "\<Entering InitGB\>"]; \[IndentingNewLine]ifo = 
            TakeInitials[G]; \  (*\ 
            Get\ initial\ \(\(forms\)\(.\)\)\ \
*) \[IndentingNewLine]InfoMessage[verbosity, 4, "\<Initials:\>", \ 
            ifo]; \[IndentingNewLine]rGB = 
            OreLeftGroebner[ifo]; \[IndentingNewLine]InfoMessage[verbosity, 
            4, "\<their Gr\[ODoubleDot]bnerbase:\n\>", 
            rGB]; \[IndentingNewLine]rGB\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Interreduce: (zwischen-) Reduktion einer gegebenen \
Gr\[ODoubleDot]bnerbasis.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[Interreduce];\)\), "\[IndentingNewLine]", 
    \(\(Interreduce[G_List, v_:  0] := 
        OreReduceGroebnerBasis[G, v];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Liftup[Gw,G,{order}] Liftet die Elemente aus Gw \
bz\[UDoubleDot]glich einer (zur Matrixordnung {order}) reduzierten Gr\
\[ODoubleDot]bnerbasis G.\
\>", "Subsubsection",
  InitializationCell->True],

Cell["\<\
Hierzu wird bez\[UDoubleDot]glich der Ordnung \"order\" eine \
Division mit Rest berechnet. Dieser Rest ist dann zu subtrahieren, um ein \
Idealelement mit dem gleichen Leitterm zu erhalten.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[LiftUp];\)\), "\[IndentingNewLine]", 
    \(\(LiftUp[Gw_List, G_List, {order__}, 
          verbosity_Integer:  0] := \[IndentingNewLine]Module[{oldorder, 
            ret}, \[IndentingNewLine]InfoMessage[verbosity, 
            3, "\<Entering LiftUp:\>"]; \[IndentingNewLine]oldorder = 
            OreOrderData[]; \[IndentingNewLine]OreRedefineMonomOrder[
            order]; \[IndentingNewLine]ret = 
            Map[# - \(OreDivision[#, OreSimplify /@ G]\)[\([1]\)] &, 
              OreSimplify /@ Gw]; \[IndentingNewLine]OreRedefineMonomOrder[
            oldorder]; \[IndentingNewLine]ret = 
            OreSimplify /@ ret\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["NextDegeneration[G,v] ist eine Funktion aus dem Package Ore.", \
"Subsubsection",
  InitializationCell->True],

Cell["\<\
Diese Funktion bestimmt den Punkt w auf der Geraden von der \
Leitform der aktuellen Monomordnung zum Zielgewicht v, an dem  erstmals neue \
Monome in den Initialpolynomen eines Ore-Polynomes g\[Element]G auftauchen. \
Wegen zugriff auf Interna zugreift, ist dies in Ore.m realisiert.\
\>", "Text",\

  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DoTheWalk [G,DestOrder]  Gr\[ODoubleDot]bner-Walk zur Zielordnung \
DestOrder ausf\[UDoubleDot]hren. 
Achtung: Nach erfolgreicher Ausf\[UDoubleDot]hrung ist die Zielordnung die \
aktuelle!\
\>", "Subsubsection"],

Cell["\<\
G mu\[SZ] eine reduzierte Gr\[ODoubleDot]bnerbasis \
bez\[UDoubleDot]glich der aktuellen Ordnung sein. 
Defaultm\[ADoubleDot]\[SZ]ig wird getestet, ob der letzte Schritt erfolgreich \
war, verbosity=-1 schaltet dies ab. Da der Walk nicht immer zum Ziel f\
\[UDoubleDot]hrt, ist das nur zu empfehlen, wenn man sich sicher ist.\
\>", \
"Text"],

Cell[BoxData[{\(Clear[DoTheWalk];\), "\[IndentingNewLine]", 
    RowBox[{\(DoTheWalk::"\<B singular\>" = "\<Singular destination order \
matrix `1`.\>";\), "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(DoTheWalk[G_List, DestOrder_ /; MatrixQ[DestOrder], \ 
          verbosity_Integer:  0, maxsteps_:  Infinity]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({aO, \  (*\ 
                aO : \ Actual\ Ordermatrix\ \(\(here\)\(.\)\)\ \
*) \[IndentingNewLine]GG,  (*\ 
                The\ actual\ Basis\ on\ the\ \(\(walk\)\(.\)\)\ \
*) \[IndentingNewLine]Gw,  (*\ 
                The\ initalforms\ of\ the\ Elements\ of\ \(\(GG\)\(.\)\)\ \
*) \[IndentingNewLine]Gwp\ ,  (*\ 
                Sorted\ Gw\ /\ 
                    new\ \(\(gr\[ODoubleDot]bnerbase\)\(.\)\)\ \
*) \[IndentingNewLine]vars, \  (*\ 
                Current\ variable\ \(\(list\)\(.\)\)\ \
*) \[IndentingNewLine]A, \  (*\ \(Startorder\)\(.\)\ *) \[IndentingNewLine]B \
= DestOrder, \  (*\ 
                Destination\ \(\(order\)\(.\)\)\ *) \[IndentingNewLine]v, \  \
(*\ The\ initialform\ of\ the\ \(\(destinationorder\)\(.\)\)\ \
*) \[IndentingNewLine]w, \  (*\ 
                Initialform\ of\ actual\ order\ on\ the\ \(\(walk\)\(.\)\)\ \
*) \[IndentingNewLine]t, \  (*\ 
                ratio\ from\ the\ last\ weight\ to\ the\ \(\(destination\)\(.\
\)\)\ *) \[IndentingNewLine]Ordervectors, \  (*\ 
                The\ vectors\ according\ to\ all\ \(\(monomials\)\(.\)\)\ \
*) \[IndentingNewLine]step = 0\  (*\ 
                actual\ step\ of\ the\ \(\(Walk\)\(.\)\)\ \
*) \[IndentingNewLine]}\), ",", " ", "\[IndentingNewLine]", 
            RowBox[{"Catch", "[", "\[IndentingNewLine]", 
              
              RowBox[{\(If[Det[B] \[Equal] 0, 
                  Message[DoTheWalk::"\<B singlular\>", B]; Abort[]\ ]\), ";",
                 "\[IndentingNewLine]", \(InfoMessage[verbosity, 
                  3, "\<Entering DoTheWalk:\>", G, DestOrder]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ 1. \ Initialisation\ *) \), 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \({vars, \ A} = {OreOrderData[]}\), 
                ";", "\[IndentingNewLine]", \(w = First[A]\), 
                ";", \(v = First[B]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(GG = G\), 
                ";", \( (*\ 
                  Start\ with\ the\ given\ \(\(gr\[ODoubleDot]bnerbase\)\(.\)\
\)\ *) \), 
                StyleBox["\[IndentingNewLine]",
                  FontColor->GrayLevel[0.500008]], \(InfoMessage[verbosity, 
                  3, "\<Initialized: v,w,g=\>", v, w, GG]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(While[
                  True, \  (*\ main\ loop\ *) \[IndentingNewLine]InfoMessage[
                    verbosity, 0, 
                    Print["\<Check, whether actual GG is still a Gr\
\[ODoubleDot]bner base: Current matrix is:\>", OreCurrentMatrix]; 
                    If[OreIsLeftGroebner[GG], "\<It is.\>", \ 
                      Print["\<No! Exit.\>"]; \ 
                      OreRedefineMonomOrder[vars, \ A]; 
                      Throw[{"\<Walk Failed!\>", 
                          GG}]]]; \[IndentingNewLine]\[IndentingNewLine]step \
= step + 1; \[IndentingNewLine]\[IndentingNewLine]lastorder = 
                    OreOrderData[];  (*\ 
                    remember\ last\ order\ *) \[IndentingNewLine]aO = \ 
                    RefinedOrder[w, B];  (*\ 
                    Next\ \(\(Order\)\(:\)\)\ \
*) \[IndentingNewLine]OreRedefineMonomOrder[vars, \ aO]; \  (*\ 
                    Setting\ the\ new\ \(\(Order\)\(.\)\)\ \
*) \[IndentingNewLine]InfoMessage[verbosity, 1, "\<New order matrix is:\>", 
                    OreCurrentMatrix, "\<.\>"]; \[IndentingNewLine]GG = \
\((OreSimplify /@ GG)\); \  (*\ 
                    Re - sort\ the\ \(\(Objects\)\(.\)\)\ \
*) \[IndentingNewLine]\[IndentingNewLine]InfoMessage[verbosity, 
                    2, "\<last order: \>", {lastorder}[\([2]\)] // 
                      MatrixForm, \ "\<actual order: \>", \ 
                    OreCurrentMatrix // MatrixForm, \ "\<Gb now: \>", 
                    GG]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    2. \ \ get\ the\ \(\(initialpolynomials\)\(:\)\)\ \
*) \[IndentingNewLine]Gw = TakeInitials[GG]; \[IndentingNewLine]InfoMessage[
                    verbosity, 2, "\<Step 2, Initial forms:\>", 
                    Gw]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    3. \ \ sort\ according\ to\ new\ \(\(order\)\(.\)\)\ \
*) \[IndentingNewLine]\[IndentingNewLine]Gwp = 
                    SortOrePolynomials[Gw]; \[IndentingNewLine]InfoMessage[
                    verbosity, 2, "\<Step 3: Sorted, now Gwp=\>", 
                    Gwp]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    4. \ \ Calculate\ \(\(Groebnerbasis\)\(.\)\)\ \
*) \[IndentingNewLine]\[IndentingNewLine]InfoMessage[verbosity, 
                    2, "\<Step 4: Calculating GB of initials:\>"]; \
\[IndentingNewLine]Gwp = 
                    InitGB[Gwp, verbosity]; \[IndentingNewLine]InfoMessage[
                    verbosity, 3, "\<It is:\>", 
                    Gwp]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    Interreduction\ leads\ here\ to\ failures; \
\[IndentingNewLine] (*\ 
                      5. \ \ \(\(interreduction\)\(.\)\)\ \
*) \[IndentingNewLine]Gwp = 
                      Interreduce[
                        Gwp];\[IndentingNewLine]*) \[IndentingNewLine]\
\[IndentingNewLine] (*\ 
                    6. \ \ Lift\ to\ a\ \(\(gr\[ODoubleDot]bnerbasis\)\(.\)\)\
\ *) \[IndentingNewLine]GG = 
                    LiftUp[Gwp, GG, \ {lastorder}, \ 
                      verbosity]; \[IndentingNewLine]InfoMessage[verbosity, 
                    2, "\<Step 6: Gwp now lifted: GG=\>", 
                    GG]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    7. \ \ \(\(interreduction\)\(.\)\)\ \
*) \[IndentingNewLine]GG = Interreduce[GG]; \[IndentingNewLine]InfoMessage[
                    verbosity, 2, "\<Step 7: Gwp reduced: GG=\>", 
                    GG]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    8. \ \ are\ we\ \(\(ready\)\(?\)\)\ \
*) \[IndentingNewLine]InfoMessage[verbosity, 2, "\<Step 8: Ready? \>", 
                    w === v]; \[IndentingNewLine]If[w === v, \ 
                    Return[GG]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    9. \ \ search\ new\ \(\(border\)\(.\)\)\ \
*) \[IndentingNewLine] (*Ordervectors = \ 
                      TakeVectors[GG]; \[IndentingNewLine]InfoMessage[
                      verbosity, 3, "\<Step 9. GG, Ordervectors:\>", 
                      GG, "\< : \>", 
                      Ordervectors];*) \[IndentingNewLine]\[IndentingNewLine]{\
w, t} = NextDegeneration[GG, 
                      v]; \[IndentingNewLine]\[IndentingNewLine]InfoMessage[
                    verbosity, 
                    2, "\<Step 9: New weight determined.\>"]; \
\[IndentingNewLine]InfoMessage[verbosity, 3, "\<t=\>", t, "\< weight=\>", 
                    w]; \[IndentingNewLine]If[t == 2, \ 
                    Return[GG]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                    
                    10. \ prepare\ next\ \(\(iteration\)\(.\)\)\
*) \[IndentingNewLine] (*\ \(w = \ \((1 - t)\) w + 
                          t\ v;\)\ *) \[IndentingNewLine]InfoMessage[
                    verbosity, 3, "\<Next weight vector: w=\>", 
                    w]; \[IndentingNewLine]If[step >= maxsteps, \ 
                    Return[]]; \[IndentingNewLine]InfoMessage[verbosity, 
                    2, "\<Entering iteration \>", 
                    step + 1];\[IndentingNewLine]]\), ";"}], 
              " ", \( (*\ While\ *) \), "\[IndentingNewLine]", "]"}]}], 
          "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EndPackage[];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
AutoGeneratedPackage->Automatic,
WindowSize->{922, 770},
WindowMargins->{{22, Automatic}, {Automatic, 0}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 73, 1, 146, "Title",
  InitializationCell->True],
Cell[1852, 56, 100, 1, 81, "Subtitle",
  InitializationCell->True],
Cell[1955, 59, 93, 2, 39, "Input",
  InitializationCell->True],
Cell[2051, 63, 99, 2, 39, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2175, 69, 111, 2, 39, "Subsubsection",
  InitializationCell->True],
Cell[2289, 73, 151, 3, 62, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2477, 81, 42, 0, 39, "Subsubsection"],
Cell[2522, 83, 1747, 26, 384, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4306, 114, 92, 1, 60, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4423, 119, 255, 6, 81, "Subsubsection",
  InitializationCell->True],
Cell[4681, 127, 447, 9, 121, "Text",
  InitializationCell->True],
Cell[5131, 138, 743, 12, 315, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[5911, 155, 141, 4, 39, "Subsubsection",
  InitializationCell->True],
Cell[6055, 161, 214, 4, 85, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6306, 170, 218, 5, 60, "Subsubsection",
  InitializationCell->True],
Cell[6527, 177, 207, 4, 85, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6771, 186, 166, 4, 39, "Subsubsection",
  InitializationCell->True],
Cell[6940, 192, 721, 13, 246, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[7698, 210, 139, 4, 39, "Subsubsection",
  InitializationCell->True],
Cell[7840, 216, 193, 4, 62, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[8070, 225, 207, 5, 60, "Subsubsection",
  InitializationCell->True],
Cell[8280, 232, 242, 5, 71, "Text",
  InitializationCell->True],
Cell[8525, 239, 723, 12, 269, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[9285, 256, 115, 2, 39, "Subsubsection",
  InitializationCell->True],
Cell[9403, 260, 338, 7, 96, "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[9778, 272, 221, 5, 60, "Subsubsection"],
Cell[10002, 279, 351, 7, 96, "Text"],
Cell[10356, 288, 8075, 139, 2385, "Input",
  InitializationCell->True],
Cell[18434, 429, 78, 2, 39, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

