(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     45917,       1118]*)
(*NotebookOutlinePosition[     46903,       1149]*)
(*  CellTagsIndexPosition[     46859,       1145]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[" \"Algorithmen auf Ore-Algebren\" ", "Title",
  InitializationCell->True],

Cell["\<\
Algorithmen auf Ore-Algebren \[UDoubleDot]ber \
\[DoubleStruckCapitalQ].\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell["Historie:", "Subsubsection",
  InitializationCell->True],

Cell["\<\
19.09.01: ... 06.03.02:see versions 00.*
05.04.04: some cosmetics on verbosity level 3.
07.04.04: Implemented OreReduceGroebnerBasis.
24.12.04: changed:OreLeadingMonomial\[Rule]OreLeadingOperatorMonomial,
24.12.04: changed:OreLeadingMonomial\[Rule]OreLeadingOperatorMonomial,
02.03.05: OreLeftGr\[ODoubleDot]bnerBase:fixed missbehaviour due to not \
sorting S-pols.
25.04.05: Implemented OreIsLeftGroebner.
15.05.05: fixed an unbelievable  bug in OreDivison.
16.05.05: fixed similary bug in OreReduceGroebnerBasis. reduction may not be \
done simultanously!
16.05.05:Added extended groebnerbase functions.
mar/jun 05: Implemented extended versions of GB-Algorithms, fixed further \
bugs.
                      Formatted the source into a more readable form.
 jan 06   : Removed extended ore Division (not needed). \
\>", "Text",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["N\[ODoubleDot]tige Einbindungen und Start des Paketkontxtes:", \
"Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(BeginPackage["\<OreAlgorithms`\>", "\<Ore`\>"];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Deklarationen", "Section"],

Cell["\<\
Hier werden die implementierten Funktionen dem aufrufenden Kontext \
zug\[ADoubleDot]nglich gemacht, zugleich wird eine Hilfestellung \
implementiert.\
\>", "Text"],

Cell[BoxData[
    \(\(OreAlgebrasVersion::usage = "\<OreAlgebrasVersion returns the package \
version.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BaseGenerators::usage = "\<This is an option for extended gr\
\[ODoubleDot]bnerbase manipulations. The option BaseGenerators->G is needed \
for functions to check whether the generated coefficients are \
correct.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InfoMessage::usage\  = \ \
"\<InfoMessage[verboselevel_Integer,priority_Integer,__] prints all data \
after the first two arguments if priority is not less than the \
verboselevel.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreCheckExtended::usage = "\<OreCheckExtended[r_,G_] looks, whether \
the extended orepolynomial r={p,lp} statisfies the condition that the List lp \
of OrePolynomials generates r in the form \
p=lp[[1]]*G[[1]]+...+lp[[g]]*G[[g]], with g = |G|.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDivision::usage = "\<OreDivision[a_OrePolynomial, g_List] performs \
the division algorithm for dividing a by multiple polynomials. It determines \
a representation r=a+a1*g1+a2*g2+...+al*gl, where deg r < deg gi for all i. \
It returns {r, {a1, a2, ... al}} 
\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDivisionExtended::usage = \
\[IndentingNewLine]"\<OreDivisionExtended[p_,L_List,vl_Integer:0,Options_:{}] \
performs the Ore(Extended)Division of exteded Polynomials, keeping track of \
the coefficients and returning as result the extended result, i.e. {r,L} with \
the result r and a List L of Coefficients presenting r with Respect to a \
given Base. For higher verbosity levels the reference base G has to be given \
as option BaseGenerators\[Rule]<Referencebase>\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExtendedLeftGroebnerLimited::usage = \
\[IndentingNewLine]"\<OreExtendedLeftGroebnerLimited[l_List,LengthLimit_\
Integer, vl_Integer:0]: Generates a left groebnerbase of l={g1, ..., gn}, \
where for every element gj of the groebnerbase a list of coefficients lj={c1, \
.. cn} with g=c1 g1+ ... + cn gn is created. Returns: {{g1,l1},...{gm, lm}}. \
Of course this is much slower than the pure groebnerbase \
calculation.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExtendedNormalForm::usage = "\<OreExtendedNormalForm[f_,P_] \
calculates the normalform of an extended f-polynomial (i.e. a list consisting \
of an ore polynomial together with the coefficients of the representation \
with respect of a set of ore polynomials) based on a set P of estended ore \
polynomials.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExtendedSPoly::usage = \
"\<OreExtendedSPoly[{p_OrePolynomial,lp_List},{q_OrePolynomial,lq_List}] \
calculates the S-polynomial of p and q and a representation l from the \
polynomials p,q and their representations lp and lq.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreGCD::usage = "\<OreGCD[a_OrePolynomial, b_OrePolynomial]\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreIsLeftGroebner::usage = "\<OreIsLeftGroebner[l_List,vl_Integer:0]: \
Test whether the list l is a groebnerbase (looks whether every S-polynom \
reduces to zero). If vl>0 occures, entering the procedure is mentioned.\>";\)\
\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLeftGroebner::usage\  = \ "\<OreLeftGroebner[l_List, \
verboselevel_Integer:0] finds for a given list of Ore-polynomials a left \
groebnerbase with respect to the actual termorder and returns this base as a \
list of Ore-polynomials. The 'verboselevel' determins the amount of \
information given while the procedure is advancing, to avoid boredom; the \
higher this number, the more information will be printed about the \
progress.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLeftGroebnerLimited::usage\  = \ \
\[IndentingNewLine]"\<OreLeftGroebner[l_List, MaxElements_Integer, \
verboselevel_Integer:0] finds for a given list of Ore-Polynomials a left \
groebnerbase with respect to the actual termorder and returns this base as a \
List of Ore-polynomials or the first MaxElements it found, when the algorithm \
didn't stop until then. The 'verboselevel' determins the amount of \
information given while the procedure is advancing, avoiding boredom; the \
higher this number, the more information will be printed about the \
progress.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMonomialLCM::usage\  = \ \
"\<OreMonomialLCM[a_OreMonomial,b_OreMonomial] returns the least common \
multiple of the oremonomials a,b\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreNormalForm::usage = "\<OreNormalForm[f_OrePolynomial,P_List]:Gives \
back the normal form of the polynomial with respect to the given list of ore \
polynomials and the actual order. This ist a truncated version of the \
division algorithm only regarding the division rest.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrePartDivision::usage = "\< \
OrePartDivision[a_OrePolynomial,g_OrePolynomial] divides out the leading term \
of g at the first possible position of a. It returns the result in the form \
{r, a',g'}, where r = a'*a + g'*g, deg(a')=0 .\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreRandomPolynomial::usage = \
\[IndentingNewLine]"\<OreRandomPolynomial[D_OrePolynomial,k?integer:5, \
range_List:{-8,8}] creates a random OrePolynomial  of degree k with integer \
coefficients in a given range.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreReduceExtendedGroebnerBasis::usage = \
\[IndentingNewLine]"\<OreReduceExtendedGroebnerBasis[G_List, \
vl_Integer:0,Options_:{}] performs the operation of reducing an extended \
groebnerbase G while keeping track of of the given presentations - for higher \
verbosity-levels vl the referred-to basis has to be given as the option \
BaseGenerators\[Rule]<Referencebase>. \>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreReduceGroebnerBasis::usage = "\<OreReduceGroebnerBasis[G_List, \
vl_Integer:0] returns the reduced Groebnerbasis. The optional parameter vl, \
if greater than 0, gives the verbosity-level for debugging.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(OreReducePolynomial::usage = \
"\<OreReducePolynomial[s_OrePolynomial,B_List] reduces a polynomial according \
to a given set of ore polynomials.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreTopReduce::usage = "\< \
OreTopReduce[a_OrePolynomial,g_OrePolynomial] executes the top-reduction of a \
with respect to g.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreTopReducibleQ::usage = \
"\<OreTopReducibleQ[a_OrePolynomial,g_OrePolynomial] tests if the leading \
monomial of a is divided by the one of g. in this case a is top reducible \
with respect to g.\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementationen", "Section"],

Cell[BoxData[
    \(\(\(Begin["\<`Private`\>"];\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreAlgebrasVersion = "\<Version 2.6, jan 2006\>";\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Kontrollausgaben und Testfunktionen", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Bedingte Ausgabe, wird nur ausgewertet, wenn die \"Gespr\
\[ADoubleDot]chigkeit\" hoch genug ist.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(InfoMessage[verboselevel_Integer, priority_Integer, 
          MessageText__] := \[IndentingNewLine]If[
          verboselevel \[GreaterEqual] \ priority, 
          Print[MessageText]];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[InfoMessage, HoldRest];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Erzeugen eines zuf\[ADoubleDot]lligen Ore Polynomes.", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreRandomPolynomial[a_OrePolynomial, k_Integer:  5, \ 
          range_List: {\(-8\), 8}]\  := \[IndentingNewLine]OPo[
            Random[Integer, range]] + \[IndentingNewLine]Sum[
            OMu[OPo[Random[Integer, range]], a^i], {i, 1, k}];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Teiler, Vielfache und S-Polynom.", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "MonomialLCM",
  StyleBox[" (optimierbar)",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection",
  InitializationCell->True],

Cell["\<\
MonomialLCM bestimmt den kommutativen kleinsten gemeinsamen \
Vielfachen von zwei Monomen.\
\>", "Text"],

Cell[BoxData[
    \(\(OreMonomialLCM[a_OreMonomial, b_OreMonomial] := \  (*\ 
          Das\ ' S - 
            Polynom'\ Fuer\ Monome\ *) \[IndentingNewLine]Module[{L}, \
\[IndentingNewLine]L = 
            Split[Sort[Join[List @@ a, List @@ b]], 
              First[#1] \[Equal] First[#2] &]; \  (*\ 
            Liste\ der\ ' \(\(Runs'\)\(.\)\)\ *) \[IndentingNewLine]L = 
            Map[\  (*\ 
                Maxima\ der\ auftauchenden\ Potenzen\ \(\(bilden\)\(.\)\)\ \
*) \[IndentingNewLine]If[
                  Length[#] \[Equal] 
                    2, \[IndentingNewLine]{\(#[\([1]\)]\)[\([1]\)], \ 
                    Max[\(#[\([1]\)]\)[\([2]\)], \(#[\([2]\)]\)[\([2]\)]]}, \ \
 (*\ else\ *) \[IndentingNewLine]#[\([1]\)]\[IndentingNewLine]] &, \
\[IndentingNewLine]L\[IndentingNewLine]]; \  (*\ 
            Map\ *) \ \[IndentingNewLine]OreMonomial @@ L\  (*\ 
            Als\ OreMonomial\ \(\(zurueckgeben\)\(.\)\)\ \
*) \[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reduktion des Leittermes modulo einem Polynom", "Subsubsection",
  InitializationCell->True],

Cell["\<\
 TopReducibleQ testet, ob das Leitmonom von g in dem von a aufgeht.\
\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreTopReducibleQ[a_OrePolynomial, 
          g_OrePolynomial] := \[IndentingNewLine]And @@ 
          Thread[SummandToVector[First[a]] \[GreaterEqual] 
              SummandToVector[First[g]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "OreTopReduce f\[UDoubleDot]hrt, wenn m\[ODoubleDot]glich die Reduktion des \
Leitmonomes durch. Dies ist ",
  StyleBox["im ordnungserhaltenden Fall",
    FontColor->RGBColor[1, 0, 0]],
  " gerade das S-Polynom! "
}], "Text"],

Cell[BoxData[
    \(\(OreTopReduce[a_OrePolynomial, 
          g_OrePolynomial] := \[IndentingNewLine]If[OreTopReducibleQ[a, g], 
          OreSPoly[a, g], a];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Die Memory-Version von TopReduce gibt eine Liste aus der Reduktion \
und dem Faktor, mit dem das zu reduzierende Polynom multipliziert wurde zur\
\[UDoubleDot]ck.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreTopReduceMemory[a_OrePolynomial, 
          g_OrePolynomial] := \[IndentingNewLine]If[
          OreTopReducibleQ[a, 
            g], \(OreExtendedSPolynomial[a, g]\)[\([{1, 2}]\)], {a, 
            OreOne}];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["OrePartDivision: ", "Subsubsection"],

Cell["\<\
Einmalige Reduktion des gr\[ODoubleDot]\[SZ]tm\[ODoubleDot]glichen \
Termes,
R\[UDoubleDot]ckgabe einer Liste {r, a',g'}, mit  r = a' a + g' g, deg(a')=0 
wobei g'=0 genau wenn a nicht g-reduzierbar ist.
Dabei wird bis eine Reduktion m\[ODoubleDot]glich ist, oder das Polynom zu \
klein wird sukzessive der Leitterm entfernt.\
\>", "Text"],

Cell[BoxData[
    \(\(OrePartDivision[a_OrePolynomial, g_OrePolynomial, 
          DebugLevel_:  0] := \[IndentingNewLine]Module[{aa = a, l, Ra, 
            Rg}, \[IndentingNewLine]InfoMessage[DebugLevel, 3, "\<PD: a=\>", 
            a, "\< g=\>", \ 
            g]; \ \[IndentingNewLine]While[\(! \((aa < 
                  g)\)\), \[IndentingNewLine]\(If[
                OreTopReducibleQ[aa, g], \ \[IndentingNewLine]{l, Ra, Rg} = 
                  OreExtendedSPolynomial[aa, 
                    g]; \[IndentingNewLine]Return[{OMu[Ra, a] + OMu[Rg, g], 
                    Ra, Rg}]\  (*\ 
                  erstmoegliches\ Monom\ eliminieren\ *) \[IndentingNewLine], \
\  (*\ else\ *) \[IndentingNewLine]\(aa = OreLesserTerms[aa];\)\  (*\ 
                  Rest\ von\ a\ betrachten\  ... \ *) \[IndentingNewLine], \  \
(*\ Weiss\ nicht\ *) \[IndentingNewLine]\(Print["\<Strange error in \
OrePartDivision[a_OrePolynomial,g_OrePolynomial]\>"];\)\[IndentingNewLine]];\)\
\[IndentingNewLine]]; \[IndentingNewLine]Return[{a, OPo[1], \ OPo[0]}]\  (*\ 
            No\ Division\ at\ \(\(all\)\(.\)\)\ \
*) \[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreDivision: Divisionsalghorithmus auf Listen von \
OrePolynomen.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[TextData[{
  "Eingabe: ein Ore Polynom a, eine Liste g von (l) Ore Polynomen. \nAusgabe: \
{r, {a1, a2, ... al}} mit r=a+a1*g1+a2*g2+...+al*gl und  r nicht reduzierbar \
modulo gi f\[UDoubleDot]r alle i. Im ordnungserhaltenden Fall",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]],
  "ist stets deg(ai gi) <= deg a.\nVorgehen: \nAusgehend von \
a=0+0*g1+0*g2+...+0*gl wird partiell der linke Ausdruck r in \n \
r=a+a1*g1+a2*g2+...+al*gl durch ein gi dividiert, \n und damit der \
Koeffizient ai und r so abge\[ADoubleDot]ndert, da\[SZ] die Gleichung \
erhalten bleibt. \n Dies wird durchgef\[UDoubleDot]hrt, bis keine weitere \
Reduktion mehr m\[ODoubleDot]glich ist. "
}], "Text"],

Cell[BoxData[
    \(\(OreDivision[a_OrePolynomial, \ g_List, \ 
          DebugLevel_:  
            0] := \[IndentingNewLine]Module[\[IndentingNewLine]{rr = 
              a, \  (*\ Rest, \ 
              zunaechst\ gleich\ \(\(a\)\(.\)\)\ *) \[IndentingNewLine]cc = 
              Map[OPo[0] &, g], \  (*\ Koeffizientenliste, \ 
              zunaechst\ alle\ 0\ *) \[IndentingNewLine]i, \ 
            fertig = False, \[IndentingNewLine]ll = OPo[1], \ llneu, \ 
            rrneu, \ restneu}, \[IndentingNewLine]InfoMessage[DebugLevel, 
            3, "\<ODiv: p = \>", p, "\< g = \>", 
            g]; \[IndentingNewLine]While[\(! fertig\), \
\[IndentingNewLine]fertig = True; \  (*\ 
              Noch\ keinen\ Kandidaten\ zur\ Reduktion\ \(\(gefunden\)\(.\)\)\
\ *) \[IndentingNewLine]For[i = 1, \ 
              i \[LessEqual] Length[g], \  (*\ 
                Alle\ Dividenden\ in\ Reihenfolge\ \(\(durchtesten\)\(.\)\)\ \
*) \[IndentingNewLine]InfoMessage[DebugLevel, 2, "\<Partdiv of \>", 
                rr, "\< by \>", g[\([i]\)], "\<= \>", 
                OrePartDivision[rr, 
                  g[\([i]\)]]]; \[IndentingNewLine]{restneu, llneu, rrneu} = 
                OrePartDivision[rr, g[\([i]\)], 
                  DebugLevel]; \[IndentingNewLine]InfoMessage[DebugLevel, 
                3, "\<ODiv: i = \>", 
                i, "\< OrePartDivision[rr,g[[i]]] = \>", {restneu, llneu, 
                  rrneu}]; \[IndentingNewLine]If[\((rrneu === 
                      OPo[0])\) || \((\(! OreIsUnitQ[
                        llneu]\))\), \ \[IndentingNewLine]\(i++\); \ 
                Continue[], \  (*\ \(war\ nix\  ... \)\ else\ \
*) \[IndentingNewLine]fertig = False; \  (*\ 
                  Eine\ Reduktion\ \(gefunden!\)\ *) \[IndentingNewLine]rr = 
                  restneu; \ \[IndentingNewLine]ll = OMu[llneu, ll]; \  (*\ 
                  Den\ Vorfaktor\ zum\ bisherigen\ aufmultiplizieren\ \
*) \[IndentingNewLine]InfoMessage[DebugLevel, 1, "\<i = \>", 
                  i, "\< llneu = \>", llneu]; \[IndentingNewLine]cc = 
                  Map[OMu[llneu, #] &, cc]; \  (*\ 
                  sowie\ auf\ die\ bisherigen\ \(\(Koeffizienten\)\(.\)\)\ \
*) \[IndentingNewLine]cc[\([i]\)] = cc[\([i]\)] + rrneu; \  (*\ 
                  und\ den\ momentanen\ Koeffizienten\ aktualisieren\ \
*) \[IndentingNewLine]InfoMessage[DebugLevel, 3, "\<Status: r= \>", 
                  rr, "\< = \>", "\<(\>", ll, "\<)*\>", \ a\ , "\< + \>", \ 
                  cc, "\<.\>", 
                  g]; \[IndentingNewLine]Break[];\[IndentingNewLine]]; \  (*\ 
                If\ *) \[IndentingNewLine]]; \[IndentingNewLine]InfoMessage[
              DebugLevel, 3, "\<r=\>", rr, "\<=\>", ll, "\<*(\>", 
              a, "\<) + \>", g, "\<.\>", 
              cc];\[IndentingNewLine]]; \[IndentingNewLine]ll = 
            OreInverse[
              ll]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
            Die\ Einheit\ ll\ invertieren\  ... \ *) \[IndentingNewLine]{OMu[
              ll, rr], \(OMu[ll, #] &\) /@ cc}\ \  (*\ 
            Und\ die\ gesuchte\ Darstellung\ \(\(bestimmen\)\(.\)\)\ \
*) \[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreReducePolynomial: Reduktion eines Elementes \
bez\[UDoubleDot]glich einer Basis.\
\>", "Subsubsection"],

Cell[" Dies ist einfach der Rest der Division:", "Text"],

Cell[BoxData[
    \(\(OreReducePolynomial[s_OrePolynomial, B_List] := 
        First[OreDivision[s, B]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gr\[ODoubleDot]bnerbasis bestimmen", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
OreNormalForm: Normalform bez\[UDoubleDot]glich einer Menge von \
Polynomen bilden.\
\>", "Subsubsection"],

Cell["\<\
Dies ist eine abgespeckte Version des Divisionsalgorithmus.
Wieder wird das gegebene Polynom reduziert, bis keine weitere Reduktion
bez\[UDoubleDot]glich eines der Polynome aus der \[UDoubleDot]bergebenen \
Liste mehr m\[ODoubleDot]glich ist.
Da die Normalformbestimmung zeitkritisch sein kann, wurde sie eigenst\
\[ADoubleDot]ndig implementiert, gespart ist das Mitf\[UDoubleDot]hren der \
Koeffizienten. Im Laufe der Berechnung werden die Divisionskandidaten deren \
Grad bereits zu hoch f\[UDoubleDot]r das anstehende Monom ist entfernt.
Hier geht die Eigenschaft ordnungserhaltend zu sein ein!\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[OreNormalForm];\)\), "\[IndentingNewLine]", 
    \(\(OreNormalForm[f_OrePolynomial, P_List] := 
        Module[\[IndentingNewLine]{R, 
            Rfact, \[IndentingNewLine]ff = f, \[IndentingNewLine]PP, \ 
            i}, \[IndentingNewLine]R = OreZero; \[IndentingNewLine]PP = 
            Select[P, \(! \((f < #)\)\) &]; \  (*\ 
            Zu\ gro\[SZ]e\ Terme\ scheiden\ gleich\ \(aus!\)\
*) \[IndentingNewLine]PP = Sort[PP, #1 < #2 &]; \[IndentingNewLine]While[
            ff =!= \ OreZero\  && \ PP =!= {}, \[IndentingNewLine]i = 
              1; \[IndentingNewLine]While[
              i \[LessEqual] 
                  Length[PP] && \(! \((OreTopReducibleQ[ff, 
                      PP[\([i]\)]])\)\), \(i++\)]; \[IndentingNewLine]If[
              i <= Length[PP], \ \[IndentingNewLine]{ff, Rfact} = 
                OreTopReduceMemory[ff, PP[\([i]\)]]; \[IndentingNewLine]R = 
                OMu[Rfact, R];\[IndentingNewLine], \[IndentingNewLine]R = 
                R + OreLeadingSummand[ff]; \ \[IndentingNewLine]ff = 
                OreLesserTerms[
                  ff];\[IndentingNewLine]]; \[IndentingNewLine]PP = 
              Select[PP, \(! \((ff < #)\)\) &]; \  (*\ 
              Zu\ gro\[SZ]e\ Terme\ scheiden\ \
\(aus!\)*) \[IndentingNewLine]];  (*While*) \[IndentingNewLine]R + 
            ff\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["OreIsLeftGroebner:  Test, ob eine Gr\[ODoubleDot]bnerbasis vorliegt.", \
"Subsubsection"],

Cell[TextData[{
  "Testet Buchbergers Bedingung, da\[SZ] alle S-Polynome zu null reduziert \
werden.\nDabei wird mittels Hold die zeitkritische Rechnung aufgeschoben und \
erst im AND ausgef\[UDoubleDot]hrt, damit die lazy evaluation der AND \
Anweisung in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " zum Tragen kommt."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[OreIsLeftGroebner];\)\), "\n", 
    \(\(OreIsLeftGroebner[G_List, vl_Integer:  0] := 
        Module[{B, IArr, h, h0, NumberOfElements = Length[l], Hforms}, 
          InfoMessage[vl, 3, "\<Start of OreIsLeftGroebner, arguments:\>", 
            G, "\<, \>", LengthLimit, "\<, \>"\ vl]; \[IndentingNewLine]B = 
            Table[Table[OreSPoly[G[\([i]\)], G[\([j]\)]], {i, 1, j - 1}], {j, 
                2, Length[G]}]; \[IndentingNewLine]Hforms = \(Hold[
                  OreNormalForm[#, G] === OreZero] &\) /@ 
              Flatten[B]; \[IndentingNewLine]Return[
            Release[And @@ Hforms]]\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["OreLeftGroebner: Bestimmen einer links-Gr\[ODoubleDot]bnerbasis.", \
"Subsubsection"],

Cell["\<\
Dies wird \[UDoubleDot]ber die limited Version bestimmt, mit dem \
Limit 100, das f\[UDoubleDot]r kein Beispiel einen wirklichen Unterschied \
ausmachen d\[UDoubleDot]rfte. Eventuell ist diese Schranke noch \
heraufzusetzen.\
\>", "Text"],

Cell[BoxData[
    \(\(OreLeftGroebner[l_List, \ 
          vl_Integer:  0] := \[IndentingNewLine]OreLeftGroebnerLimited[l, 
          100, vl];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreLeftGroebnerLimited: Den Buchberger Algorithmus \
ausf\[UDoubleDot]hren.\
\>", "Subsubsection"],

Cell[TextData[{
  "Dabei wird als einfache Beschleunigung die Antisymmetrie der S-Polynome \
ausgenutzt, die auch im Ore-Fall die Halbierung der Anzahl der zu \
berechnenden S-Polynome zul\[ADoubleDot]sst.\nEs werden zun\[ADoubleDot]chst \
alle relevanten S-Polynome gebildet und aufsteigend nach der durch die \
Monomordnung gegebenen Halbordnung sortiert  (was die Ausf\[UDoubleDot]hrung \
in der Regel sehr bescheunigt). \nJedes S-Polynom, dessen Normalform noch \
nicht verschwindet, wird zu der Basis hinzugenommen, und die entstehenden \
neuen S-Polynome mit den bereits vorhandenen Elementen zur Liste der \
S-Polynomen hinzusortiert.\nWie KRW zeigten, terminiert das Verfahren im ",
  StyleBox["solvable",
    FontColor->RGBColor[0, 1, 0]],
  " Fall stets - allerdings kann die Ausf\[UDoubleDot]hrung hoffnungslos \
lange dauern, deshalb bietet die \"limited\" version an, die \
L\[ADoubleDot]nge der berechneten Basis zu begrenzen. Nat\[UDoubleDot]rlich \
liegt im Allgemeinen keine Gr\[ODoubleDot]bnerbasis vor, wenn die Berechnung \
aufgrund der Limitierung abgebrochen wurde! "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[OreLeftGroebnerLimited];\)\), "\[IndentingNewLine]", 
    \(\(OreLeftGroebnerLimited[l_List, LengthLimit_Integer, \ 
          vl_Integer:  0] := \[IndentingNewLine]Module[{G = l, \ B, IArr, \ 
            h, h0, \ NumberOfElements = 
              Length[l]}, \[IndentingNewLine]InfoMessage[vl, 
            3, "\<Start of OreLeftGroebner, arguments:\>", l, "\<, \>", 
            LengthLimit, "\<, \>"\ vl]; \[IndentingNewLine]B = 
            Table[Table[OreSPoly[G[\([i]\)], G[\([j]\)]], {i, 1, j - 1}], {j, 
                2, Length[G]}]; \[IndentingNewLine]B = 
            Sort[Flatten[
                B], #1 < #2 &]; \[IndentingNewLine]While[\((Length[B] > 
                  0)\) && \((\ 
                Length[G] < LengthLimit)\), \ \[IndentingNewLine]InfoMessage[
              vl, 2, "\<G is: \>", G, "\<\n B is: \>", \ 
              B]; \[IndentingNewLine]h = First[B]; \ 
            B = \ Rest[B]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              Kleinstes\ S - 
                Polynom\ \(\(w\[ADoubleDot]hlen\)\(.\)\)\ \
*) \[IndentingNewLine]h0 = 
              OreNormalForm[h, G]; \ \[IndentingNewLine]InfoMessage[vl, 
              3, "\<Selected from B the S-polynomial = \>", 
              h]; \[IndentingNewLine]If[\ 
              h0 =!= OreZero, \[IndentingNewLine]h0 = 
                OreEliminateContent[h0]; \[IndentingNewLine]B = \ 
                Sort[Flatten[{B, \(OreSPoly[#, h0] &\) /@ 
                        G}], #1 < #2 &]; \  (*\ 
                Alle\ Paare\ aus\ G\ x\ {h0}\ zu\ B\ \(\(hinzufuegen\)\(.\)\)\
\ *) \[IndentingNewLine]G = Append[G, h0]; \[IndentingNewLine]InfoMessage[vl, 
                1, "\<As element \>", Length[G], "\< added \>", 
                h0, "\< =!= \>", \ 
                OreZero, "\< to G. \>"];\[IndentingNewLine], 
              Null\  (*\ 
                else : \ \(\(nothing\)\(.\)\)\ *) \[IndentingNewLine], \  (*\ 
                dont\ know\ \
*) \[IndentingNewLine]\(Return["\<OreLeftGroebner: can't compare \>", 
                  h0, "\<, \>", OreZeroPolynomial];\)\[IndentingNewLine]] (*\ 
              If\ *) \[IndentingNewLine]];  (*\ 
            While\ Length[B] > 
                0\  ... \ *) \[IndentingNewLine]G\[IndentingNewLine]];\)\ \
\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["OreReduceGroebnerBasis: Reduzieren einer Gr\[ODoubleDot]bnerbasis.", \
"Subsubsection"],

Cell["\<\
Eine Hilfsfunktion entfernt Nullpolynome aus einer Liste von Ore \
Polynomen.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(RemoveZeros[L_List] := Select[L, # =!= OreZero &];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
OreReduceGroebnerBasis bildet solange zu jedem Element den \
Divisionsrest bez\[UDoubleDot]glich der restlichen Elemente, bis dies f\
\[UDoubleDot]r kein Element mehr eine Ver\[ADoubleDot]nderung bringt.\
\>", \
"Text"],

Cell[BoxData[
    \(Clear[OreReduceGroebnerBasis]; 
    OreReduceGroebnerBasis[G_List, \ 
        vl_Integer:  0] := \[IndentingNewLine]Module[{GG, Changed, reduced, 
          i}, \[IndentingNewLine]GG = 
          RemoveZeros[G]; \ \[IndentingNewLine]GG = 
          Sort[GG, #2 < #1 &]; \  (*\ 
          Greatest\ \(\(first\)\(.\)\)\ *) \[IndentingNewLine]InfoMessage[vl, 
          2, "\<RGB: sorted Basis: \>", \ GG]; \[IndentingNewLine]InfoMessage[
          vl, 4, "\<simultanous quotients:\>", \ \[IndentingNewLine]Table[
            OreDivision[GG[\([i]\)], Drop[G, {i}]], \[IndentingNewLine]{i, 1, 
              Length[GG]}]\[IndentingNewLine]]; \[IndentingNewLine]Changed = 
          True; \[IndentingNewLine]While[
          Changed, \[IndentingNewLine]Changed = False; \[IndentingNewLine]For[
            i = 1, i \[LessEqual] 
              Length[GG], \(i++\), \[IndentingNewLine]reduced = 
              First[OreDivision[GG[\([i]\)], 
                  Drop[GG, {i}]]]; \[IndentingNewLine]If[
              reduced =!= GG[\([i]\)], \ \[IndentingNewLine]Changed = 
                True; \ \[IndentingNewLine]If[
                reduced === OreZero, \[IndentingNewLine]GG = 
                  Drop[GG, {i}], \[IndentingNewLine]GG[\([i]\)] = 
                  reduced, \[IndentingNewLine]\(InfoMessage[vl, 
                    0, "\<RGB: Impossible decision, you should never read \
this!\>"];\)\[IndentingNewLine]]; \[IndentingNewLine]Break[];\
\[IndentingNewLine]]; \  (*if*) \[IndentingNewLine]]; \  (*for\
*) \[IndentingNewLine]]; \  (*\ 
          While\ *) \[IndentingNewLine]OreEliminateContent /@ 
          GG\[IndentingNewLine]];\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Die Extended-Versionen: Beweisbarkeit durch Zeugen.", "Subsection"],

Cell["\<\
Die Idee ist: Bei den erweiterten Versionen wird nicht nur mit \
Elementen des Ideales gerechnent, sondern es wird die Darstellung jedes \
Elementes durch die urspr\[UDoubleDot]nglich gegebenen Erzeugenden mitgef\
\[UDoubleDot]hrt. Sind also die Erzeuger g1, ... gn eines Ideales G gegeben, \
so speichert man zu einem Element 
f= a1 g1 + a2 g2+ \[Ellipsis]+an gn die erweiterte Version {f,{a1,a2,\
\[Ellipsis], an}}. 
So kann man etwa nach erstellen einer erweiterten Gr\[ODoubleDot]bnerbasis H \
nicht nur einfach die Gr\[ODoubleDot]bnerbasiseigenschaft nachweisen, und \
\[UDoubleDot]ber die Division G\[Subset]\[LeftAngleBracket]H\
\[RightAngleBracket] zeigen, sondern hat auch Zeugen f\[UDoubleDot]r eine \
Darstellung der Basiselemente in G, also \[LeftAngleBracket]H\
\[RightAngleBracket]\[Subset]G.
Dieses Feature war im \[UDoubleDot]brigen eine wunderbare Hilfe bei der \
Fehlersuche!\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
OreCheckExtended: Testen, ob die erweiterte Darstellung korrekt \
ist.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(OreCheckExtended[r_, 
          G_] := \((First[r] === 
            Sum[OMu[OPo[\(Last[r]\)[\([i]\)]], G[\([i]\)]], {i, 1, 
                Length[Last[r]]}])\);\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreExtendedSPoly: S-Poynom von Polynomen in erweiterter \
Darstellung.\
\>", "Subsubsection"],

Cell["\<\
Die Faktoren, mit denen die Erweiterung korrekt bestimmt wird, erh\
\[ADoubleDot]lt die Prozedur aus dem erweiterten S-Polynom, das zu p,q \
au\[SZ]er dem S-Polynom s auch a,b mit s=a p+b q liefert.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[OreExtendedSPoly];\)\), "\[IndentingNewLine]", 
    \(\(OreExtendedSPoly[{p_OrePolynomial, lp_List}, {q_OrePolynomial, 
            lq_List}, 
          vl_Integer:  0] := \[IndentingNewLine]Module[{S, lS, a, 
            b}, \[IndentingNewLine]{S, a, b} = 
            OreExtendedSPolynomial[p, 
              q]; \ \[IndentingNewLine]Return[{S, \((\(OMu[a, #] &\) /@ 
                    lp)\) + \((\(OMu[b, #] &\) /@ 
                    lq)\)}];\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Die Hilfsfunktion OreExtendedSPolyMemory gibt den beim \
Divisionsalgorithmus wichtigen Faktor a in der Darstellung  s=a p+b q mit zur\
\[UDoubleDot]ck, der dort nicht vergessen werden darf.\
\>", "Text"],

Cell[BoxData[
    \(\(OreExtendedSPolyMemory[{p_OrePolynomial, lp_List}, {q_OrePolynomial, 
            lq_List}, 
          vl_Integer:  0] := \[IndentingNewLine]Module[{S, lS, a, 
            b}, \[IndentingNewLine]{S, a, b} = 
            OreExtendedSPolynomial[p, 
              q]; \ \[IndentingNewLine]Return[{{S, \((\(OMu[a, #] &\) /@ 
                      lp)\) + \((\(OMu[b, #] &\) /@ lq)\)}, 
              a}];\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreExtendedNormalForm: Normalformberechnung f\[UDoubleDot]r \
erweiterte Darstellungen.\
\>", "Subsubsection"],

Cell["\<\
Dies ist gerade OreNormalForm um die Buchhaltung der Koeffizienten \
erweitert.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[OreExtendedNormalForm];\)\), "\[IndentingNewLine]", 
    \(\(OreExtendedNormalForm[f_, P_, vl_Integer:  0] := 
        Module[\[IndentingNewLine]{R, \ 
            Rfact, \[IndentingNewLine]ff = f, \[IndentingNewLine]PP, \ 
            i}, \[IndentingNewLine]R = OreZero; \ 
          Rfact = OreOne; \[IndentingNewLine]PP = 
            Select[P, \(! \((First[f] < First[#])\)\) &]; \  (*\ 
            Zu\ gro\[SZ]e\ Terme\ scheiden\ gleich\ \(aus!\)\
*) \[IndentingNewLine]PP = 
            Sort[PP, First[#1] < First[#2] &]; \[IndentingNewLine]While[
            First[ff] =!= \ OreZero\  && \ PP =!= {}, \[IndentingNewLine]i = 
              1; \[IndentingNewLine]While[
              i \[LessEqual] 
                  Length[PP] && \(! \((OreTopReducibleQ[First[ff], 
                      First[PP[\([i]\)]]])\)\), \(i++\)]; \
\[IndentingNewLine]If[
              i <= Length[PP], \[IndentingNewLine]InfoMessage[vl, 
                4, "\<OreExtendedNormalForm: before \
ff=OreExtendedSPoly[ff,PP[[i]]];\nR=\>", R, "\<\nff=\>", 
                ff, "\<\nPP[[i]]=\>", 
                PP[\([i]\)]]; \[IndentingNewLine]{ff, Rfact} = 
                OreExtendedSPolyMemory[ff, PP[\([i]\)], 
                  vl]; \[IndentingNewLine]InfoMessage[vl, 
                4, "\<OreExtendedNormalForm:\nR=\>", R, "\<\nff=\>", 
                ff, "\<\nPP[[i]]=\>", 
                PP[\([i]\)], "\<Factor for R (must be of zerodegree):\>", 
                Rfact]; \[IndentingNewLine]R = 
                OMu[Rfact, 
                  R];\[IndentingNewLine], \[IndentingNewLine]InfoMessage[vl, 
                4, "\<OreExtendedNormalForm: cutted. \nR=\>", R, "\<\nff=\>", 
                ff]; \[IndentingNewLine]R = 
                R + OreLeadingSummand[
                    First[ff]]; \ \[IndentingNewLine]ff = {OreLesserTerms[
                    First[ff]], Last[ff]}; \[IndentingNewLine]InfoMessage[vl, 
                4, "\<OreExtendedNormalForm:\nR=\>", R, "\<\nff=\>", 
                ff];\[IndentingNewLine]]; \[IndentingNewLine]PP = 
              Select[PP, \(! \((First[ff] < First[#])\)\) &]; \  (*\ 
              Zu\ gro\[SZ]e\ Terme\ scheiden\ \
\(aus!\)*) \[IndentingNewLine]];  (*While*) \[IndentingNewLine]{R + 
              First[ff], Last[ff]}\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreExtendedLeftGroebnerLimited: Erweiterte Gr\[ODoubleDot]bnerbasis \
bestimmen.\
\>", "Subsubsection"],

Cell["\<\
Hier entsteht eine Gr\[ODoubleDot]bnerbasis aus erweiterten \
Elementen. 
zu jedem S-Polynom werden die Koeffizienten der Elemente der alten Basis \
mitprotokolliert. Es wird also einVektor von Orepolynomen \
mitgef\[UDoubleDot]hrt mitgef\[UDoubleDot]hrt, dessen skalarprodukt mit dem \
n- Tupel derBasiselementeden eigentliche Eintrag ergibt.\
\>", "Text"],

Cell["\<\
Hilfsfunktion: Eine Einheitsmatrix aus OrePolynomen, die triviale \
Koeffizientenliste.\
\>", "Text"],

Cell[BoxData[
    \(\(OreUnit[i_Integer, length_Integer] := 
        Table[OPo[KroneckerDelta[i, l]], {l, 1, length}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Der Gr\[ODoubleDot]bnerbasisalgorithmus ist in der erweiterten \
Version kaum anders als gehabt:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[OreExtendedLeftGroebnerLimited];\)\), "\[IndentingNewLine]", 
    \(\(OreExtendedLeftGroebnerLimited[l_List, LengthLimit_Integer, \ 
          vl_Integer:  0] := \[IndentingNewLine]Module[{G, \ B, IArr, \ h, 
            h0, \ NumberOfElements = 
              Length[l]}, \[IndentingNewLine]InfoMessage[vl, 
            3, "\<Start of Extended OreLeftGroebner,\n arguments:\>", 
            l, "\<, \>", LengthLimit, "\<, \>"\ vl]; \[IndentingNewLine]G = 
            Table[{l[\([i]\)], OreUnit[i, NumberOfElements]}, {i, 1, 
                NumberOfElements}]; \[IndentingNewLine]InfoMessage[vl, 
            3, "\<G:\>", G]; \[IndentingNewLine]B = 
            Table[Table[
                OreExtendedSPoly[G[\([i]\)], G[\([j]\)]], {i, 1, j - 1}], {j, 
                2, Length[G]}]; \[IndentingNewLine]B = 
            Sort[Flatten[B, 1], 
              First[#1] < 
                  First[#2] &]; \[IndentingNewLine]While[\((Length[B] > 
                  0)\) && \((\ 
                Length[G] < LengthLimit)\), \ \[IndentingNewLine]InfoMessage[
              vl, 2, "\<G is: \>", G, "\<\n B is: \>", \ 
              B]; \[IndentingNewLine]h = First[B]; \ 
            B = \ Rest[B]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
              Kleinstes\ S - 
                Polynom\ \(\(w\[ADoubleDot]hlen\)\(.\)\)\ \
*) \[IndentingNewLine]h0 = 
              OreExtendedNormalForm[h, G]; \ \[IndentingNewLine]InfoMessage[
              vl, 3, "\<Selected from B the S-polynomial = \>", 
              h, "\<\n with normalform:\>", h0]; \[IndentingNewLine]If[\ 
              First[h0] =!= OreZero, \[IndentingNewLine]B = \ 
                Sort[Flatten[{B, \(OreExtendedSPoly[#, h0] &\) /@ G}, 1], 
                  First[#1] < First[#2] &]; \  (*\ 
                Alle\ Paare\ aus\ G\ x\ {h0}\ zu\ B\ \(\(hinzufuegen\)\(.\)\)\
\ *) \[IndentingNewLine]G = Append[G, h0]; \[IndentingNewLine]InfoMessage[vl, 
                1, "\<Added \>", h0, "\< =!= \>", \ 
                OreZero, "\< to G. \>"];\[IndentingNewLine], 
              Null\ \[IndentingNewLine], \
\[IndentingNewLine]\(Return["\<OreLeftGroebner: can't compare \>", 
                  h0, "\<, \>", 
                  OreZeroPolynomial];\)\[IndentingNewLine]];\
\[IndentingNewLine]];  (*\ 
            While\ Length[B] > 
                0\  ... \ *) \[IndentingNewLine]G\[IndentingNewLine]];\)\ \
\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["OreDivisionExtended: Division samt Basisdarstellungen.", "Subsubsection"],

Cell["\<\
Die erweiterte Version der Division durch mehrere Elemente benutzt \
einfach die Urspr\[UDoubleDot]ngliche Division. Die berechnete Darstellung \
des Restes mu\[SZ] dann noch f\[UDoubleDot]r die Koeffizientenliste des \
Ergebnisses durchgef\[UDoubleDot]hrt werden. Falls ein Informationslevel >0 \
\[UDoubleDot]bergeben wird, mu\[SZ] die zugrundeliegende Basis \
\[UDoubleDot]ber die Option BaseGenerators\[Rule]G \[UDoubleDot]bergeben \
werden. \
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[OreDivisionExtended];\)\), "\[IndentingNewLine]", 
    \(\(Options[
          OreDivisionExtended] = {BaseGenerators \[Rule] 
            Null};\)\), "\[IndentingNewLine]", 
    \(\(OreDivisionExtended[p_, L_List, vl_Integer:  0, 
          options___] := \[IndentingNewLine]Module[{r, koeffs, darst, tmp, 
            G}, \[IndentingNewLine]G = \((\((BaseGenerators /. {options})\) /. 
                Options[
                  OreDivisionExtended])\); \ \[IndentingNewLine]\
\[IndentingNewLine]InfoMessage[vl, 4, "\<ODEXT: Eingabe: p = \>", 
            p, \ "\<, \n geteilt durch L= \>", 
            L, "\<\n Basis der Darstellung: \>", 
            G, "\<\nOptions: \>", {options}]; \ \[IndentingNewLine]\
\[IndentingNewLine]If[vl > 0 && \((G === Null)\), \ 
            InfoMessage[1, "\<No base given!\>"]; 
            Abort[]]; \[IndentingNewLine]\[IndentingNewLine]{r, koeffs} = 
            OreDivision[First[p], First /@ L, 
              vl]; \[IndentingNewLine]\[IndentingNewLine]tmp = 
            Table[\(OMu[koeffs[\([i]\)], #] &\) /@ 
                Last[L[\([i]\)]], \[IndentingNewLine]{i, 1, 
                Length[koeffs]}]; \[IndentingNewLine]darst = 
            Last[p] + Plus @@ tmp; \[IndentingNewLine]If[
            vl == 0 || \ 
              OreCheckExtended[{r, darst}, 
                G], \ \[IndentingNewLine]InfoMessage[vl, \ 
              3, "\<ODEXT: f\[UDoubleDot]r \>", {r, 
                darst}, "\< korrekt.\>"], \ \[IndentingNewLine]InfoMessage[
              vl, \ 1, "\<ODEXT: Darstellung verletzt!\>"]; \
\[IndentingNewLine]InfoMessage[vl, \ 
              2, "\<ODEXT: Darst = Last[p]+Plus@@tmp = \
\>"\[IndentingNewLine], \ darst // FullForm]; \[IndentingNewLine]InfoMessage[
              vl, \ 2, "\<ODEXT: Returning: \>", {{r, darst}, koeffs}]; 
            Abort[], \ \[IndentingNewLine]InfoMessage[vl, \ 
              1, "\<Nicht entscheidbarer Ausdruck:\>", 
              OreCheckExtended[{r, darst}, 
                G]]\[IndentingNewLine]]; \[IndentingNewLine]Return[{{r, 
                darst}, koeffs}]\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OreReduceExtendedGroebnerBasis: Erweiterter \
Reduktionsalgorithmus.\
\>", "Subsubsection"],

Cell["\<\
Erweiterte Version der Hilfsfunktion, die Nullelemente herauswirft:\
\
\>", "Text"],

Cell[BoxData[
    \(\(RemoveExtendedZeros[L_List] := 
        Select[L, First[#] =!= OreZero &];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Der erweiterte Reduktionsalgorithmus. Einziger Unterschied zum \
einfachen Reduzieren ist wieder einzig das Verwenden der erweiterten \
Versionen der Funktionen. Die Basisgeneratoren werden als Optionen \
\[UDoubleDot]bergeben falls eine h\[ODoubleDot]here Verbosity dies \
erforderlich macht (OreDivisionExtended testet dann die \
Integrit\[ADoubleDot]t).\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[OreReduceExtendedGroebnerBasis];\)\), "\n", 
    \(\(Options[
          OreReduceExtendedGroebnerBasis] = {BaseGenerators \[Rule] 
            Null};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(OreReduceExtendedGroebnerBasis[G_List, \ vl_Integer:  0, 
          options___] := \[IndentingNewLine]Module[{GG, Changed, reduced, 
            i, \ oo}, \[IndentingNewLine]oo = 
            Sequence @@ 
              Flatten[{options, 
                  Options[
                    OreReduceExtendedGroebnerBasis]}]; \[IndentingNewLine]GG \
= RemoveExtendedZeros[G]; \ \[IndentingNewLine]GG = 
            Sort[GG, First[#2] < First[#1 &]]; \  (*\ 
            Greatest\ \(\(first\)\(.\)\)\ *) \[IndentingNewLine]\
\[IndentingNewLine]InfoMessage[vl, 2, "\<RGB: sorted Basis: \>", \ 
            GG]; \[IndentingNewLine]InfoMessage[vl, 
            3, "\<simultanous Quotients:\>", \ \[IndentingNewLine]Table[
              OreDivisionExtended[GG[\([i]\)], Drop[G, {i}], vl, 
                oo], \[IndentingNewLine]{i, 1, 
                Length[GG]}]\[IndentingNewLine]]; \[IndentingNewLine]Changed \
= True; \[IndentingNewLine]While[
            Changed, \[IndentingNewLine]Changed = 
              False; \[IndentingNewLine]For[i = 1, 
              i \[LessEqual] 
                Length[GG], \(i++\), \[IndentingNewLine]reduced = 
                First[OreDivisionExtended[GG[\([i]\)], Drop[GG, {i}], vl, 
                    oo]]; \[IndentingNewLine]If[
                reduced =!= GG[\([i]\)], \ \[IndentingNewLine]Changed = 
                  True; \ \[IndentingNewLine]If[
                  First[reduced] === OreZero, \[IndentingNewLine]GG = 
                    Drop[GG, {i}], \[IndentingNewLine]GG[\([i]\)] = 
                    reduced, \[IndentingNewLine]\(Print["\<RGB: Internal \
error. Should be impossible to read this message!\>"];\)\[IndentingNewLine]]; \
\[IndentingNewLine]Break[];\[IndentingNewLine]]; \  \
(*if*) \[IndentingNewLine]]; \  (*for*) \[IndentingNewLine]]; \  (*\ 
            While\ *) \[IndentingNewLine]Return[
            GG];\ \[IndentingNewLine]];\)\(\ \)\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Abschlu\[SZ] des Privat- und Paketkontextes.", "Subsection"],

Cell[BoxData[
    \(\(\(\(End[]\) \)\(;\)\(\ \ \)\( (*\ 
      Private\ Context\ *) \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(EndPackage[];\)\(\n\)
    \)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
AutoGeneratedPackage->Automatic,
WindowSize->{1105, 738},
WindowMargins->{{79, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "lef", \
"Mathematica", "Orealgebra"}, "OreAlgs.ps", CharacterEncoding -> \
"iso8859-1"],
"Magnification"->1},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 79, 1, 232, "Title",
  InitializationCell->True],
Cell[1858, 56, 100, 3, 81, "Subtitle"],

Cell[CellGroupData[{
Cell[1983, 63, 62, 1, 39, "Subsubsection",
  InitializationCell->True],
Cell[2048, 66, 866, 18, 346, "Text",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2951, 89, 115, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[3069, 93, 112, 2, 39, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3218, 100, 32, 0, 66, "Section"],
Cell[3253, 102, 174, 4, 71, "Text"],
Cell[3430, 108, 149, 3, 62, "Input",
  InitializationCell->True],
Cell[3582, 113, 281, 5, 108, "Input",
  InitializationCell->True],
Cell[3866, 120, 249, 5, 108, "Input",
  InitializationCell->True],
Cell[4118, 127, 313, 5, 131, "Input",
  InitializationCell->True],
Cell[4434, 134, 332, 6, 154, "Input",
  InitializationCell->True],
Cell[4769, 142, 538, 8, 223, "Input",
  InitializationCell->True],
Cell[5310, 152, 491, 8, 200, "Input",
  InitializationCell->True],
Cell[5804, 162, 379, 6, 154, "Input",
  InitializationCell->True],
Cell[6186, 170, 297, 5, 131, "Input",
  InitializationCell->True],
Cell[6486, 177, 130, 3, 39, "Input",
  InitializationCell->True],
Cell[6619, 182, 289, 5, 131, "Input",
  InitializationCell->True],
Cell[6911, 189, 505, 8, 200, "Input",
  InitializationCell->True],
Cell[7419, 199, 633, 10, 246, "Input",
  InitializationCell->True],
Cell[8055, 211, 205, 4, 85, "Input",
  InitializationCell->True],
Cell[8263, 217, 344, 5, 154, "Input",
  InitializationCell->True],
Cell[8610, 224, 304, 5, 131, "Input",
  InitializationCell->True],
Cell[8917, 231, 281, 5, 108, "Input",
  InitializationCell->True],
Cell[9201, 238, 441, 7, 177, "Input",
  InitializationCell->True],
Cell[9645, 247, 276, 5, 108, "Input",
  InitializationCell->True],
Cell[9924, 254, 214, 4, 85, "Input",
  InitializationCell->True],
Cell[10141, 260, 195, 4, 85, "Input",
  InitializationCell->True],
Cell[10339, 266, 267, 5, 108, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[10643, 276, 35, 0, 113, "Section"],
Cell[10681, 278, 98, 2, 39, "Input",
  InitializationCell->True],
Cell[10782, 282, 114, 2, 39, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[10921, 288, 85, 1, 60, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[11031, 293, 130, 3, 39, "Subsubsection"],
Cell[11164, 298, 328, 6, 85, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[11529, 309, 105, 1, 39, "Subsubsection",
  InitializationCell->True],
Cell[11637, 312, 308, 5, 108, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11994, 323, 54, 0, 60, "Subsection"],

Cell[CellGroupData[{
Cell[12073, 327, 144, 5, 39, "Subsubsection",
  InitializationCell->True],
Cell[12220, 334, 114, 3, 46, "Text"],
Cell[12337, 339, 1003, 19, 338, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[13377, 363, 98, 1, 39, "Subsubsection",
  InitializationCell->True],
Cell[13478, 366, 121, 4, 46, "Text",
  InitializationCell->True],
Cell[13602, 372, 258, 5, 85, "Input",
  InitializationCell->True],
Cell[13863, 379, 243, 6, 71, "Text"],
Cell[14109, 387, 202, 4, 62, "Input",
  InitializationCell->True],
Cell[14314, 393, 214, 5, 71, "Text",
  InitializationCell->True],
Cell[14531, 400, 276, 6, 62, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[14844, 411, 42, 0, 39, "Subsubsection"],
Cell[14889, 413, 349, 7, 121, "Text"],
Cell[15241, 422, 1172, 19, 361, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[16450, 446, 126, 4, 39, "Subsubsection",
  InitializationCell->True],
Cell[16579, 452, 689, 12, 221, "Text"],
Cell[17271, 466, 3211, 53, 775, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[20519, 524, 116, 3, 39, "Subsubsection"],
Cell[20638, 529, 56, 0, 46, "Text"],
Cell[20697, 531, 147, 3, 39, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20893, 540, 56, 0, 60, "Subsection"],

Cell[CellGroupData[{
Cell[20974, 544, 116, 3, 39, "Subsubsection"],
Cell[21093, 549, 621, 10, 196, "Text"],
Cell[21717, 561, 1417, 24, 522, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[23171, 590, 95, 1, 39, "Subsubsection"],
Cell[23269, 593, 346, 8, 96, "Text"],
Cell[23618, 603, 699, 11, 223, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[24354, 619, 91, 1, 39, "Subsubsection"],
Cell[24448, 622, 248, 5, 71, "Text"],
Cell[24699, 629, 186, 4, 62, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[24922, 638, 108, 3, 39, "Subsubsection"],
Cell[25033, 643, 1101, 17, 246, "Text"],
Cell[26137, 662, 2326, 41, 614, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[28500, 708, 93, 1, 39, "Subsubsection"],
Cell[28596, 711, 129, 4, 46, "Text",
  InitializationCell->True],
Cell[28728, 717, 115, 2, 39, "Input",
  InitializationCell->True],
Cell[28846, 721, 229, 5, 71, "Text"],
Cell[29078, 728, 1698, 29, 660, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30825, 763, 73, 0, 60, "Subsection"],
Cell[30901, 765, 917, 16, 196, "Text"],

Cell[CellGroupData[{
Cell[31843, 785, 103, 3, 39, "Subsubsection"],
Cell[31949, 790, 226, 5, 62, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[32212, 800, 103, 3, 39, "Subsubsection"],
Cell[32318, 805, 250, 5, 71, "Text",
  InitializationCell->True],
Cell[32571, 812, 543, 10, 177, "Input",
  InitializationCell->True],
Cell[33117, 824, 214, 4, 71, "Text"],
Cell[33334, 830, 486, 9, 154, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[33857, 844, 120, 3, 39, "Subsubsection"],
Cell[33980, 849, 103, 3, 46, "Text"],
Cell[34086, 854, 2362, 41, 683, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[36485, 900, 113, 3, 39, "Subsubsection"],
Cell[36601, 905, 367, 7, 96, "Text"],
Cell[36971, 914, 111, 3, 46, "Text"],
Cell[37085, 919, 161, 3, 39, "Input",
  InitializationCell->True],
Cell[37249, 924, 120, 3, 46, "Text"],
Cell[37372, 929, 2454, 43, 637, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[39863, 977, 79, 0, 39, "Subsubsection"],
Cell[39945, 979, 470, 8, 96, "Text"],
Cell[40418, 989, 2162, 38, 637, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[42617, 1032, 101, 3, 39, "Subsubsection"],
Cell[42721, 1037, 93, 3, 46, "Text"],
Cell[42817, 1042, 139, 3, 39, "Input",
  InitializationCell->True],
Cell[42959, 1047, 380, 7, 121, "Text"],
Cell[43342, 1056, 222, 5, 62, "Input",
  InitializationCell->True],
Cell[43567, 1063, 1967, 34, 775, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[45583, 1103, 66, 0, 60, "Subsection"],
Cell[45652, 1105, 129, 3, 39, "Input",
  InitializationCell->True],
Cell[45784, 1110, 93, 3, 62, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

