(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     89485,       2390]*)
(*NotebookOutlinePosition[     90478,       2421]*)
(*  CellTagsIndexPosition[     90434,       2417]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Ore Algebra Basispaket", "Title"],

Cell["Basisroutinen zum rechnen in Ore-Algebren ", "Subsubtitle",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["History", "Subsubsection",
  InitializationCell->True],

Cell["\<\
30.01.06: Rechtschreibkorrekturen ... 
16.06.05: Umwandlung in pr\[ADoubleDot]sentationsform, Privacy \
wiederhergestellt.
 26.04.05: Bug in OreContent beseitigt (GCD statt PolynomialGCD).
  07.03.05: Inhaltsfunktion bez\[UDoubleDot]glich Operatorvariablen als \
OreVarContent und OreVarEliminateContent implementiert.
  22.02.05: Bug in OperatorPowerTimesSummand f\[UDoubleDot]r Diff beseitigt.
  24.12.04: changed: OreLeadingMonomial\[Rule]OreLeadingOperatorMonomial.
  24.12.04: denn es ist nur der Operatoranteil des Leitmonomes.
  24.12.04: Neu: OreLeadingMonomial ist korrekt das Leitmonom.
            13.10.04 : OreHasNoOperators implementiert. OreCurrentMatrix
                wird nun initialisiert
  12.10.04 : OreExponent implementiert, OreIsMonicQ korrigiert.
  09.10.04 : OreCoefficientList gibt wirklich die Koeffizienten aus
              statt der Variablen.
  
  07.10.04 : OMu auch als un\[ADoubleDot]re Operation zugelassen.    
  06.10.04 : fehlendes UpdateCounter in DeclareVariables \
eingef\[UDoubleDot]gt.
  31.08.04 : usage-Informationen ausgebaut. 
  21.05.04 : Beschreibungen der \"***DefineOrder\"-Befehle \
erg\[ADoubleDot]nzt
  05.04.04 : Bug in OreMultiplication beseitigt
  05.04.04 : Multiplizieren mit OreZero lieferte Unsinn
  29.03.04 : OreInitialTerm[x_OrePolynomial] implementiert
  23.03.04 : OreGetMonomOrder, OreOrderData mit den Operationen
  23.03.04 : OreDefine... angepasst, Datenstruktur angepasst.
  17.03.04 : S-Polynom berichtigt, Ordnungsfunktionen zugef\[UDoubleDot]gt
  06.05.02 : Multiplikation neugeschrieben. 
  29.04.02 : Bug in OreVarMonomialQ beseitigt. 
  04.04.02 : Vektorordnungen implementiert, intern
  03.04.02 : Umwandlung von OreSummanden in Vektoren, um 
            die Ordnung darueber implementieren zu koennen.;
  26.03.02: 
    Implementiert: OreVarMonomialQ OreExtendedExp2Vec OreExp2Vec OreVec2OPo
  25.03.02: Design\[ADoubleDot]nderung: Zu den Operatoren kommt nun noch eine \
Liste Gradrelevanter Variablen
  13.06.01 : Ausbau auf mehrere Operatoren auf einer Variablen
  ... ;\
\>", "Text",
  InitializationCell->True],

Cell["\<\
  ToDo:                                        
\tOreContent so ausbauen, da\[SZ] auch Parameter ber\[UDoubleDot]cksichtigt \
werden.
  F\[UDoubleDot]r den Gr\[ODoubleDot]bner-Walk:                               \
        
  To Check:
  OreVersion up Date?
  OreContent sollte mit Parametern (die keine Ore Variablen sind) \
zurechtkommen.\
\>", "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Deklarationen und Schnittstelle f\[UDoubleDot]r den aufrufenden \
Kontext.", "Section"],

Cell[BoxData[
    \(\(BeginPackage["\<Ore`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreApply::usage\  = \ "\<OreApply[_OrePolynomial,_] 
Applies the given OrePolynomial as an operator on the second \
Argument.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Delta::usage = \ "\<The Map Delta[i], extended on polynomials.If 'Op' \
is the i-th operator, then Op f = \[Sigma][f]Op + \[Delta][f]. Where \
\[Delta]=Delta[i]\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NextDegeneration::usage\  = \ "\< NextDegeneration[L_List, v_List] \
gets the next degenerationpoint of the list L of ore polynomials when \
wandering from the current order to the order with the wightvector \
v.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NextDegenerationVec::usage\  = \ "\< NextDegenerationVec[L_List, \
v_List] gets the next degenerationpoint of the list L of vectors when \
wandering from the current order to the order with the wightvector \
v.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Operation::usage = \ "\<The actual operations Operation[i] as \
functions.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreCoefficientList::usage = "\<OreCoefficientList[P_OrePolynomial] \
gives a list consisting of the coefficients of P.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreContent::usage = "\<OreContent[P_OrePolynomial] returns the GCD of \
the coefficients of P, using the common GCD-command from mathematica (i.e. \
assuming commutativity of the basering)\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreCurrentMatrix::usage = "\<OreCurrentMatrix[] returns the matrix of \
the actual monomorder together with a List of the ordered objects defining \
the canonical Order.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineLexOrder::usage = "\<Usage: OreDefineLexOrder switches to \
(default) lexicographical order. Other orders: OreDefineReverseLexOrder, \
OreDefineDegLexOrder, OreDefineReverseDegLexOrder.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineReverseLexOrder::usage\  = \ "\<Usage: \
OreDefineReverseLexOrder[] switches to the inverse lexicographical order. \
Other orders: OreDefineLexOrder, OreDefineDegLexOrder, \
OreDefineReverseDegLexOrder\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineDegLexOrder::usage\  = \ "\<Usage: OreDefineDegLexOrder[] \
switches to the degree lexicographical order.OreDefineReverseLexOrder, \
OreDefineLexOrder, OreDefineReverseDegLexOrder\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineReverseDegLexOrder::usage\  = \ "\<Usage: \
OreDefineReverseDegLexOrder[] switches to the degree (double)reverse \
lexicographical order.Other orders: OreDefineReverseLexOrder, \
OreDefineDegLexOrder, OreDefineLexOrder.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDeclareVariables::usage = "\<OreDeclareVariables[L_List] takes the \
not jet declared variables from L and appends them to the list of already \
declared variables.
    See also: OreDefineOperator, OreDefineShift, OreDefineDiff, \
OreDefineQDifferentiation, OreDefineDummy.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineOperator::usage\  = \ "\<OreDefineOperator[_Symbol,_List, \
_List,_Function] : Set up the local definitions for Sigma, Delta of a new \
operator, appends it on the list of operators and returns an ore polynomial \
cosisting of the new operator. The first argument denotes the name of the \
operator shown in the output. The first list is a list of rules defining The \
algebrahom. \[Sigma], for example {X -> 3, Y->X, Z->Z}. The second list is \
the same with \[Delta], the third parameter describes the operation. For \
\[Sigma] \[NotEqual] id it is sufficient to give the image of \[Delta] for \
the first variable X with \[Sigma](X)\[NotEqual]X, because \[Delta] is fully \
dertermined with this data. Consistency will not be checked!
See also: OreDeclareVariables, OreDefineShift, OreDefineDiff, \
OreDefineQDifferentiation, OreDefineDummy.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineShift::usage\  = \ \
\[IndentingNewLine]"\<OreDefineShift[_Symbol, _Symbol] : Set up the local \
definitions for Sigma, Delta of a new shift operator, appends it on the list \
of operators and returns an ore polynomial cosisting of the new operator. The \
first argument denotes the name of the operator shown in the Output. The \
second argument says, wich variable is shifted. Consistency will not be \
checked (for example violation of the ore condition that the operators must \
commute)!\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineDiff::usage\  = \ \
\[IndentingNewLine]"\<OreDefineDiff[_Symbol, _Symbol] : Set up the local \
definitions for Sigma, Delta of a new Differeniation operator, appends it on \
the list of operators and returns an ore polynomial cosisting of the new \
operator. The first argument denotes the name of the operator shown in the \
Output. The second argument says, with respect to wich variable is \
differentiated. Consistency will not be checked (for example violation of the \
Ore Condition that the operators must commute)!\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineQDifferentiation::usage\  = \ \
\[IndentingNewLine]"\<OreDefineDiff[_Symbol, _Symbol,_Symbol] : Set up the \
local definitions for Sigma, Delta of a new q-Differeniation operator, \
appends it on the list of operators and returns an ore polynomial cosisting \
of the new operator. The first argument denotes the name of the operator \
shown in the Output. The second argument says, with respect to wich variable \
is differentiated, the third stands for the Parameter 'q' of the \
q-Differentiation. Consistency will not be checked (for example violation of \
the Ore Condition that the operators must commute)!\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreDefineDummy::usage\  = \ \
\[IndentingNewLine]"\<OreDefineDummy[_Symbol] : Set up the local definitions \
for Sigma, Delta of a new commutative operator, appends it on the list of \
operators and returns an ore polynomial cosisting of the new operator. The \
argument denotes the name of the operator shown in the Output. Applying this \
operator is just multiplying its argument as a commutative \
variable.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreEliminateContent::usage = "\<OreEliminateContent[P_OrePolynomial] \
Devides by the Content
and simplifies the Coefficients.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExponent::usage = "\<OreExponent[M_OrePolynomial/;OreObjectQ[M], \
S_OrePolynomial] gives the maximal power to wich M appears in one of the \
Summands of S.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExtendedSPolynomial::usage = \
"\<OreExtendedSPolynomial[p_OrePolynomial,q_OrePolynomial] returns the \
S-Polynomial and Monomials a,b with S=a*p + b*q in the Form {S,a,b}. \
\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreGetMonomOrder::usage = "\<OreGetMonomOrder[] gives the currently \
used momomorder. It returns a list {Variables,Matrix}. 'Variables' is a list \
containing all relevant variables, thus defining a 'canonical Order'. \
'Matrix' defines a matrix describing how the actual order emerges from the \
canonical Order.
See also OreRedefineMonomOrder.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreInverse::usage = "\<Inverts an Operator if it is a Unit.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreIsMonicQ::usage = "\<OreIsMonicQ[P_OrePolynomial] Tests whether P \
is a simple monomial.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreIsUnitQ::usage = "\<OreIsUnitQ[P_OrePolynomial] tests, if P is \
invertible.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreIsObjectQ::usage = "\<OreIsObjectQ[P] tests, whether P is an ore \
polynomial consisting of one single operator or ore variable.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreInitialTerm::usage = "\<OreInitialTerm[x_OrePolynomial]: Gives the \
Initial Term of x with respect to the first row of the actual order \
matrix.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLeadingCoefficient::usage = \
"\<OreLeadingCoefficient[_OrePolynomial] returns
the leading coefficient of this polynomial.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLeadingSummand::usage = "\<OreLeadingSummand[_OrePolynomial] \
returns
the leading Summand of this polynomial.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLesserTerms::usage = "\<OreLesserTerms[p_OrePolynomial] returns \
the polynomial without the Leading Term.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLeadingMonomial::usage = \ "\<OreLeadingMonomial[f_OrePolynomial] \
returns the leading summand, divided by all non-ore-variable \
constants\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreLeadingOperatorMonomial::usage\  = \ \
"\<OreLeadingOperatorMonomial[_OrePolynomial] returns the leading monomial
of the given orepolynomial.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreListOfOrderObjects::usage = "\<A list of the objects concerned by \
the current order in internal form. This is a raw form, to see the variables \
in their actual canonical order, use OreOrderedListOfObjects. 
See also: OreOrderedListOfObjects.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OMu::usage = "\<Short for OreMultiplication. \>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OPo::usage = "\<Make An Ore Polynomial from an \
Expression/OreSummand\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ore::usage\  = \ "\<Functions to handle Expressions with \
Ore-Operators\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMapOnCoefficients::usage = \
"\<OreMapOnCoefficients[f_Function,P_OrePolynomial]
Applies the given Function on all Coefficients.l\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMonomial::usage = \ "\<OreMonomial[{n1,p1},{n2,p2}, ...,{ni,pi}] \
stands for the Product
of the pi-th Powers of Operator n1, ... Operator ni, n1 < n2 < ... ni .\>";\)\
\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreNumberOfObjects::usage = "\<This is OreNumberOfOperators + \
OreNumberOfVariables\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreNumberOfOperators::usage\  = "\<This is the number of defined \
Operators.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreNumberOfVariables::usage\  = \ "\<This ist the number of declared \
variables.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreOne::usage\  = \ "\< The One-Polynomial. \>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreOneMonomial::usage\  = \ "\<The One-Monomial D^0\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(OreOperatorNames::usage\  = "\<This is a list of the names of the \
Operators.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreOrderData::usage = "\<Giving a sequence of the currently used \
canonical order of objects and the current order matrix. This Sequence ist \
ready to be the Argument(s) of 'OreRedefineMonomOrder'.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreOrderedListOfObjects::usage = "\<OreOrderedListOfOrderObjects \
returns a list of variables and operators ordered according to the identity \
order.
See also: OreOrderData\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrePolynomial::usage = "\< OrePolynomial[_OreSummand, _OreSummand, \
...] denotes
an OrePolynomial in cannonical Form, i.e. sorted with respect to the Monomial
Order.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrePolynomialsToVectorList::usage = \
\[IndentingNewLine]"\<OrePolynomialsToVectorList[L_List] Returns a List of \
all ordervectors of all summands occuring in the given list of \
orepolynomials.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreRedefineMonomOrder::usage\  = "\<Usage: \
OreRedefineMonomOrder[Monomials_List, Matrix_List]
This redefines the Monomial Order used. The first list must consist of The \
operators, wich should be considered in their canonical order (i.e. Dx, Dy, \
Dz for the canonical Order  Dx > Dy > Dz), the second is a Matrix A, defining \
the actual Order (such that in our example Dx^m Dy^n Dz^o < Dx^M Dy^N Dz^O is \
defined by 
(m,n,o).A < (M,N,O).A where the latter '<' denotes the lexicographical \
order.)
WARNING: After adding a new Operator, OreRedefineMonomOrder must be called \
again.
See also: OreOrderData\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSummand::usage = "\<OreSummand[_OreCoefficient,_OreMonomial] \
encapsulates a polynomial 
Coefficient and an Ore Monomial.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreVariables::usage\  = \ "\<This is a list of the declared variables \
of the Algebra.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMultiplication::usage = "\<perform Multiplication of \
OrePolynomials\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreShowStatus::usage = "\<Show all Operators, variables and \
OrderInformation\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSimplify::usage\  = \ "\<OreSimplify[_OrePoly] Collects and sorts \
with respect
to the monomial ordering.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSimplifyCoefficients::usage = "\<Apply the mathematica - simplify \
to the
coefficients of an ore polynomial (assuming commutativity of the ring of \
coefficients).\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSPoly::usage = "\<OreSPoly[p_OrePolynomial,q_OrePolynomial] \
returns the S-Polynomial of monomials p,q.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreTerm::usage = "\<OreTerm[x___] returns an ore polynomial \
consisting of the product of all arguments after translating them to ore \
polynomials.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreVarContent::usage = "\<OreVarContent[P_OrePolynomial] gives the \
polynomial GCD of the coefficients of the operatormonomials.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(OreVarEliminateContent::usage = \
"\<OreVarEliminateContent[P_OrePolynomial] devides out OreVarContent[P] from \
the coefficients of the operatormonomials\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreVarMonomialQ::usage\  = \ "\<OreVarMonomialQ[a_Expression] Tests, \
whether the expression a is a monomial in the ore variables.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(OreZero::usage = \ "\< The Zero-Polynomial. \>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreZeroSummand::usage\  = \ "\<The summand zero\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Sigma::usage = "\<The maps Sigma[i], defined on polynomials. If 'Op' \
is the i-th Operator, then Op f = \[Sigma][f]Op + \[Delta][f]. Where \
\[Sigma]=Sigma[i]\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SolvableQ::usage = "\<SolvableQ tests, if the actual order is of \
solvable type.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SummandToVector::usage = \
\[IndentingNewLine]"\<SummandToVector[f_OreSummand] translates an ore summand \
into the internal ordervector. The i-th entry is the power to wich the i-th \
oreobject appears.\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Die Implementation.", "Section"],

Cell[BoxData[
    \(\(\(Begin["\<`Private`\>"];\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Aufbau der internen Datenstruktur.", "Subsection",
  InitializationCell->True],

Cell["\<\
Die interne Datenstruktur sieht im Detail wie folgt aus:
Die Objekte, mit denen der Anwender arbeitet haben den Header 
OrePolynomial.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Initialisierung der Container f\[UDoubleDot]r die Ore-Objekte und \
die Ordnung, Buchhaltungsfunktionen.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(OreOperators\  = \ {};\)\), "\[IndentingNewLine]", 
    \(\(OreVariables\  = \ {};\)\), "\[IndentingNewLine]", 
    \(\(OreNumberOfOperators = 0;\)\), "\[IndentingNewLine]", 
    \(\(OreNumberOfVariables = 0;\)\), "\[IndentingNewLine]", 
    \(OreListOfOrderObjects = {}; \ \ \ \ \ \  (*"\< Ops & Vars \>"\
*) \[IndentingNewLine]OreNumberOfObjects := 
      OreNumberOfOperators + OreNumberOfVariables;\)}], "Input",
  InitializationCell->True],

Cell["\<\
Defaultm\[ADoubleDot]\[SZ]ig wird die interne Reihenfolge f\
\[UDoubleDot]r die Ordnung verwendet.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    StyleBox[\(\(OreOrderVector := 
          Table[i, {i, OreNumberOfObjects}];\)\(\ \)\),
      FontColor->RGBColor[1, 0, 0]]], "Input",
  InitializationCell->True],

Cell["\<\
Die Reihenfolge der Objekte f\[UDoubleDot]r die Ordnung kann mit \
folgender Permutation umgeordnet werden:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(OreInternalToActual := 
        Table[i, {i, OreNumberOfObjects}];\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell["Die die aktuelle Ordnung definierende Matrix", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreCurrentMatrix = {{}};\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Abk\[UDoubleDot]rzungen f\[UDoubleDot]r h\[ADoubleDot]ufige Objekte:", \
"Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(OreOneMonomial\  := 
      OreMonomial[]; \  (*"\< Das \>" 
        Einsmonom "\< vom Grad 0 \>"*) \[IndentingNewLine]OreZero\  = \ 
      OPo[0];\), "\[IndentingNewLine]", 
    \(\(OreZeroSummand = OreSummand[0, OreOneMonomial];\)\), "\n", 
    \(\(OreOne\  = \ OPo[1];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Ausgabeformatierungen, um ein lesbares Polynomformat zu \
erhalten\
\>", "Subsection",
  InitializationCell->True],

Cell["\<\
Die folgenden Ausgabe\[ADoubleDot]nderungen sind eher \
provisorischer Natur. Es tauchen noch einige nicht so sch\[ODoubleDot]ne Ph\
\[ADoubleDot]nomene auf. Hauptnachteil f\[UDoubleDot]r die Anwendung ist das \
copy/paste nicht funktioniert.\
\>", "Text"],

Cell[BoxData[{
    \(\(Format\ [
          OreOneMonomial] := "\<\>";\)\  (*"\< Faktor 1 weglassen. \>"*) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Format\ [
          OreMonomial[
            x_]]\  ^:= \  (*"\< Einzelne Potenz Darstellen. \>"\
*) \[IndentingNewLine]OreOperatorNames[x[\([1]\)]]^x[\([2]\)];\)\), "\n", 
    \(\(Format\ [
          OreMonomial[
            x__]]\  ^:= \  (*"\< Mehrere Potenzen hintereinanderschreiben. \
\>"*) \[IndentingNewLine]Infix[\[IndentingNewLine]Map[\(OreOperatorNames[#1]^#\
2 &\) @@ \ Sequence[#] &, {x}]\[IndentingNewLine], "\<\>"];\)\), "\n", 
    \(\(Format[OreSummand[x_, OreOneMonomial]] ^:= x;\)\), "\n", 
    \(Format[OreSummand[1, m_OreMonomial]] ^:= 
      m; \  (*"\< skip Factor One. \>"*) \ \n
    Format[x_OreSummand]\  ^:= \ 
      Infix[x\ , "\<\>"];\n\), "\[IndentingNewLine]", 
    \(\(Format[OrePolynomial[x_OreSummand]] ^:= x;\)\), "\n", 
    \(\(Format[OrePolynomial[x__OreSummand]] ^:= \[IndentingNewLine]Infix[
          OrePolynomial[x], "\<+\>"];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Hier ist die eigentliche Ausgabeformatierung beendet. Es folgt ein \
Format f\[UDoubleDot]r die nichtausgef\[UDoubleDot]hrte
Ore-Multiplikation. Eine nicht ausgef\[UDoubleDot]hrte Multiplikation von \
Ore-Objekten weist im Allgemeinen
auf einen Fehler bei den Berechnungen hin.\
\>", "Text"],

Cell[BoxData[
    \(Format[OreMultiplication[x__]] ^:= 
      Infix[OreMultiplication[x], "\<*@*\>"]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attribute der Datenstrukturen.", "Subsection",
  InitializationCell->True],

Cell["\<\
OrePolynome als reine Container sind nicht zu schachteln: \
OPo[x,OPo[y]]=OPo[x,y],
OreMonome werden obendrein stets sortiert dargestellt: Operatorvariablen \
unter sich kommutieren!\
\>", "Text"],

Cell[BoxData[{
    \(\(SetAttributes[OrePolynomial, \ Flat];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[OreMonomial, {Flat, Orderless}];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Funktionen um Auskunft \[UDoubleDot]ber den aktuellen Zustand zu \
geben.", "Subsection",
  InitializationCell->True],

Cell["Die Objekte in der momentan gew\[ADoubleDot]hlten Reihenfolge:", "Text"],

Cell[BoxData[
    \(\(OreOrderedListOfObjects := 
        Table[\[IndentingNewLine]OreListOfOrderObjects[\([\[IndentingNewLine]\
OreOrderVector[\([i]\)]\[IndentingNewLine]]\)], {i, 1, 
            OreNumberOfObjects}\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["Der Gesamtstatus der Datenstruktur:", "Text"],

Cell[BoxData[
    \(\(OreShowStatus\  := \((\[IndentingNewLine]Print["\< \
OreNumberOfVariables: \>", 
            OreNumberOfVariables]; \[IndentingNewLine]Print["\< \
OreNumberOfOperators: \>", 
            OreNumberOfOperators]; \[IndentingNewLine]Print["\< \
OreNumberOfObjects: \>", 
            OreNumberOfObjects]; \[IndentingNewLine]Print["\<OperatorNames: \
\>", Table[OreOperatorNames[i], {i, 1, 
                OreNumberOfOperators}]]; \
\[IndentingNewLine]Print["\<\[Sigma]`s: \>", 
            Table[Sigma[i], {i, 1, 
                OreNumberOfOperators}]]; \
\[IndentingNewLine]Print["\<\[Delta]`s: \>", 
            Table[Delta[i], {i, 1, 
                OreNumberOfOperators}]]; \
\[IndentingNewLine]Print["\<\[Delta]`s: \>", 
            Table[OreOperatorNames[i], {i, 1, 
                OreNumberOfOperators}]]; \
\[IndentingNewLine]Print["\<OperatorVariables: \>", 
            Table[OreVariables[\([i]\)], {i, 1, 
                OreNumberOfVariables}]]; \
\[IndentingNewLine]Print["\<OreOperators: \>", 
            Table[OreOperators[\([i]\)], {i, 1, 
                OreNumberOfOperators}]]; \
\[IndentingNewLine]Print["\<OreListOfOrderObjects: \>", \
\[IndentingNewLine]OreListOfOrderObjects]; \[IndentingNewLine]Print["\<In \
current 'canonical Order': \>", \[IndentingNewLine]OreOrderedListOfObjects\
\[IndentingNewLine]] (*"\<Print\>"*) ; \[IndentingNewLine]Print["\<Ordered \
via Matrix:\>", 
            OreCurrentMatrix\[IndentingNewLine]];\[IndentingNewLine])\);\)\)],\
 "Input",
  InitializationCell->True],

Cell["\<\
Die folgende Funktion ist praktisch, um die aktuelle Ordnung \
festzuhalten. 
Ihre Ausgabe kann direkt als Eingabe f\[UDoubleDot]r OreRedefineOrder \
verwendet werden, 
OreGetMonomOrder kapselt das Ergebnis in eine Liste.\
\>", "Text"],

Cell[BoxData[{
    \(\(OreOrderData[] \
:= \[IndentingNewLine]Sequence[\[IndentingNewLine]OreOrderedListOfObjects, \
\[IndentingNewLine]OreCurrentMatrix\ ];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(OreGetMonomOrder[] := {OreOrderData[]};\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Funktionen zum Modifizieren der Bestehenden Algebrastruktur.", "Section"],

Cell[CellGroupData[{

Cell[" Neue Objekte einf\[UDoubleDot]hren.", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Den internen Zustand den aktuellen Objektlisten anpassen", \
"Subsubsection"],

Cell["\<\
Die Buchhaltung auf den neuen Stand bringen, die Ordnung wieder \
anpassen, Remembereffekte r\[UDoubleDot]ckg\[ADoubleDot]ngig machen.\
\>", \
"Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(UpdateCounter := \ \[IndentingNewLine]Module[{}, \
\[IndentingNewLine]OreNumberOfOperators = 
            Length[OreOperators]; \[IndentingNewLine]OreListOfOrderObjects = 
            Flatten[{OreOperators, 
                OreVariables}]; \[IndentingNewLine]OreDefineLexOrder; \
\[IndentingNewLine]Clear[
            OreExp2Vec]; \[IndentingNewLine]MakeOreExp2Vec; \
\[IndentingNewLine]Clear[
            MonomToVector]; \[IndentingNewLine]MakeMonomToVector\
\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Hilfsfunktion: Test, ob eine Variable schon belegt ist, oder ein \
zul\[ADoubleDot]ssiges Symbol. 
HoldAll sorgt daf\[UDoubleDot]r, da\[SZ] die Argumente nicht schon beim \
Aufruf ausgewertet werden,
falls das m\[ODoubleDot]glich ist.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SetAttributes[
        SymbolicQuest, {HoldAll, \ Listable}];\)\), "\[IndentingNewLine]", 
    \(\(SymbolicQuest[v_] := \(! ValueQ[v]\);\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Neue Variablen einfuehren. ", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[OreDeclareVariables];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[OreDeclareVariables, 
        HoldAll];\)\), "\[IndentingNewLine]", 
    \(\(\(OreDeclareVariables::"\<NonSymbolic\>" = "\<There are non symbolic \
arguments.\>";\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(OreDeclareVariables[
          L_List] := \[IndentingNewLine]Module[{NewVars}, \
\[IndentingNewLine]If[\(! And @@ 
                SymbolicQuest[
                  L]\), \  (*"\< any non-symbolic Variables? \>"\
*) \[IndentingNewLine]\(Message[
                OreDeclareVariables::"\<NonSymbolic\>"];\)\[IndentingNewLine]]\
; \[IndentingNewLine]If[\ 
            OreNumberOfVariables > 
              0, \  (*"\< We have already Variables ? \>"\
*) \[IndentingNewLine]NewVars\  = \ 
              Complement[L, 
                OreVariables]; \ \  (*"\< really new Variables. \>"\
*) \[IndentingNewLine]OreVariables = 
              Join[OreVariables, 
                NewVars]; \  (*"\< Append them all. \
\>"*) \[IndentingNewLine]OreNumberOfVariables\  = \ 
              Length[OreVariables];\  (*"\< update number. \>"\
*) \[IndentingNewLine],  (*"\< Else: We have no Variables declared jet. \>"\
*) \[IndentingNewLine]OreVariables\  = \ 
              L; \[IndentingNewLine]OreNumberOfVariables = 
              Length[L];\[IndentingNewLine]]; \
\[IndentingNewLine]OreListOfOrderObjects = 
            Flatten[{OreOperators, 
                OreVariables}]; \[IndentingNewLine]UpdateCounter;\
\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Neue Operatoren einf\[UDoubleDot]hren", "Subsubsection"],

Cell["\<\
Hilfsfunktionen um nichttriviale Substitutionen aus einer Liste von \
Substitutionsregeln herauszufinden.\
\>", "Text"],

Cell[BoxData[{
    \(\(FindNonZeroRules[r_List] := \ 
        Select[r, #[\([2]\)] =!= 0 &];\)\), "\n", 
    \(\(FindNonIdentRules[r_List] := \ 
        Select[r, #[\([2]\)] =!= #[\([1]\)] &];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Den variablen Teil eines Polynomes bzgl. der geg. Variablenliste \
finden: es wird einfach der Konstante Part abgezogen.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(VariablePart[P_, variables_List] := 
        P - \((P /. Thread[variables \[Rule] 0])\);\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Allgemeinen Operator anf\[UDoubleDot]gen.", "Subsubsection"],

Cell["\<\
 Neue Operatoren einf\[UDoubleDot]hren und die interne Struktur \
konsistent halten.
Im ersten Schritt werden Namenssymbol und Operation in die \
zuge\[ODoubleDot]rigen Listen eingetragen.
Mittels OreDeclareVariables werden dann die in den Sigma- und Deltalisten \
auftauchenden neuen 
Variablen aufgenommen.
Der in Form von Rules \[UDoubleDot]bergebene Algebrahomomorphismus Sigma wird \
als reine Funktion in
die Liste der Sigmas eingetragen.
Anschlie\[SZ]end wird die Sigma-Derivation Delta nach theoretischen \
\[CapitalUDoubleDot]berlegungen aus der 
Arbeit aus dem gegebenene Sigma aufgebaut und ebenfalls als reine Funktion \
abgespeichert.
\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(OreDefineOperator[Name_Symbol, \ SigmaX_List, \ DeltaX_List, \ 
        Op_Function] := \[IndentingNewLine]Module[{Y, n, \ fDelt, \ dVars, \ 
          fSig}, \[IndentingNewLine]OreNumberOfOperators = 
          OreNumberOfOperators + 
            1; \[IndentingNewLine]With[{n = 
              OreNumberOfOperators}, \[IndentingNewLine]OreOperatorNames[n] = 
            Name; \ \[IndentingNewLine]Operation[n] = 
            Op; \ \[IndentingNewLine]OreDeclareVariables[\[IndentingNewLine]\
Evaluate[Union[Flatten[{\(First[#] &\) /@ SigmaX, \(First[#] &\) /@ 
                      DeltaX}]]]\[IndentingNewLine]]; \[IndentingNewLine]fSig \
= FindNonIdentRules[SigmaX]; \[IndentingNewLine]Sigma[
              n] = \ # /. \ 
                fSig\  &; \  (*"\< Algebrahomomorphisus anwenden \>"\
*) \[IndentingNewLine]\[IndentingNewLine] (*"\< Delta kann nur die Null- eine \
Kombination partieller;\[IndentingNewLine]  Ableitungen fuer \[Sigma] = id , \
oder eine innere \[Sigma]-Derivation ;\[IndentingNewLine]  fuer \[Sigma] \
\[NotEqual] id sein : \>"*) \[IndentingNewLine]fDelt = 
            FindNonZeroRules[DeltaX]; \[IndentingNewLine]If[
            fDelt === {}, \  (*"\< Nullderivation. \
\>"*) \[IndentingNewLine]Delta[n]\  = \ 
              0 &\ \ \ ; \[IndentingNewLine]OreOperators = 
              Append[OreOperators, 
                OrePolynomial[OreSummand[1, OreMonomial[{n, 1}]]]]; 
            UpdateCounter; \[IndentingNewLine]Return[
              OreOperators[\([OreNumberOfOperators]\)]\ \
]\[IndentingNewLine]]; \[IndentingNewLine]If[
            fSig === {}, \ \ \ \ \  (*"\< Kombination vielfacher \>" 
                klassischer "\< Derivationen, \[Sigma]=id \>"\
*) \[IndentingNewLine] (*"\< Regeln fuer Partielle Ableitungen aus den \
Substitutionen bestimmen.  \>"*) \[IndentingNewLine]dVars = 
              Map[First[#] &, 
                fDelt]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*"\< fuer Delta \
relevante Variablen.   \>"*) \[IndentingNewLine]Delta[n]\  = \ 
              Function[{P}, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
 (*"\< Summe der partiellen Ableitungen. \>"*) \[IndentingNewLine]Plus @@ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*"\< \
Ueber die EinzelAbleitungen aufsummieren ... \>"*) \[IndentingNewLine]Map[\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*"\< Jede \
Substitution aus fDelt einzeln anwenden ... \
\>"*) \[IndentingNewLine]#[\([2]\)] 
                        D[P, First[#]] &, \[IndentingNewLine]fDelt\ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*"\< Fuer jede der Regeln. \>"\
*) \[IndentingNewLine]]\[IndentingNewLine]]; \  (*"\< Function \>"\
*) \[IndentingNewLine]]; \[IndentingNewLine]\[IndentingNewLine]If[\((fDelt =!= \
{})\) && \((fSig =!= {})\), \  (*"\< Es liegt eine innere Derivation vor! \>"\
*) \[IndentingNewLine]Y[n] = 
              Together[\[IndentingNewLine]\((\(fSig[\([1]\)]\)[\([1]\)] /. 
                      fDelt\ )\)/\  (*"\< Erstes X mit \
\[Sigma](X)\[NotEqual]X waehlen! \
\>"*) \[IndentingNewLine]\((\(fSig[\([1]\)]\)[\([1]\)] - \
\(fSig[\([1]\)]\)[\([2]\)])\)\ \  (*"\< Vorfaktor Y[n]=\[Delta](X) / (X-\
\[Sigma](X)) \>"*) \[IndentingNewLine]]; \[IndentingNewLine]Delta[n]\  = \ 
              Together[
                  Y[n]\ \ \((#\  - \(Sigma[
                            n]\)[#])\)] &; \  (*"\< Innere \
\[Sigma]-Derivation \>"*) \[IndentingNewLine]]; \[IndentingNewLine] (*"\< \
Operator verpacken und in die Liste einreihen. \
\>"*) \[IndentingNewLine]OreOperators = 
            Append[OreOperators, 
              OrePolynomial[
                OreSummand[1, 
                  OreMonomial[{n, 
                      1}]]]]; \[IndentingNewLine]UpdateCounter; \
\[IndentingNewLine]OreOperators[\([OreNumberOfOperators]\)]\ \  (*"\< neuen \
Operator zur\[UDoubleDot]ck \>"*) \[IndentingNewLine]]\  (*"\< With n = \
...\>"*) \[IndentingNewLine]]\)\(;\)\(\ \)\( (*"\< Define Ore Operator \>"*) \
\)\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spezielle Operatoren:", "Subsubsection"],

Cell["\<\
Der Shift-Operator.
Hier kann OperatorPowerTimesSummand, also p-faches Shiften um 1 effizient als \
eine einzige Substitution realisiert werden.\
\>", "Text"],

Cell[BoxData[
    \(\(OreDefineShift[opname_Symbol, \ 
          varname_Symbol] := \[IndentingNewLine]Module[{Res}, \
\[IndentingNewLine]Res = 
            OreDefineOperator[
              opname, \ {varname \[Rule] \ 
                  varname + 1}, \ {varname\  \[Rule] \ 
                  0}, \ # /. {varname\  \[Rule] \ 
                      varname + 
                        1} &]; \
\[IndentingNewLine]OperatorPowerTimesSummand[{Res[\([1, 2, 1, 1]\)], p_}, 
              m_] := \[IndentingNewLine]\((\[IndentingNewLine]\
OperatorPowerTimesSummand[{Res[\([1, 2, 1, 1]\)], p}, 
                  m] = \[IndentingNewLine]{{First[
                        m] /. {varname\  \[Rule] \ varname + p}, 
                    OreMonomial[{Res[\([1, 2, 1, 1]\)], p}, 
                      m[\([2]\)]]}}\[IndentingNewLine])\); \ \
\[IndentingNewLine]Res\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Der Differentialoperator. Auch hier wird OperatorPowerTimesSummand \
extra definiert.\
\>", "Text"],

Cell[BoxData[
    \(\(OreDefineDiff[opname_Symbol, \ 
          varname_Symbol] := \[IndentingNewLine]Module[{Res}, \
\[IndentingNewLine]Res = 
            OreDefineOperator[
              opname, \ {varname \[Rule] varname}, \ {varname\  \[Rule] \ 
                  1}, \ D[#, 
                  varname] &]; \ \ OperatorPowerTimesSummand[{Res[\([1, 2, 1, 
                    1]\)], p_}, 
              m_] := \[IndentingNewLine]\((\[IndentingNewLine]\
OperatorPowerTimesSummand[{Res[\([1, 2, 1, 1]\)], p}, 
                  m] = \[IndentingNewLine]Module[{Rlist, \[Phi] = m[\([1]\)], 
                    i}, \[IndentingNewLine]Prepend[\[IndentingNewLine]Table[\
\[IndentingNewLine]{\ \[Phi] = D[\[Phi], varname]; Binomial[p, i] \[Phi], 
                        OreMonomial[{Res[\([1, 2, 1, 1]\)], p - i}, 
                          m[\([2]\)]]}, {i, 1, 
                        p}\[IndentingNewLine]], \
\[IndentingNewLine]{m[\([1]\)], 
                      OreMonomial[{Res[\([1, 2, 1, 1]\)], p}, 
                        m[\([2]\)]]}\[IndentingNewLine]]\[IndentingNewLine]]\
\[IndentingNewLine])\); \[IndentingNewLine]Res\n];\)\)], "Input",
  InitializationCell->True],

Cell["Die q-Differentiation. ", "Text"],

Cell[BoxData[
    \(\(OreDefineQDifferentiation[opname_Symbol, \ varname_Symbol, \ 
          qname_Symbol] := \[IndentingNewLine]OreDefineOperator[
          opname, \ {varname \[Rule] qname\ varname}, \ {varname\  \[Rule] \ 
              1}, Together[\((\((# /. {varname \[Rule] \ 
                            qname\ varname})\) - #)\)/\((\((qname - 1)\) 
                    varname)\)] &\ \ ];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Der Dummy-Operator ist ein Kommutativer Operator, der keine \
Variable beeinflu\[SZ]t.\
\>", "Text"],

Cell[BoxData[
    \(\(OreDefineDummy[
          opname_Symbol]\  := \ \[IndentingNewLine]OreDefineOperator[
          opname, \ {}, \ {}, #\ opname &];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Die Grundoperationen.", "Section"],

Cell["\<\
ExpandedCollect ist eine Hilfsfunktion, die in einem Ausdruck die \
Monome in Ore-Variablen isoliert und optional eine Funktion auf den \
Koeffizienten ausf\[UDoubleDot]hrt. 
(Thanks to Carl Woll, Physics Dept, U of Washington )\
\>", "Text"],

Cell[BoxData[
    \(\(ExpandedCollect[expr_, vars_, h_:  Identity] := 
        Module[{sub}, 
          Expand[Collect[expr, vars, sub]] /. sub \[Rule] h];\)\)], "Input",
  InitializationCell->True],

Cell["Grundlegende Vereinfachungen und Abk\[UDoubleDot]rzungen.", "Text"],

Cell[BoxData[{
    \(\(OPo[x_OrePolynomial] := \ x;\)\), "\[IndentingNewLine]", 
    \(\(OPo[x_OreSummand] := \ OrePolynomial[x];\)\), "\n", 
    \(\(OPo[x_OreMonomial] := \ OrePolynomial[OreSummand[1, x]];\)\), "\n", 
    \(\(OPo[x_ /; OreVarMonomialQ[x]]\  := \ 
        OrePolynomial[OreSummand[x, OreOneMonomial]];\)\), "\n", 
    \(\(OPo[x_]\  := \ 
        OPo /@ \((ExpandedCollect[x, OreVariables])\);\)\), "\n", 
    \(\(OMu[x___] := OreMultiplication[x];\)\), "\[IndentingNewLine]", 
    \(\(OMu[a_, b_, c__] := OMu[a, OMu[b, c]];\)\ \), "\[IndentingNewLine]", 
    \(\(OreTerm[x___] := OMu @@ \((OPo /@ {x})\);\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Operationen zum Umgang mit den Monomen in den Ore Variablen ", \
"Subsection"],

Cell[CellGroupData[{

Cell["\<\
Wandeln von OrePolynomen in ihre Exponentenvektoren und zur\
\[UDoubleDot]ck.\
\>", "Subsubsection"],

Cell["\<\
Einen Ausdruck in eine Linearkombination von Monomen in den \
OreVariablen expandieren.\
\>", "Text"],

Cell[BoxData[
    \(\(OreVarExpand[f_] := ExpandedCollect[f, OreVariables];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Testen, ob mit dem gegebenen Ausdruck ein Monom in Ore-Variablen \
vorliegt. 
Also ein in den Ore Variablen homogenes,  summenfreies Polynom.\
\>", "Text"],

Cell[BoxData[
    \(\(\(OreVarMonomialQ[
          a_] := \[IndentingNewLine]PolynomialQ[a, 
            OreVariables] && \ \ \ \  (*"\< must be Polynomial and \>"\
*) \[IndentingNewLine]\((FreeQ[a, 
                x_ /; MemberQ[OreVariables, 
                    x]]\  || \ \[IndentingNewLine]Head[OreVarExpand[a]] =!= 
                Plus)\);\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Ein Monom wandeln in eine (Gem\[ADoubleDot]\[SZ] Auftauchens in \
\"OreVariables\") geordnete Liste L der Exponenten.
R\[UDoubleDot]ckgabe des Faktors und der Liste.  R\[UDoubleDot]ckagabe von \
a,L.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExtendedExp2Vec[
          f_ /; OreVarMonomialQ[f]] := \[IndentingNewLine]Module[{L, 
            a}, \[IndentingNewLine]a = 
            f /. Thread[
                OreVariables \[Rule] \ 
                  1]; \  (*"\< None-Ore-Factor \>"*) \[IndentingNewLine]L = 
            Rest[FactorList[
                f]]; \  (*"\< Factors not equal 1 \>"*) \ \
\[IndentingNewLine]L = 
            Join[Map[#[\([1]\)] \[Rule] \ #[\([2]\)] &, L], 
              Map[# \[Rule] 0 &, 
                OreVariables]]; \  (*"\< Make x\[Rule]i from{x,i}.\>"\
*) \[IndentingNewLine]L = 
            OreVariables /. 
              L; \  (*"\< Substitute Vars in List by Exponents. \>"\
*) \[IndentingNewLine]Return[{a, L}];\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
 Wegen Remembereffekten mu\[SZ] OreExp2Vec \[ODoubleDot]fter \
neudefiniert werden. \
\>", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MakeOreExp2Vec := \((\[IndentingNewLine]\(OreExp2Vec[
                f_ /; OreVarMonomialQ[f]] := \[IndentingNewLine]\((OreExp2Vec[
                    f] = \[IndentingNewLine]\(OreExtendedExp2Vec[
                      f]\)[\([2]\)]\[IndentingNewLine])\);\)\
\[IndentingNewLine])\);\)\), "\[IndentingNewLine]", 
    \(\(MakeOreExp2Vec;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \( (*"\< OreVec2OPo[v_] Wandelt die Vektordarstellung in ein Monom \
zurueck. \>"*) \)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "OreVec2Mon: R\[UDoubleDot]ckumwandlung eines Vektors in das zugeh\
\[ODoubleDot]rige Monom",
  StyleBox[". Rememberprogrammierung ist vorerst auskommentiert.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[
    \(\(OreVec2Mon[
          v_] := \[IndentingNewLine]\(( (*"\< OreVec2Mon[v]= \>"\
*) \[IndentingNewLine]OreMonomial @@ 
            Transpose[{Table[i, {i, OreNumberOfOperators}], 
                Take[v, 
                  OreNumberOfOperators]}]\[IndentingNewLine])\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(OreVec2OPo[
          v_] := \[IndentingNewLine]\(( (*"\< OreVec2OPo[v]= \>"\
*) \[IndentingNewLine]OrePolynomial[\[IndentingNewLine]OreSummand[\
\[IndentingNewLine]Times @@ \((OreVariables^
                    Take[v, \(-OreNumberOfVariables\)])\), \
\[IndentingNewLine]OreMonomial @@ 
                Transpose[{Table[i, {i, OreNumberOfOperators}], 
                    Take[v, 
                      OreNumberOfOperators]}]\[IndentingNewLine]]\
\[IndentingNewLine]]\[IndentingNewLine])\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MakeMonomToVector := \((\[IndentingNewLine]MonomToVector[
              OreOneMonomial] := 
            Table[0, {OreNumberOfOperators}]; \
\[IndentingNewLine]MonomToVector[
              m_OreMonomial] := \((\[IndentingNewLine]MonomToVector[
                  m] = \[IndentingNewLine]Module[{T}, \[IndentingNewLine]T = 
                    Table[0, {i, 1, 
                        OreNumberOfOperators}]; \[IndentingNewLine]For[
                    i = 1, \ 
                    i <= Length[
                        m], \(i++\), \[IndentingNewLine]\ \(T[\([\ 
                            m[\([i, 1]\)]\ ]\)] = \ 
                        m[\([i, 
                            2]\)]\ ;\)\[IndentingNewLine]]; \
\[IndentingNewLine]T\[IndentingNewLine]])\)\[IndentingNewLine])\);\)\), "\
\[IndentingNewLine]", 
    \(\(MakeMonomToVector;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SummandToVector[
          f_OreSummand] := \ \
\[IndentingNewLine]Join[\[IndentingNewLine]MonomToVector[
            f[\([2]\)]]\[IndentingNewLine], \[IndentingNewLine]OreExp2Vec[
            f[\([1]\)]]\ ];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OrePolynomialToVector[
          OrePolynomial[f_]] := \[IndentingNewLine]SummandToVector[
          f];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operationen in direktem Zusammenhang mit Ordnungen", "Subsection"],

Cell[CellGroupData[{

Cell["Ordnung auf Zahlenvektoren.", "Subsubsection"],

Cell[" Lexikographisch ", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(VectorLessLex[a_List, b_List] := \(! OrderedQ[{b, a}]\);\)\)], "Input",\

  InitializationCell->True],

Cell[" umgekehrt Lexikographisch ", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(VectorLessInvLex[a_List, 
          b_List] := \[IndentingNewLine]\(! OrderedQ[{Reverse[b], 
              Reverse[a]}]\);\)\)], "Input",
  InitializationCell->True],

Cell[" Grad - Lexikographisch ", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(VectorLessDegLex[a_List, 
          b_List] := \[IndentingNewLine]Module[{A = Plus @@ a, 
            B = Plus @@ b}, \[IndentingNewLine]A < 
              B\  || \((\((A === B)\) && \ \ VectorLessLex[a, 
                  b])\)\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[" Grad - umgekehrt Lexikographisch ", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(VectorLessDegInvLex[a_List, 
          b_List] := \[IndentingNewLine]Module[{A = Plus @@ a, 
            B = Plus @@ b}, \[IndentingNewLine]A < 
              B\  || \((\((A === B)\) && \ \ VectorLessInvLex[a, 
                  b])\)\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["Beliebige Matrixordnung. ", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(VectorLessMatrix[a_List, b_List, 
          M /; MatrixQ[M]] := \[IndentingNewLine]VectorLessLex[a . M, 
          b . M];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ordnung auf Ore-Summanden. ", "Subsubsection",
  InitializationCell->True],

Cell["Tests, ob ein Monom vorliegt, ob dieses monisch ist.", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(OreIsSummandQ[
          P_OrePolynomial]\  := \ \((Length[P] \[Equal] 1)\);\)\), "\n", 
    \(\(OreIsMonicQ[P_OrePolynomial]\  := 
        OreIsSummandQ[P] && \ \(OreExtendedExp2Vec[P[\([1, 1]\)]]\)[\([1]\)] === 
            1;\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Im folgenden werden spezielle Ordnungen \[UDoubleDot]ber \
Matrixordnungen realisiert.\
\>", "Text"],

Cell[BoxData[
    \( (*"\< Lexikografische Ordnung \>"*) \)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(OreDefineLexOrder := \((OreRedefineMonomOrder[OreListOfOrderObjects, 
            IdentityMatrix[
              OreNumberOfObjects]])\);\)\[IndentingNewLine]\[IndentingNewLine]\
 (*"\< Default: Lexikografisch \>"*) \), "\n", 
    \(\(OreDefineLexOrder;\)\[IndentingNewLine]\[IndentingNewLine] (*"\< \>" 
        Inverse "\< Lexikografische Ordnung \>"*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(OreDefineReverseLexOrder := \[IndentingNewLine]OreRedefineMonomOrder[
          OreListOfOrderObjects, 
          Reverse[IdentityMatrix[
              OreNumberOfObjects]]];\)\[IndentingNewLine]\[IndentingNewLine] \
(*"\< --\[Rule] \>"*) \), "\n", 
    \(\(OreDefineDegLexOrder\  := \[IndentingNewLine]OreRedefineMonomOrder[
          OreListOfOrderObjects, \[IndentingNewLine]Prepend[\
\[IndentingNewLine]Rest[
              IdentityMatrix[OreNumberOfObjects]], \[IndentingNewLine]Table[
              1, {OreNumberOfObjects}]\[IndentingNewLine]]\[IndentingNewLine]]\
;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(OreDefineReverseDegLexOrder\  \
:= \[IndentingNewLine]OreRedefineMonomOrder[
          OreListOfOrderObjects, \[IndentingNewLine]Prepend[\
\[IndentingNewLine]Reverse[
              1 - Rest[
                  IdentityMatrix[
                    OreNumberOfObjects]]\[IndentingNewLine]], \
\[IndentingNewLine]Table[
              1, {OreNumberOfObjects}]\[IndentingNewLine]]\[IndentingNewLine]]\
;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ordnung auf OreSummanden und OrePolynomen definieren:", "Subsubsection",
  InitializationCell->True],

Cell["\<\
Dabei bedeutet \"/:\", da\[SZ] nicht \"<\" (Less) umdefiniert wird, \
sondern die Definition an
\"OreSummand\" gebunden ist.\
\>", "Text"],

Cell[BoxData[{
    \(\(OreSummand /: \ OreZeroSummand\  < \ OreZeroSummand := \ 
        False;\)\), "\[IndentingNewLine]", 
    \(\(OreSummand /: \ OreZeroSummand\  < _OreSummand\  := \ 
        True;\)\), "\[IndentingNewLine]", 
    \(\(\(OreSummand /: \ 
        a_OreSummand\  < b_OreSummand\  := \ \[IndentingNewLine]VectorLess[
          SummandToVector[a], SummandToVector[b]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(OrePolynomial /: \ 
        a_OrePolynomial < 
          b_OrePolynomial := \[IndentingNewLine]First[OreSimplify[a]] < 
          First[OreSimplify[b]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Umdefinieren der Ordnung auf den Multiindizees ", "Subsubsection",
  InitializationCell->True],

Cell["\<\
Hilfsfunktion: Eine Matrix oben links in eine Einheitsmatrix \
einschreiben. \
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(RenderMatrix[A0_, 
          Lgt_Integer] := \[IndentingNewLine]Module[{A = A0, 
              i}, \[IndentingNewLine]m = 
              Length[A[\([1]\)]]; \[IndentingNewLine]A = 
              Map[Join[#, Table[0, {Lgt - m}]] &, 
                A]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\  (*"\< rechts um Nullen ausbauen \>"*) \[IndentingNewLine]A = 
              Join[A, Table[
                  Table[0, {Lgt}], {Lgt - 
                      Length[A]}]]; \  (*"\< nach unten ausbauen \>"\
*) \[IndentingNewLine]For[i = m + 1, \ 
              i \[LessEqual] 
                Lgt\ , \(i++\), \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  (*"\< Diagonale mit Einsen auffuellen. \>"*) \[IndentingNewLine]\(A = 
                  ReplacePart[\ A, 
                    1, {i, i}];\)\ \[IndentingNewLine]]; \[IndentingNewLine]A\
\[IndentingNewLine]] /; Length[A0[\([1]\)]] \[LessEqual] \ Lgt;\)\)], "Input",\

  InitializationCell->True],

Cell["Liegt eine einzelne Unbestimmte vor?", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimpleObjectQ[P_OrePolynomial] := 
        Module[{v}, \[IndentingNewLine]If[\(! OreIsMonicQ[P]\), 
            Return[False]]; \[IndentingNewLine]v = 
            SummandToVector[P]; \[IndentingNewLine]Return\ [
            1 === Plus @@ \((\(If[# =!= 0, 1, 0] &\) /@ 
                    v)\)]; \  (*"\< genau ein Objekt vorhanden\>"\
*) \[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Umdefinieren der aktuellen Monomordnung: 
Zu den \[UDoubleDot]bergebenen Monomen in ihrer Reihenfolge wird die \
\[UDoubleDot]bergebene Matrixordnung zu einer Matrixordnung
f\[UDoubleDot]r alle Unbestimmten ausgebaut. 
Dazu wird die entsprechende Matrix f\[UDoubleDot]r die interne Ordnung \
berechnet. \
\>", "Text"],

Cell[BoxData[
    \(\(\(OreRedefineMonomOrder[Monomials_List, \ 
        M_List]\  := \[IndentingNewLine]Catch[\(Module[{Perm, \ A, 
              Dummy}, \[IndentingNewLine]If[\  (*"\< Liegen wirklich Monome \
vor? \>"*) \[IndentingNewLine]Apply[And, 
                  Map[SimpleObjectQ[#] &, 
                    Monomials]]\  || \  (*"\< All simple Objects? \>"\
*) \[IndentingNewLine]Length[Monomials] =!= 
                  Length[Union[
                      Monomials]], \  (*"\< not pairwise different? \>"\
*) \[IndentingNewLine]Throw["\<given Polynomials can't be used to define an \
order.\>"]\[IndentingNewLine]]; \[IndentingNewLine]If[
              Not[MatrixQ[
                  M]], \[IndentingNewLine]Throw["\<The second argument of \
OreRedefineMonomOrder should be a matrix.\>"]\[IndentingNewLine]]; \
\[IndentingNewLine]If[
              Dimensions[M] =!= {Length[Monomials], 
                  Length[Monomials]}, \[IndentingNewLine]Throw["\<The matrix \
is not of the correct form.\>"]\[IndentingNewLine]]; \[IndentingNewLine]If[
              Det[M] == 
                0, \[IndentingNewLine]Throw["\<The order matrix is \
singular.\>"]\[IndentingNewLine]]; \[IndentingNewLine]\[IndentingNewLine] (*"\
\< Die geg. Monome in eine Liste der Indizees der internen Reihenfolge \
uebersetzen. Anbei Gueltigkeit checken. \>"*) \[IndentingNewLine]v = 
              Table[\[IndentingNewLine]If[
                  Head[Monomials[\([i]\)]] =!= 
                    OrePolynomial, \  (*"\< Variable? \>"\
*) \[IndentingNewLine]If[\[IndentingNewLine]MemberQ[OreVariables, 
                      Monomials[\([i]\)]], \  (*"\< registrierte Variable? \
\>"*) \[IndentingNewLine]OreNumberOfOperators + 
                      Plus @@ \(Flatten @@ 
                          Position[OreVariables, 
                            Monomials[\([i]\)]]\)\[IndentingNewLine], \  \
(*"\< else \>"*) \[IndentingNewLine]\(Throw["\<Objects not valid\>"];\)\
\[IndentingNewLine]]\[IndentingNewLine], \  (*"\< else: Operator \>"\
*) \[IndentingNewLine]Monomials[\([i, 1, 2, 1, 
                      1]\)]\  (*"\< internal Number of that Operator\>"\
*) \[IndentingNewLine]], \[IndentingNewLine]{i, 1, 
                  Length[Monomials]}\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]With[{\ n = OreNumberOfObjects}, \[IndentingNewLine]v = 
                Join[v, 
                  Complement[Table[i, {i, n}], 
                    v]]; \  (*"\< Ergaenzen zur Gesammtobjektanzahl. \>"\
*) \[IndentingNewLine]OreOrderVector = 
                v; \[IndentingNewLine]\[IndentingNewLine]Perm = 
                Table[\(Position[v, i]\)[\([1, 1]\)], {i, 
                    n}]; \  (*"\< Umkehrpermutation bestimmen \>"\
*) \[IndentingNewLine]OreInternalToActual = Perm; \[IndentingNewLine]AA = 
                RenderMatrix[M, 
                  n]; \[IndentingNewLine]\[IndentingNewLine] (*"\< A wird \
Durch Spaltenumordnung an die reale interne Anordnung unserer Monome \
angepasst. \>"*) \[IndentingNewLine]\[IndentingNewLine]A = 
                Transpose[
                  Table[\(Transpose[AA]\)[\([Perm[\([i]\)]]\)], {i, 1, 
                      n}]];\[IndentingNewLine]\[IndentingNewLine]]; \  (*"\< \
With n = OreNumberOfOperators \>"*) \[IndentingNewLine]\[IndentingNewLine] \
(*"\< Umdefinieren der Monomordnung \>"*) \[IndentingNewLine]\
\[IndentingNewLine]VectorLess[a_List, 
                b_List] := \(! OrderedQ[{A . b, 
                    A . a}]\); \[IndentingNewLine]OreCurrentMatrix = 
              AA; \[IndentingNewLine]OreOrderVector = 
              v; \  (*"\< Kanonische Ordnung \>"*) \[IndentingNewLine]];\)\
\[IndentingNewLine]]\)\(;\)\(\ \)\( (*"\< Catch \>"*) \)\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operationen und Regeln f\[UDoubleDot]r Monome in den Ore Operatoren.", \
"Subsection",
  InitializationCell->True],

Cell["Mehrfach auftretende Operatoren werden zusammengefasst:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMonomial[{a_, x_}, {a_, y_}] := 
        OreMonomial[{a, x + y}];\)\)], "Input",
  InitializationCell->True],

Cell["Faktoren mit Exponent Null verschwinden:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMonomial[{_, 0}] := OreMonomial[];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Eine Funktion auf alle Koeffizienten der Operatormonome anwenden:\
\
\>", "Text"],

Cell[BoxData[
    \(\(OreMapOnCoefficients[f_Function, 
          P_OrePolynomial] := \[IndentingNewLine]Map[
          OreSummand[f[#[\([1]\)]], #[\([2]\)]] &, P];\)\)], "Input",
  InitializationCell->True],

Cell["Leitkoeffizient, Leitoperatoren, Leitterm und Leitmonom:", "Text"],

Cell[BoxData[{
    \(\(OreLeadingCoefficient[
          f_OrePolynomial] := \[IndentingNewLine]f[\([\)\(1, 
            1\)\(]\)] /. \((\(# \[Rule] 1 &\) /@ 
              OreVariables)\);\)\ \), "\n", 
    \(\(OreLeadingOperatorMonomial[
          f_OrePolynomial]\  := \[IndentingNewLine]\(OreSimplify[
            f]\)[\([\)\(1, 2\)\(]\)];\)\), "\n", 
    \(\(OreLeadingSummand[
          f_OrePolynomial]\  := \[IndentingNewLine]\(OreSimplify[
            f]\)[\([\)\(1\)\(]\)];\)\n\), "\[IndentingNewLine]", 
    \(\(OreLeadingMonomial[
          f_OrePolynomial]\  := \[IndentingNewLine]Block[{t = 
              OreLeadingSummand[
                f]}, \[IndentingNewLine]OreSummand[\[IndentingNewLine]First[
                t]/\((First[
                    t] /. \((\(# \[Rule] 1 &\) /@ 
                      OreVariables)\))\), \
\[IndentingNewLine]t[\([\)\(2\)\(]\)]\[IndentingNewLine]]\[IndentingNewLine]];\
\)\)}], "Input",
  InitializationCell->True],

Cell["Terme niedrigerer Ordnung als der Leitterm:", "Text"],

Cell[BoxData[
    \(\(OreLesserTerms[p_OrePolynomial]\  := \[IndentingNewLine]If[
          Length[p] > 1, \[IndentingNewLine]Rest[
            OreSimplify[
              p]]\[IndentingNewLine],  (*"\< else \
\>"*) \[IndentingNewLine]OreZero\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreCoefficientList[
          P_OrePolynomial]\  := \[IndentingNewLine]Table[
            P[\([i, 1]\)], {i, 1, Length[P]}] /. {Sequence @@ 
              Thread[OreVariables \[Rule] 1]};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Der Inhalt als GCD der Koeffizienten. Verbesserung: ",
  StyleBox["PolynomialGCD der Koeffizientenliste?",
    FontColor->RGBColor[0, 1, 0]]
}], "Text"],

Cell[BoxData[
    \(\(OreContent[P_OrePolynomial]\  := 
        PolynomialGCD @@ OreCoefficientList[P];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Variableninhalt: maximalen Linksfaktor als Polynom in den Ore \
Variablen finden:\
\>", "Text"],

Cell[BoxData[
    \(\(OreVarContent[
          P_OrePolynomial] := \[IndentingNewLine]Module[{tmp}, \
\[IndentingNewLine]tmp = 
            Sort[List @@ P, 
              Order[#1[\([2]\)], #2[\([2]\)]] \[Equal] 
                  1 &]; \[IndentingNewLine]tmp = 
            Split[tmp, #1[\([2]\)] \[Equal] #2[\([2]\)] &]; \
\[IndentingNewLine]tmp = \((Plus @@ \((First /@ #)\) &)\) /@ 
              tmp; \[IndentingNewLine]PolynomialGCD @@ 
            tmp\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
 Inhalt herausdividieren.                                     \
\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreEliminateContent[
          P_OrePolynomial] := \[IndentingNewLine]OreMapOnCoefficients[
          Together[#/OreContent[P]] &, P];\)\)], "Input",
  InitializationCell->True],

Cell["Variableninhalt herausk\[UDoubleDot]rzen:", "Text"],

Cell["\<\
 - Sortieren & Zusammenfassen nach Operatoren.
- Aufaddieren der zugeh\[ODoubleDot]rigen Variablen.
- Bilden des Polynom-GCD, herausdividieren. 
- neue Variablen mit den gemerkten Operatoren zusammenf\[UDoubleDot]gen. \
\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreVarEliminateContent[
          P_OrePolynomial] := \[IndentingNewLine]Module[{tmp, ops, 
            gc}, \[IndentingNewLine]tmp = 
            Sort[List @@ P, 
              Order[#1[\([2]\)], #2[\([2]\)]] \[Equal] 
                  1 &]; \[IndentingNewLine]tmp = 
            Split[tmp, #1[\([2]\)] \[Equal] #2[\([2]\)] &]; \
\[IndentingNewLine]ops = 
            Last /@ \(First /@ 
                tmp\); \[IndentingNewLine]tmp = \((Plus @@ \((First /@ #)\) \
&)\) /@ tmp; \[IndentingNewLine]gc = 
            PolynomialGCD @@ 
              tmp; \[IndentingNewLine]tmp = \(Together[#/gc] &\) /@ 
              tmp; \[IndentingNewLine]Inner[OMu[OPo[#1], OPo[#2]] &, tmp, 
            ops, Plus]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[" Abfragen, ob eine Einheit vorliegt:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreIsUnitQ[
          P_OrePolynomial] \
:= \[IndentingNewLine]\((OreLeadingOperatorMonomial[P] === 
              OreOneMonomial)\) && \((Variables[
                OreLeadingCoefficient[
                  P]] === {})\)\  && \ \ \((OreLeadingCoefficient[
                P] \[NotEqual] 0)\);\)\)], "Input",
  InitializationCell->True],

Cell["Einheit invertieren:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreInverse[
          P_OrePolynomial /; 
            OreIsUnitQ[
              P]] := \[IndentingNewLine]OPo[\((OreLeadingCoefficient[
                P])\)^\((\(-1\))\)];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Abfrage, ob ein OrePolynom nur aus einem Grundobjekt besteht:\
\>", \
"Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreIsObjectQ[
          M_] := \ \[IndentingNewLine]\((Head[M] === 
              OrePolynomial)\) && \((Length[M] \[Equal] 
              1)\) && \[IndentingNewLine]\((1 === 
              Plus @@ \(Abs /@ SummandToVector[First[M]]\))\);\)\)], "Input",
  InitializationCell->True],

Cell[" Bestimmen des Exponenten eines Objektes in einem Summanden:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExponent[M_OrePolynomial /; OreIsObjectQ[M], \ S_OreSummand] := \ 
        Plus @@ \[IndentingNewLine]\((SummandToVector[S]*
              SummandToVector[First[M]])\);\)\)], "Input",
  InitializationCell->True],

Cell["Exponent eines Objektes in einem Polynom:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreExponent[M_OrePolynomial /; OreIsObjectQ[M], \ 
          S_OrePolynomial] := \ \[IndentingNewLine]Max[\(OreExponent[
                M, #] &\) /@ \((List @@ S)\)];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Addition", "Subsection",
  InitializationCell->True],

Cell["\<\
Das zentrale Werkzeug ist OreSimplify, da\[SZ] Ore Polynome stets \
in eine Darstellung als geordnete Sume von Termen darstellt.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
OreSimplify: Liste von Ore Summanden aufaddieren und  vereinfachen. \
\
\>", "Subsubsection",
  InitializationCell->True],

Cell["Einige triviale Regeln:", "Text"],

Cell[BoxData[{
    \(\(OreSimplify[{}]\  := \ {OreZeroSummand};\)\), "\n", 
    \(\(\(OreSimplify[{OreSummand[
            0, _OreMonomial]}]\  := \ {OreZeroSummand}\)\(;\)\(\ \)\( (*"\< \
Term mit Faktor 0 entfernen. \
\>"*) \)\(\[IndentingNewLine]\)\(OreSimplify[{f_OreSummand}]\  := \ \
{f}\)\(;\)\(\ \)\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Vereinfachen einer Liste von Summanden. 
1. Aufsteigend nach der Monomordnung sortieren.
2. \"Runs\" gleicher Monome mittels \"Split\" gruppieren, und \
anschlie\[SZ]end die Koeffizienten aufaddieren.
3. Nullen Eliminieren und falls nichts \[UDoubleDot]brig bleibt, \
OreZeroSummand zur\[UDoubleDot]ckgeben.\
\>", "Text"],

Cell[BoxData[
    \(\(OreSimplify[
          f_List] := \ \ Module[{n, sumliste, runliste, zsumm, \ 
              Result}, \[IndentingNewLine]sumliste = 
              Sort[f, #2 < #1 &]; \ \ \[IndentingNewLine]runliste = \ 
              Split[sumliste, 
                SummandToVector[#1] === 
                    SummandToVector[#2] &]; \[IndentingNewLine]Result = \ \
\(OreSummand[Together[Plus @@ Map[#[\([1]\)] &, #]], #[\([1, 2]\)]] &\) /@ 
                runliste; \ \[IndentingNewLine]\[IndentingNewLine]Result\  = \
\ Select[Flatten[Result], First[#] =!= 0 &\ ]; \ \[IndentingNewLine]If[
              Result =!= \ {}, 
              Result, {OreZeroSummand}\ ]\ \[IndentingNewLine]]\  /; \ 
          f =!= {}\  (*"\< Module \>"*) ;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Ein OrePolynom vereinfachen bedeutet nun einfach die Liste der \
Summanden zu vereinfachen.\
\>", "Text"],

Cell[BoxData[
    \(\(OreSimplify[
          OrePolynomial[f__]] := \[IndentingNewLine]OreSimplifyCoefficients[
          Apply[OrePolynomial, OreSimplify[{f}]]];\)\)], "Input",
  InitializationCell->True],

Cell["Die Koeffizientenpolynome vereinfachen: ", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSimplifyCoefficients[
          f_OrePolynomial] := \[IndentingNewLine]OreMapOnCoefficients[
          Collect[#, OreVariables] &, f];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Summanden zu einem OrePolynomen aufaddieren ist nun eine Anwendung \
von Simplify:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSummand /: \ 
        Plus[f__OreSummand]\  := \ \ \[IndentingNewLine]Apply[OrePolynomial, 
          OreSimplify[{f}]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Damit erhalten wir schon die Addition von Ore Polynomen (die ja als \
Listen ihrer Summanden definiert sind):\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Plus[OrePolynomial[f__OreSummand], 
          OrePolynomial[g__OreSummand]] ^:= \ Plus[f, g];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiplikation", "Subsection",
  InitializationCell->True],

Cell["\<\
Die gew\[ODoubleDot]hnliche Multiplikation wird nur f\[UDoubleDot]r \
linksmultiplikation mit expliziten Zahlen zugelassen.\
\>", "Text"],

Cell[BoxData[{
    \(\(Times[a_OrePolynomial, \ b_OrePolynomial]\ \  ^:= \ 
        Return["\<Times doesn't work on Ore-Objekts !\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Times[a_OreSummand, \ b_OrePolynomial]\ \  ^:= \ 
        Return["\<Times doesn't work on Ore-Objekts !\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Times[a_, \ b_OrePolynomial]\  ^:= \ 
        OreMultiplication[OPo[a], b] /; NumberQ[a];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Hilfsfunktion: In einer Liste von OreSummanden gleiche \
Operatorpotenzen zusammenfassen: 
f\[UDoubleDot]r jeden \"Run\" gleicher Operatorpotenzen die Variablen \
aufaddieren.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(CollectSame[
          L_] := \[IndentingNewLine]\({Plus @@ \((\(#[\([1]\)] &\) /@ #)\), \
#[\([1, 2]\)]} &\) /@ \ \[IndentingNewLine]Split[\[IndentingNewLine]Sort[L, 
              OrderedQ[{#1[\([2]\)], #2[\([2]\)]}] &], \[IndentingNewLine]#1[\
\([2]\)] \[Equal] #2[\([2]\)] &];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "F\[UDoubleDot]r ein OrePolynomial p die Darstellung in der Gestalt \n",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_1\) d\_1\^\[Alpha]\_1 + \[Ellipsis] + \(p\_k\) 
          d\_k\^\[Alpha]\_k\)]],
  "mit Polynomen ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  "und verschiedenen Operatorpotenzen ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\^\[Alpha]\_i\)]],
  "\nin Form einer Liste zur\[UDoubleDot]ckgeben."
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(CollectOperators[p_] := \[IndentingNewLine]CollectSame[
          List @@ p];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Ein Monom von links mit einer Operatorpotenz multiplizieren.", \
"Subsubsection"],

Cell[TextData[{
  "Dies ist die generische Variante, einen Summanden mit der j-ten Potenz des \
Operators i zu multiplizieren.\nDas erste Argument hat also die Gestalt \
op={i,j}, das Zweite ist als OreSummand ein Term ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(m\_var\) m_op\)]],
  ". \nStartend mit dem Polynomanteil des Summanden werden f\[UDoubleDot]r \
jede Operatorpotenz ",
  Cell[BoxData[
      \(TraditionalForm\`0, \[Ellipsis], k, \[Ellipsis], j\)]],
  " die Koeffizienten ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  "in \n",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\(D\^\(j - k\)\)(
            c\_0 + \(c\_1\) D + \(c\_2\) D\^2 + \(\[Ellipsis]c\_k\) D\^k)\) 
          m\_op\)]],
  "als Liste bestimmt.\nAnschlie\[SZ]end werden die Operatorvariablen um ",
  Cell[BoxData[
      \(TraditionalForm\`m\_var\)]],
  "aufgef\[UDoubleDot]llt. Ein Select entfernt Nullterme.\n\nF\[UDoubleDot]r \
spezielle Operatoren sollte nach M\[ODoubleDot]glichkeit eine Schnellere \
Variante bereitgestellt werden,\nda diese Operation zeitkritisch und \
Grundlegend f\[UDoubleDot]r weitere Berechnungen ist."
}], "Text"],

Cell[BoxData[
    \(\(OperatorPowerTimesSummand[op_, 
          m_] := \[IndentingNewLine]Module[{PoLis\ , \
\[IndentingNewLine]DegCount = 
              Last[op]\ \[IndentingNewLine]}, \[IndentingNewLine]PoLis = \
{First[m]}; \ \[IndentingNewLine]With[{i = 
                First[op]},  (*"\< i ist the Number of the Operator. \>"\
*) \[IndentingNewLine]While[
              DegCount > 0, \[IndentingNewLine]PoLis = 
                Prepend[Map[Sigma[i], PoLis], 0] + \[IndentingNewLine]Append[
                    Map[Delta[i], PoLis], 
                    0]; \[IndentingNewLine]\(DegCount--\);\[IndentingNewLine]]\
; \[IndentingNewLine]Select[\ \[IndentingNewLine]Table[{PoLis[\([k + 1]\)], 
                  OreMonomial[m[\([2]\)], {i, k}]}, {k, 0, 
                  op[\([2]\)]}]\[IndentingNewLine], 
              First[#] =!= 
                  0 &\[IndentingNewLine]]\[IndentingNewLine]]\  (*"\< With \
i=op[[1]] \>"*) \[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Die selbe Operation f\[UDoubleDot]r eine Liste aufzusummierender \
Summanden:\
\>", "Text"],

Cell[BoxData[
    \(\(OperatorPowerTimesSummandList[op_, \ 
          L_] := \[IndentingNewLine]CollectSame[\[IndentingNewLine]Flatten[\(\
OperatorPowerTimesSummand[op, #] &\) /@ L, 
            1]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Nacheinander die OperatorPotenzen des Monomes multiplizieren (ein \
Monom ist einfach als
eine Liste von Operatorpotenzen realisiert):\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OperatorMonomTimesSummandList[m_, L_] := \[IndentingNewLine]Fold[
          OperatorPowerTimesSummandList[#2, #1] &, L, m];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Nun k\[ODoubleDot]nnen einen Summanden mit einer Liste von \
Summanden multiplizieren:\
\>", "Text"],

Cell[BoxData[
    \(\(SummandTimesSummandList[s_, 
          L_] := \[IndentingNewLine]\({First[s]*First[#], #[\([2]\)]} &\) /@ 
          OperatorMonomTimesSummandList[s[\([2]\)], L];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ListMult[L_, 
          M_] := \[IndentingNewLine]CollectSame[\[IndentingNewLine]Flatten[\(\
SummandTimesSummandList[#, M] &\) /@ L, 1]\[IndentingNewLine]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \( (*"\< Aus einem Ausdruck in Variablen eine Liste von Summanden machen: \
\>"*) \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \( (*"\< Variation von ExpandedCollect, um ein Polynom in eine Liste\
\[IndentingNewLine]von OreSummanden zu \[UDoubleDot]berf\[UDoubleDot]hren: \
\>"*) \)], "Input",
  InitializationCell->True],

Cell["\<\
Hilfsfunktion: MakeSummandList aus einem (evtl. inhomogenen) \
Polynom eine Liste von 
Objekten vom Typ OreSummand machen. In gewissem Sinne die Umkehrung von 
\"CollectSame\". Der gr\[ODoubleDot]\[SZ]te Aufwand ist hierbei das \
Verhindern von vorzeitigem Anwenden
der Regeln, die mit den Funktionen OreMonomial und OreSummand verbunden sind.\
\
\>", "Text"],

Cell[BoxData[
    \(\(MakeSummandList[{expr_, mon_}] := \[IndentingNewLine]Module[{sub, 
            osu, Zwi}, \[IndentingNewLine]Zwi = \((\((Expand[
                        Collect[expr, OreVariables, 
                          sub]]\[IndentingNewLine] /. {Times[a_, 
                            sub[b_]] \[Rule] 
                          osu[a\ b, mon]})\)\[IndentingNewLine] /. {sub[
                        a_] \[Rule] \ osu[a, mon]})\)\[IndentingNewLine] /. 
              osu \[Rule] 
                OreSummand\ ;  (*"\< nicht zu frueh, sonst rechnet OreSummand \
...\>"*) \[IndentingNewLine]If[Head[Zwi] === OreSummand, \ {Zwi}, 
            List @@ Zwi]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ore Multiplikation", "Subsubsection"],

Cell["\<\
Nach diesen Vorbereitungen ist f\[UDoubleDot]r die Multiplikation \
von Ore Polynomen nicht mehr viel zu tun:
Die einstellige Multiplikation operiert trivial, mehrstellige \
\[UDoubleDot]ber die implementierte Listenoperation,
der Bequemlichkeit wird noch die linksmultiplikation mit einer rationalen \
Zahl definiert.\
\>", "Text"],

Cell[BoxData[
    \(\(OreMultiplication[v_OrePolynomial] := v;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMultiplication[v_OrePolynomial, \ 
          w_OrePolynomial] := \[IndentingNewLine]Module[{L1, L2, \ 
            Res}, \[IndentingNewLine]L1 = CollectOperators[v]; \ 
          L2 = CollectOperators[w]; \[IndentingNewLine]Res = 
            Flatten[MakeSummandList /@ 
                ListMult[L1, L2]]; \[IndentingNewLine]OPo[
            Plus @@ Res]\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreMultiplication[v_ /; Element[v, Rationals], \ 
          w_OrePolynomial] := \[IndentingNewLine]OreMultiplication[OPo[v], 
          w];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Schnelles Potenzieren:", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Power[x_OrePolynomial, \ n_ /; n > 1]\  ^:= \ \((\[IndentingNewLine]\ 
          OrePolynomial /: \ 
            Power[x, \ n] = \[IndentingNewLine]OreMultiplication[
              Power[x, Floor[n/2]], 
              Power[x, n - Floor[n/2]]]\[IndentingNewLine])\);\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operatoren Anwenden", "Section"],

Cell[BoxData[
    \(\(OreApply[OreOneMonomial, P_]\  := \ P;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(OreApply[m_OreMonomial, \ 
        P_]\  := \[IndentingNewLine]OreApply[\[IndentingNewLine]Rest[
          m], \  (*"\< Restliche Operationen aufheben und ... \>"\
*) \[IndentingNewLine]Nest[\ Operation[\ \(m[\([1]\)]\)[\([1]\)]\ ], \ 
          P, \ \(m[\([1]\)]\)[\([2]\)]]\  (*"\< ... erste Op abarbeiten. \>"\
*) \[IndentingNewLine]]\)\(;\)\(\ \)\( (*"\< Apply \>"*) \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreApply[m_OrePolynomial, \ P_]\  := \[IndentingNewLine]Apply[Plus, 
          Map[#[\([1]\)]*OreApply[#[\([2]\)], P] &, m]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["H\[ODoubleDot]here Funktionen", "Section"],

Cell["\<\
Nun kommt noch eine Kollektion von h\[ODoubleDot]eren Funktionen, \
die vom Funktionstyp nicht unbedingt
in das Grundpaket geh\[ODoubleDot]ren, die aber so stark auf die interne \
Struktur zur\[UDoubleDot]ckgreifen, da\[SZ] der 
Abschlu\[SZ] der internen Strukturen eine Bereitstellung erfordert.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["F\[UDoubleDot]r Gr\[ODoubleDot]bnerbasen: Das S-Polynom", \
"Subsubsection"],

Cell["\<\
Das S-Polynom S von p und q sowie die Darstellung S = ap+bq   \
werden bestimmt.
Erst werden dazu die Operatoranteile va, vb von a resp. b bestimmt.
Dann werden die Leitmonome von va p und vb q betrachtet,  von denen der
Variablenpart A resp B genommen wird. 
Die Variablenanteile von a,b werden dann so gew\[ADoubleDot]hlt, da\[SZ] sich \
genau die Leitmonome
herausheben, wenn man va durch a und vb durch b ersetzt.
Die nicht erweiterte Funktion ist fast der selbe Text, wobei die \
Koeffizienten nicht mehr 
explizit bestimmt werden m\[UDoubleDot]ssen.\
\>", "Text"],

Cell[BoxData[
    \(\(OreExtendedSPolynomial[p_OrePolynomial, 
          q_OrePolynomial] := \[IndentingNewLine]Module[{v, w, vg, va, vb, a, 
            b, A, B, AuB}, \[IndentingNewLine]v = 
            MonomToVector[
              p[\([1, 2]\)]];  (*"\< Operatoren von p \>"\
*) \[IndentingNewLine]w = 
            MonomToVector[
              q[\([1, 2]\)]];  (*"\< Operatoren von q \>"\
*) \[IndentingNewLine]vg = 
            Max /@ Transpose@{v, w}; \  (*"\< \>" 
              kommutativer "\< ggt der Operatoren \>"*) \[IndentingNewLine]va \
= \ OPo[OreVec2Mon[
                vg - v]]; \  (*"\< Operatoren von a \
\>"*) \[IndentingNewLine]vb = \ 
            OPo[OreVec2Mon[
                vg - w]];  (*"\< Operatoren von b \>"*) \[IndentingNewLine]A \
= First[OreLeadingSummand[
                OMu[va, 
                  OPo[OreLeadingSummand[
                      p]]]]]; \  (*"\< resultierender Variablenpart, erster \
Summand\>"*) \[IndentingNewLine]B = 
            First[OreLeadingSummand[
                OMu[vb, 
                  OPo[OreLeadingSummand[
                      q]]]]];  (*"\< resultierender Variablenpart, zweiter \
Summand\>"*) \[IndentingNewLine]AuB = 
            PolynomialGCD[A, 
              B]; \  (*"\< gemeinsamer Faktor. \>"*) \[IndentingNewLine]a = 
            OMu[OPo[Cancel[B/AuB]], 
              va]; \  (*"\< Koeffizienten bestimmen \
\>"*) \[IndentingNewLine]b = 
            OMu[OPo[\(-Cancel[A/AuB]\)], 
              vb]; \[IndentingNewLine]Return[{OMu[a, p] + OMu[b, q], a, 
              b}];\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreSPoly[p_OrePolynomial, 
          q_OrePolynomial] := \[IndentingNewLine]Module[{v, w, vg, va, vb, A, 
            B, AuB}, \[IndentingNewLine]v = 
            MonomToVector[
              p[\([1, 2]\)]];  (*"\< Operatoren von p \>"\
*) \[IndentingNewLine]w = 
            MonomToVector[
              q[\([1, 2]\)]];  (*"\< Operatoren von q \>"\
*) \[IndentingNewLine]vg = 
            Max /@ Transpose@{v, w}; \  (*"\< \>" 
              kommutativer "\< kgv der Operatoren \>"*) \[IndentingNewLine]va \
= \ OPo[OreVec2Mon[
                vg - v]]; \  (*"\< Operatoren von a \
\>"*) \[IndentingNewLine]vb = \ 
            OPo[OreVec2Mon[
                vg - w]];  (*"\< Operatoren von b \>"*) \[IndentingNewLine]A \
= \(OreLeadingSummand[
                OMu[va, 
                  OPo[OreLeadingSummand[
                      p]]]]\)[\([1]\)]; \ \  (*"\< resultierender \
Variablenpart, erster Summand\>"*) \[IndentingNewLine]B = \(OreLeadingSummand[
                OMu[vb, 
                  OPo[OreLeadingSummand[
                      q]]]]\)[\([1]\)];  (*"\< resultierender Variablenpart, \
zweiter Summand\>"*) \[IndentingNewLine]AuB = 
            PolynomialGCD[A, 
              B]; \  (*"\< gemeinsamer Faktor. \
\>"*) \[IndentingNewLine]Return[
            OMu[OPo[Cancel[B/AuB]], va, p] + \[IndentingNewLine]OMu[
                OPo[\(-Cancel[A/AuB]\)], vb, 
                q]];\[IndentingNewLine]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gr\[ODoubleDot]bnerwalk: Ordnungsspezifische Funktionen:", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
SolvableQ: Testen der gegebenen Struktur auf \"solvable \
type\".\
\>", "Subsubsection"],

Cell[TextData[{
  "Die Algebra mit der aktuellen Ordnung ist vom ",
  StyleBox["Solvable type, ",
    FontColor->RGBColor[0, 1, 0]],
  "wenn f\[UDoubleDot]r alle Kombinationen von Operatoren\n",
  Cell[BoxData[
      \(TraditionalForm\`D\_i\)]],
  "und Variablen ",
  Cell[BoxData[
      \(TraditionalForm\`X\_j\)]],
  "gilt: ",
  Cell[BoxData[
      \(TraditionalForm\`\(X\_j\) D\_i \[LessEqual] D_i\)]],
  "X_j: (",
  StyleBox["k\[ODoubleDot]nnte ja auch nach OreAlgorithms",
    FontColor->RGBColor[1, 0, 0]],
  ")"
}], "Text"],

Cell[BoxData[
    \(SolvableQ := 
      Block[{norm, 
          reve, \[IndentingNewLine]Vrs = 
            OPo /@ OreVariables}, \[IndentingNewLine]norm = 
          Flatten[Outer[OMu, Vrs, 
              OreOperators]]; \[IndentingNewLine]reve = \(OPo[
                OreLeadingMonomial[#]] &\) /@ 
            Flatten[Transpose[
                Outer[OMu, OreOperators, Vrs]]]; \[IndentingNewLine]norm === 
          reve\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell["\<\
Hilfsfunktion, die die Eintr\[ADoubleDot]ge eines Exponentenvektors \
f\[UDoubleDot]r ein Monom von der internen
in die  durch die Aktuelle Reihenfolge der Monome gegebene permutiert:\
\>", \
"Text"],

Cell[BoxData[
    \(\(ActualOrder[x_] := \(x[\([#]\)] &\) /@ OreOrderVector;\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Hilfsfunktion, die eine Listen normierter Summanden aus einer Liste von \
Ore Polynomen\nerstellt: ",
  StyleBox["(ist der Normierungskrempel \[UDoubleDot]berhaupt \
n\[ODoubleDot]tig?)",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[
    \(\(AllSummands[
          L_List] := \((\[IndentingNewLine]\((L /. {OrePolynomial \[Rule] 
                    List, n_Rational \[Rule] 
                    1})\)\[IndentingNewLine] /. {Times[n_Integer, 
                  r__] \[Rule] 
                Times[r], \[IndentingNewLine]OreSummand[n_Integer, 
                  r__] \[Rule] 
                OreSummand[1, r]}\[IndentingNewLine])\);\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Aus einer Liste von Ore Polynomen die Exponentenvektoren aller \
Terme extrahieren:\
\>", "Text"],

Cell[BoxData[
    \(\(OrePolynomialsToVectorList[f_List] := \[IndentingNewLine]Map[
          ActualOrder, \ 
          Map[SummandToVector, AllSummands[f], {2}], {2}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
 Initialvalue: Das Gewicht eines Summanden bez\[UDoubleDot]glich \
der aktuellen Norm berechnen. Dazu den Ordnungsvektor in die aktuelle \
Reihenfolge permutieren, und mit der ersten Zeile der aktuellen \
Ordnungsmatrix multiplizieren.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreInitialValue[
          s_OreSummand] := \[IndentingNewLine]\((\(\(SummandToVector[
                    s]\)[\([#]\)] &\) /@ OreOrderVector)\) . 
          OreCurrentMatrix[\([1]\)];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Initialterm: Der erste \"Run\" der gewicht sortierten \
Summanden.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(OreInitialTerm[x_OrePolynomial] := \[IndentingNewLine]OrePolynomial @@ 
          First[Split[List @@ x, 
              OreInitialValue[#1] == OreInitialValue[#2] &]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Degenerationspunkt bestimmen.", "Subsubsection"],

Cell[TextData[{
  "Hier geht es um die Randbestimmung beim Gr\[ODoubleDot]bnerwalk.\n\
NextDegenerationVec bestimmt den Rand f\[UDoubleDot]r eine Menge von \
Vektoren, \nNextDegeneration f\[UDoubleDot]r eine Menge von Ore Polynomen.\n\
Zur\[UDoubleDot]ckgegeben wird der Wert t\[Element][0,1], an dem in einen \
neuen \"cone\"\nauf dem Pfad  w = a+t(v-a) mit (a = OreCurrentMatrix[[1]])\n\
eingetreten wird. Gibt es kein solches t, so wird t=2 \
zur\[UDoubleDot]ckgegeben.\nIdee: F\[UDoubleDot]r alle l_i\[Element]L mit ",
  Cell[BoxData[
      \(TraditionalForm\`l\_i \[NotEqual] l\_1\)]],
  "l\[ODoubleDot]sen wir die Gleichung \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(l\_1\),
              "TraditionalForm"], ".", \((v + t(v - a))\)}], 
          "\[Equal]", \(l\_i . \((v + t(v - a))\)\)}], TraditionalForm]]],
  " und geben die kleinste L\[ODoubleDot]sung zur\[UDoubleDot]ck."
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(NextDegeneration[L_List, 
          v_List /; Length[L] \[Equal] 1] := {v, 1};\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell["\<\
F\[UDoubleDot]r eine Liste von Polynomen werden Ordnungsvektoren \
aller Terme betrachtet:\
\>", "Text"],

Cell[BoxData[
    \(\(NextDegeneration[L_List, v_List] := \[IndentingNewLine]First[
          Sort[\[IndentingNewLine]\(NextDegenerationVec[#, v] &\) /@ 
              OrePolynomialsToVectorList[
                L], \[IndentingNewLine]#1[\([2]\)] < #2[\([2]\)] &\
\[IndentingNewLine]]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Die Berechnungen finden auf einer Menge von (Exponenten-)Vektoren \
statt.\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(NextDegenerationVec[L_List, \ 
          v_List] := \[IndentingNewLine]Module[\[IndentingNewLine]{t, tmp, \ 
            u, \ vv, Candidate, \ LL, LLZ, LLN}, \[IndentingNewLine]u = 
            OreCurrentMatrix[\([1]\)]; \  (*"\< actual top-wight \>"\
*) \[IndentingNewLine]vv = 
            v - u; \  (*"\< Current direction. \>"*) \[IndentingNewLine]\
\[IndentingNewLine]tmp = 
            Sort[L, Not[
                  OrderedQ[{#1 . u, #2 . u}]] &]; \[IndentingNewLine]tmp = 
            Split[L, #1 . u == #2 . 
                    u &]; \  (*"\< separate initials \
\>"*) \[IndentingNewLine]{initials, LL} = {First[tmp], 
              Flatten[Rest[tmp], 
                1]}; \[IndentingNewLine]\[IndentingNewLine]If[LL \[Equal] {}, 
            Return[{v, 
                1}]]; \  (*"\< no eqations to solve. \
\>"*) \[IndentingNewLine]Candidate = 
            First[Sort[initials, 
                Not[OrderedQ[{#1 . v, #2 . 
                          v}]] &]]; \[IndentingNewLine]LL = \(# - 
                  Candidate &\) /@ 
              Rest[L]; \  (*"\< the differencevectors. \>"\
*) \[IndentingNewLine]LLZ = 
            LL . u; \ \  (*"\< enumerators \>"*) \[IndentingNewLine]LLN = 
            LL . vv; \  (*"\< denominators \>"*) \[IndentingNewLine]LL = 
            Select[Transpose[{LLZ, LLN}], #[\([2]\)] \[NotEqual] 
                  0 &]; \  (*"\< demum. \[NotEqual] 0 \>"\
*) \[IndentingNewLine]LL = \(\(-#[\([1]\)]\)/#[\([2]\)] &\) /@ 
              LL; \  (*"\< calculate the quotients. \
\>"*) \[IndentingNewLine]LL = 
            Select[LL, # > 
                  0 &]; \  (*"\< t>0 required. \>"*) \[IndentingNewLine]t = 
            Min[LL]; \[IndentingNewLine]If[\((t \[LessEqual] 0)\) || \((t > 
                  1)\), Return[{v, 
                2}], \  (*"\< no t found! \
\>"*) \[IndentingNewLine]Return[{OreCurrentMatrix[\([1]\)] + t\ vv, 
                t}]; \  (*"\< found next wight \>"*) \[IndentingNewLine]]\
\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(End[]; \ \  (*"\< Private Context \
\>"*) \[IndentingNewLine]EndPackage[];\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
AutoGeneratedPackage->None,
WindowSize->{1034, 770},
WindowMargins->{{Automatic, 120}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"dmueller", "Mathematika", "Orealgebra"}, "OrePackageV3.nb.ps", \
CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 39, 0, 98, "Title"],
Cell[1818, 55, 93, 1, 33, "Subsubtitle",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1936, 60, 60, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[1999, 63, 2106, 41, 626, "Text",
  InitializationCell->True],
Cell[4108, 106, 391, 11, 122, "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[4536, 122, 93, 1, 74, "Section"],
Cell[4632, 125, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[4725, 129, 194, 4, 43, "Input",
  InitializationCell->True],
Cell[4922, 135, 229, 4, 43, "Input",
  InitializationCell->True],
Cell[5154, 141, 281, 5, 59, "Input",
  InitializationCell->True],
Cell[5438, 148, 279, 5, 59, "Input",
  InitializationCell->True],
Cell[5720, 155, 143, 3, 27, "Input",
  InitializationCell->True],
Cell[5866, 160, 187, 3, 27, "Input",
  InitializationCell->True],
Cell[6056, 165, 257, 4, 59, "Input",
  InitializationCell->True],
Cell[6316, 171, 238, 4, 59, "Input",
  InitializationCell->True],
Cell[6557, 177, 263, 4, 59, "Input",
  InitializationCell->True],
Cell[6823, 183, 279, 5, 59, "Input",
  InitializationCell->True],
Cell[7105, 190, 257, 4, 59, "Input",
  InitializationCell->True],
Cell[7365, 196, 297, 5, 59, "Input",
  InitializationCell->True],
Cell[7665, 203, 345, 6, 75, "Input",
  InitializationCell->True],
Cell[8013, 211, 922, 13, 139, "Input",
  InitializationCell->True],
Cell[8938, 226, 570, 9, 91, "Input",
  InitializationCell->True],
Cell[9511, 237, 600, 9, 107, "Input",
  InitializationCell->True],
Cell[10114, 248, 689, 10, 107, "Input",
  InitializationCell->True],
Cell[10806, 260, 480, 8, 91, "Input",
  InitializationCell->True],
Cell[11289, 270, 195, 4, 43, "Input",
  InitializationCell->True],
Cell[11487, 276, 228, 4, 59, "Input",
  InitializationCell->True],
Cell[11718, 282, 247, 5, 59, "Input",
  InitializationCell->True],
Cell[11968, 289, 415, 7, 91, "Input",
  InitializationCell->True],
Cell[12386, 298, 130, 3, 27, "Input",
  InitializationCell->True],
Cell[12519, 303, 161, 3, 27, "Input",
  InitializationCell->True],
Cell[12683, 308, 148, 3, 27, "Input",
  InitializationCell->True],
Cell[12834, 313, 202, 4, 27, "Input",
  InitializationCell->True],
Cell[13039, 319, 218, 4, 43, "Input",
  InitializationCell->True],
Cell[13260, 325, 194, 4, 43, "Input",
  InitializationCell->True],
Cell[13457, 331, 182, 4, 43, "Input",
  InitializationCell->True],
Cell[13642, 337, 178, 3, 27, "Input",
  InitializationCell->True],
Cell[13823, 342, 212, 4, 43, "Input",
  InitializationCell->True],
Cell[14038, 348, 213, 4, 43, "Input",
  InitializationCell->True],
Cell[14254, 354, 316, 5, 75, "Input",
  InitializationCell->True],
Cell[14573, 361, 114, 2, 27, "Input",
  InitializationCell->True],
Cell[14690, 365, 139, 3, 27, "Input",
  InitializationCell->True],
Cell[14832, 370, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[14976, 375, 201, 4, 43, "Input",
  InitializationCell->True],
Cell[15180, 381, 235, 5, 43, "Input",
  InitializationCell->True],
Cell[15418, 388, 153, 3, 27, "Input",
  InitializationCell->True],
Cell[15574, 393, 146, 3, 27, "Input",
  InitializationCell->True],
Cell[15723, 398, 150, 3, 27, "Input",
  InitializationCell->True],
Cell[15876, 403, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[15992, 407, 122, 3, 27, "Input",
  InitializationCell->True],
Cell[16117, 412, 147, 3, 27, "Input",
  InitializationCell->True],
Cell[16267, 417, 268, 4, 59, "Input",
  InitializationCell->True],
Cell[16538, 423, 243, 5, 59, "Input",
  InitializationCell->True],
Cell[16784, 430, 235, 5, 59, "Input",
  InitializationCell->True],
Cell[17022, 437, 264, 5, 59, "Input",
  InitializationCell->True],
Cell[17289, 444, 679, 13, 123, "Input",
  InitializationCell->True],
Cell[17971, 459, 194, 4, 43, "Input",
  InitializationCell->True],
Cell[18168, 465, 156, 3, 27, "Input",
  InitializationCell->True],
Cell[18327, 470, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[18471, 475, 147, 3, 27, "Input",
  InitializationCell->True],
Cell[18621, 480, 178, 4, 43, "Input",
  InitializationCell->True],
Cell[18802, 486, 236, 5, 43, "Input",
  InitializationCell->True],
Cell[19041, 493, 176, 3, 27, "Input",
  InitializationCell->True],
Cell[19220, 498, 218, 4, 43, "Input",
  InitializationCell->True],
Cell[19441, 504, 200, 4, 27, "Input",
  InitializationCell->True],
Cell[19644, 510, 223, 4, 43, "Input",
  InitializationCell->True],
Cell[19870, 516, 202, 4, 27, "Input",
  InitializationCell->True],
Cell[20075, 522, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[20191, 526, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[20310, 530, 228, 4, 43, "Input",
  InitializationCell->True],
Cell[20541, 536, 150, 3, 27, "Input",
  InitializationCell->True],
Cell[20694, 541, 272, 5, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[21003, 551, 38, 0, 74, "Section"],
Cell[21044, 553, 98, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[21167, 559, 84, 1, 38, "Subsection",
  InitializationCell->True],
Cell[21254, 562, 158, 4, 68, "Text"],

Cell[CellGroupData[{
Cell[21437, 570, 137, 3, 28, "Subsubsection"],
Cell[21577, 575, 467, 8, 107, "Input",
  InitializationCell->True],
Cell[22047, 585, 150, 4, 32, "Text",
  InitializationCell->True],
Cell[22200, 591, 180, 4, 27, "Input",
  InitializationCell->True],
Cell[22383, 597, 159, 4, 32, "Text",
  InitializationCell->True],
Cell[22545, 603, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[22689, 608, 88, 1, 32, "Text",
  InitializationCell->True],
Cell[22780, 611, 89, 2, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22918, 619, 120, 2, 38, "Subsection",
  InitializationCell->True],
Cell[23041, 623, 335, 7, 75, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[23413, 635, 124, 4, 38, "Subsection",
  InitializationCell->True],
Cell[23540, 641, 266, 5, 50, "Text"],
Cell[23809, 648, 1074, 21, 251, "Input",
  InitializationCell->True],
Cell[24886, 671, 301, 6, 68, "Text"],
Cell[25190, 679, 141, 3, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[25368, 687, 80, 1, 38, "Subsection",
  InitializationCell->True],
Cell[25451, 690, 206, 5, 50, "Text"],
Cell[25660, 697, 188, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[25885, 705, 123, 2, 38, "Subsection",
  InitializationCell->True],
Cell[26011, 709, 78, 0, 32, "Text"],
Cell[26092, 711, 280, 5, 91, "Input",
  InitializationCell->True],
Cell[26375, 718, 51, 0, 32, "Text"],
Cell[26429, 720, 1542, 32, 299, "Input",
  InitializationCell->True],
Cell[27974, 754, 245, 6, 68, "Text"],
Cell[28222, 762, 298, 6, 107, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28569, 774, 79, 0, 74, "Section"],

Cell[CellGroupData[{
Cell[28673, 778, 86, 1, 38, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[28784, 783, 83, 1, 28, "Subsubsection"],
Cell[28870, 786, 188, 5, 32, "Text",
  InitializationCell->True],
Cell[29061, 793, 546, 11, 171, "Input",
  InitializationCell->True],
Cell[29610, 806, 286, 7, 68, "Text",
  InitializationCell->True],
Cell[29899, 815, 203, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[30139, 824, 81, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[30223, 827, 1630, 34, 347, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[31890, 866, 62, 0, 28, "Subsubsection"],
Cell[31955, 868, 129, 3, 32, "Text"],
Cell[32087, 873, 236, 5, 43, "Input",
  InitializationCell->True],
Cell[32326, 880, 172, 4, 32, "Text",
  InitializationCell->True],
Cell[32501, 886, 153, 3, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[32691, 894, 66, 0, 28, "Subsubsection"],
Cell[32760, 896, 700, 17, 176, "Text",
  InitializationCell->True],
Cell[33463, 915, 4137, 69, 763, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[37637, 989, 46, 0, 28, "Subsubsection"],
Cell[37686, 991, 168, 4, 50, "Text"],
Cell[37857, 997, 914, 18, 171, "Input",
  InitializationCell->True],
Cell[38774, 1017, 109, 3, 32, "Text"],
Cell[38886, 1022, 1177, 21, 283, "Input",
  InitializationCell->True],
Cell[40066, 1045, 39, 0, 32, "Text"],
Cell[40108, 1047, 441, 7, 59, "Input",
  InitializationCell->True],
Cell[40552, 1056, 110, 3, 32, "Text"],
Cell[40665, 1061, 194, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40920, 1072, 40, 0, 74, "Section"],
Cell[40963, 1074, 252, 5, 50, "Text"],
Cell[41218, 1081, 198, 4, 27, "Input",
  InitializationCell->True],
Cell[41419, 1087, 73, 0, 32, "Text"],
Cell[41495, 1089, 665, 11, 139, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[42185, 1104, 84, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[42294, 1109, 110, 3, 28, "Subsubsection"],
Cell[42407, 1114, 111, 3, 32, "Text"],
Cell[42521, 1119, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[42642, 1123, 165, 4, 50, "Text"],
Cell[42810, 1129, 397, 8, 75, "Input",
  InitializationCell->True],
Cell[43210, 1139, 251, 6, 50, "Text",
  InitializationCell->True],
Cell[43464, 1147, 799, 17, 139, "Input",
  InitializationCell->True],
Cell[44266, 1166, 136, 4, 32, "Text",
  InitializationCell->True],
Cell[44405, 1172, 404, 7, 123, "Input",
  InitializationCell->True],
Cell[44812, 1181, 143, 3, 27, "Input",
  InitializationCell->True],
Cell[44958, 1186, 224, 5, 32, "Text"],
Cell[45185, 1193, 333, 8, 75, "Input",
  InitializationCell->True],
Cell[45521, 1203, 556, 11, 155, "Input",
  InitializationCell->True],
Cell[46080, 1216, 900, 18, 219, "Input",
  InitializationCell->True],
Cell[46983, 1236, 273, 6, 91, "Input",
  InitializationCell->True],
Cell[47259, 1244, 169, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47477, 1254, 72, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[47574, 1258, 52, 0, 28, "Subsubsection"],
Cell[47629, 1260, 61, 1, 32, "Text",
  InitializationCell->True],
Cell[47693, 1263, 123, 3, 27, "Input",
  InitializationCell->True],
Cell[47819, 1268, 71, 1, 32, "Text",
  InitializationCell->True],
Cell[47893, 1271, 187, 4, 43, "Input",
  InitializationCell->True],
Cell[48083, 1277, 68, 1, 32, "Text",
  InitializationCell->True],
Cell[48154, 1280, 314, 6, 75, "Input",
  InitializationCell->True],
Cell[48471, 1288, 78, 1, 32, "Text",
  InitializationCell->True],
Cell[48552, 1291, 320, 6, 75, "Input",
  InitializationCell->True],
Cell[48875, 1299, 69, 1, 32, "Text",
  InitializationCell->True],
Cell[48947, 1302, 187, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[49171, 1311, 80, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[49254, 1314, 96, 1, 32, "Text",
  InitializationCell->True],
Cell[49353, 1317, 295, 6, 43, "Input",
  InitializationCell->True],
Cell[49651, 1325, 110, 3, 32, "Text"],
Cell[49764, 1330, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[49865, 1334, 1502, 29, 443, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[51404, 1368, 106, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[51513, 1371, 148, 4, 50, "Text"],
Cell[51664, 1377, 648, 13, 123, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[52349, 1395, 100, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[52452, 1398, 129, 4, 32, "Text",
  InitializationCell->True],
Cell[52584, 1404, 1070, 20, 171, "Input",
  InitializationCell->True],
Cell[53657, 1426, 80, 1, 32, "Text",
  InitializationCell->True],
Cell[53740, 1429, 426, 8, 91, "Input",
  InitializationCell->True],
Cell[54169, 1439, 327, 7, 86, "Text"],
Cell[54499, 1448, 3751, 63, 875, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58299, 1517, 120, 2, 38, "Subsection",
  InitializationCell->True],
Cell[58422, 1521, 99, 1, 32, "Text",
  InitializationCell->True],
Cell[58524, 1524, 133, 3, 27, "Input",
  InitializationCell->True],
Cell[58660, 1529, 84, 1, 32, "Text",
  InitializationCell->True],
Cell[58747, 1532, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[58852, 1536, 91, 3, 32, "Text"],
Cell[58946, 1541, 207, 4, 43, "Input",
  InitializationCell->True],
Cell[59156, 1547, 72, 0, 32, "Text"],
Cell[59231, 1549, 963, 20, 235, "Input",
  InitializationCell->True],
Cell[60197, 1571, 59, 0, 32, "Text"],
Cell[60259, 1573, 305, 6, 107, "Input",
  InitializationCell->True],
Cell[60567, 1581, 252, 5, 43, "Input",
  InitializationCell->True],
Cell[60822, 1588, 171, 4, 32, "Text"],
Cell[60996, 1594, 146, 3, 27, "Input",
  InitializationCell->True],
Cell[61145, 1599, 105, 3, 32, "Text"],
Cell[61253, 1604, 522, 11, 123, "Input",
  InitializationCell->True],
Cell[61778, 1617, 116, 4, 32, "Text",
  InitializationCell->True],
Cell[61897, 1623, 199, 4, 43, "Input",
  InitializationCell->True],
Cell[62099, 1629, 57, 0, 32, "Text"],
Cell[62159, 1631, 272, 7, 86, "Text",
  InitializationCell->True],
Cell[62434, 1640, 788, 16, 171, "Input",
  InitializationCell->True],
Cell[63225, 1658, 80, 1, 32, "Text",
  InitializationCell->True],
Cell[63308, 1661, 357, 8, 59, "Input",
  InitializationCell->True],
Cell[63668, 1671, 64, 1, 32, "Text",
  InitializationCell->True],
Cell[63735, 1674, 237, 6, 43, "Input",
  InitializationCell->True],
Cell[63975, 1682, 115, 4, 32, "Text",
  InitializationCell->True],
Cell[64093, 1688, 303, 6, 59, "Input",
  InitializationCell->True],
Cell[64399, 1696, 104, 1, 32, "Text",
  InitializationCell->True],
Cell[64506, 1699, 236, 4, 43, "Input",
  InitializationCell->True],
Cell[64745, 1705, 85, 1, 32, "Text",
  InitializationCell->True],
Cell[64833, 1708, 232, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[65102, 1717, 59, 1, 38, "Subsection",
  InitializationCell->True],
Cell[65164, 1720, 154, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[65343, 1727, 131, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[65477, 1733, 39, 0, 32, "Text"],
Cell[65519, 1735, 350, 7, 59, "Input",
  InitializationCell->True],
Cell[65872, 1744, 331, 7, 86, "Text"],
Cell[66206, 1753, 789, 14, 139, "Input",
  InitializationCell->True],
Cell[66998, 1769, 115, 3, 32, "Text"],
Cell[67116, 1774, 205, 4, 43, "Input",
  InitializationCell->True],
Cell[67324, 1780, 84, 1, 32, "Text",
  InitializationCell->True],
Cell[67411, 1783, 202, 4, 43, "Input",
  InitializationCell->True],
Cell[67616, 1789, 134, 4, 32, "Text",
  InitializationCell->True],
Cell[67753, 1795, 188, 4, 43, "Input",
  InitializationCell->True],
Cell[67944, 1801, 161, 4, 32, "Text",
  InitializationCell->True],
Cell[68108, 1807, 158, 3, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[68315, 1816, 64, 1, 38, "Subsection",
  InitializationCell->True],
Cell[68382, 1819, 147, 3, 32, "Text"],
Cell[68532, 1824, 455, 9, 59, "Input",
  InitializationCell->True],
Cell[68990, 1835, 227, 6, 50, "Text",
  InitializationCell->True],
Cell[69220, 1843, 345, 6, 91, "Input",
  InitializationCell->True],
Cell[69568, 1851, 484, 13, 68, "Text",
  InitializationCell->True],
Cell[70055, 1866, 142, 3, 43, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[70222, 1873, 87, 1, 28, "Subsubsection"],
Cell[70312, 1876, 1138, 25, 158, "Text"],
Cell[71453, 1903, 994, 18, 283, "Input",
  InitializationCell->True],
Cell[72450, 1923, 101, 3, 32, "Text"],
Cell[72554, 1928, 261, 5, 75, "Input",
  InitializationCell->True],
Cell[72818, 1935, 186, 5, 50, "Text",
  InitializationCell->True],
Cell[73007, 1942, 188, 3, 43, "Input",
  InitializationCell->True],
Cell[73198, 1947, 110, 3, 32, "Text"],
Cell[73311, 1952, 227, 4, 43, "Input",
  InitializationCell->True],
Cell[73541, 1958, 223, 5, 75, "Input",
  InitializationCell->True],
Cell[73767, 1965, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[73911, 1970, 212, 4, 43, "Input",
  InitializationCell->True],
Cell[74126, 1976, 369, 8, 86, "Text"],
Cell[74498, 1986, 728, 12, 139, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[75263, 2003, 43, 0, 28, "Subsubsection"],
Cell[75309, 2005, 342, 7, 68, "Text"],
Cell[75654, 2014, 105, 2, 27, "Input",
  InitializationCell->True],
Cell[75762, 2018, 443, 8, 107, "Input",
  InitializationCell->True],
Cell[76208, 2028, 204, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[76449, 2037, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[76528, 2040, 331, 6, 75, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[76920, 2053, 38, 0, 74, "Section"],
Cell[76961, 2055, 103, 2, 27, "Input",
  InitializationCell->True],
Cell[77067, 2059, 440, 7, 107, "Input",
  InitializationCell->True],
Cell[77510, 2068, 190, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[77737, 2076, 48, 0, 74, "Section"],
Cell[77788, 2078, 322, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[78135, 2089, 82, 1, 28, "Subsubsection"],
Cell[78220, 2092, 579, 12, 158, "Text"],
Cell[78802, 2106, 1617, 35, 235, "Input",
  InitializationCell->True],
Cell[80422, 2143, 1484, 32, 219, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[81943, 2180, 78, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[82046, 2184, 98, 3, 28, "Subsubsection"],
Cell[82147, 2189, 530, 17, 50, "Text"],
Cell[82680, 2208, 486, 11, 107, "Input",
  InitializationCell->True],
Cell[83169, 2221, 209, 5, 50, "Text"],
Cell[83381, 2228, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[83503, 2232, 252, 6, 50, "Text"],
Cell[83758, 2240, 454, 9, 91, "Input",
  InitializationCell->True],
Cell[84215, 2251, 107, 3, 32, "Text"],
Cell[84325, 2256, 211, 4, 43, "Input",
  InitializationCell->True],
Cell[84539, 2262, 287, 6, 50, "Text",
  InitializationCell->True],
Cell[84829, 2270, 250, 5, 43, "Input",
  InitializationCell->True],
Cell[85082, 2277, 118, 4, 32, "Text",
  InitializationCell->True],
Cell[85203, 2283, 232, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[85472, 2292, 54, 0, 28, "Subsubsection"],
Cell[85529, 2294, 947, 19, 158, "Text"],
Cell[86479, 2315, 159, 3, 27, "Input",
  InitializationCell->True],
Cell[86641, 2320, 114, 3, 32, "Text"],
Cell[86758, 2325, 329, 6, 91, "Input",
  InitializationCell->True],
Cell[87090, 2333, 126, 4, 32, "Text",
  InitializationCell->True],
Cell[87219, 2339, 2076, 40, 395, "Input",
  InitializationCell->True],
Cell[89298, 2381, 135, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

